/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainter_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <QPixmap>
#include <QVector>
#include <QWidget>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qfontmetrics.h>
#include <qimage.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpainterpath.h>
#include <qpen.h>
#include <qpicture.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtextoption.h>
#include <qtransform.h>
#include <qwidget.h>

using namespace Shiboken;


// Target ---------------------------------------------------------

extern "C" {
static int
SbkQPainter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainter >()))
        return -1;

    QPainter* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPainter", 0, 1, &arg))
        return -1;

    // Overloaded function decisor
    // 0: QPainter()
    // 1: QPainter(QPaintDevice*)
    if (numArgs == 0) {
        overloadId = 0; // QPainter()
    } else if (numArgs == 1 && Shiboken::Converter<QPaintDevice * >::isConvertible(arg)) {
        overloadId = 1; // QPainter(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainter_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPainter()
            {

                if(!PyErr_Occurred()) {
                // QPainter()
                cptr = new QPainter();
                }
                break;
            }
            case 1: // QPainter(QPaintDevice*)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return -1;
                QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // QPainter(QPaintDevice*)
                cptr = new QPainter(cpp_arg0);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QPainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQPainter_Init_TypeError;

    sbkSelf->validCppObject = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    SbkQPainter_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter", overloads);
        return -1;
}

static PyObject* SbkQPainterFunc_background(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // background()const
            const QBrush & cppResult = cppSelf->QPainter::background();
            pyResult = Shiboken::Converter<const QBrush & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_backgroundMode(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundMode()const
            Qt::BGMode cppResult = cppSelf->QPainter::backgroundMode();
            pyResult = Shiboken::Converter<Qt::BGMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_begin(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: begin(QPaintDevice*)
    if (Shiboken::Converter<QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // begin(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_begin_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // begin(QPaintDevice*)
            bool cppResult = cppSelf->QPainter::begin(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterFunc_begin_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.begin", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_beginNativePainting(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // beginNativePainting()
            cppSelf->QPainter::beginNativePainting();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_boundingRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "o" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): not enough arguments");
        return 0;
    } else if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterFunc_boundingRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:boundingRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: boundingRect(QRect,int,QString)
    // 1: boundingRect(QRectF,QString,QTextOption)
    // 2: boundingRect(QRectF,int,QString)
    // 3: boundingRect(int,int,int,int,int,QString)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter<QString >::isConvertible(pyargs[5])) {
        overloadId = 3; // boundingRect(int,int,int,int,int,QString)
    } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // boundingRect(QRect,int,QString)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 2; // boundingRect(QRectF,int,QString)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            } else if (Shiboken::Converter<const QTextOption & >::isConvertible(pyargs[2])) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_boundingRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // boundingRect(QRect,int,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // boundingRect(QRect,int,QString)
                QRect cppResult = cppSelf->QPainter::boundingRect(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // boundingRect(QRectF,QString,QTextOption)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "o");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "o";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.boundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QTextOption > cpp_arg2_auto_ptr;
                QTextOption cpp_arg2_tmp = QTextOption();
                QTextOption* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QTextOption* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QTextOption >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QTextOption >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // boundingRect(QRectF,QString,QTextOption)
                QRectF cppResult = cppSelf->QPainter::boundingRect(*cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 2: // boundingRect(QRectF,int,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // boundingRect(QRectF,int,QString)
                QRectF cppResult = cppSelf->QPainter::boundingRect(*cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Shiboken::Converter<QRectF >::toPython(cppResult);
                }
                break;
            }
            case 3: // boundingRect(int,int,int,int,int,QString)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QString cpp_arg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // boundingRect(int,int,int,int,int,QString)
                QRect cppResult = cppSelf->QPainter::boundingRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterFunc_boundingRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, QString", "PySide.QtCore.QRectF, QString, PySide.QtGui.QTextOption = QTextOption()", "PySide.QtCore.QRectF, int, QString", "int, int, int, int, int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.boundingRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_brush(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brush()const
            const QBrush & cppResult = cppSelf->QPainter::brush();
            pyResult = Shiboken::Converter<const QBrush & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_brushOrigin(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // brushOrigin()const
            QPoint cppResult = cppSelf->QPainter::brushOrigin();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_clipPath(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipPath()const
            QPainterPath cppResult = cppSelf->QPainter::clipPath();
            pyResult = Shiboken::Converter<QPainterPath >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_clipRegion(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clipRegion()const
            QRegion cppResult = cppSelf->QPainter::clipRegion();
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_combinedMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // combinedMatrix()const
            QMatrix cppResult = cppSelf->QPainter::combinedMatrix();
            pyResult = Shiboken::Converter<QMatrix >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_combinedTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // combinedTransform()const
            QTransform cppResult = cppSelf->QPainter::combinedTransform();
            pyResult = Shiboken::Converter<QTransform >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_compositionMode(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // compositionMode()const
            QPainter::CompositionMode cppResult = cppSelf->QPainter::compositionMode();
            pyResult = Shiboken::Converter<QPainter::CompositionMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_device(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // device()const
            QPaintDevice * cppResult = cppSelf->QPainter::device();
            pyResult = Shiboken::Converter<QPaintDevice * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_deviceMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deviceMatrix()const
            const QMatrix & cppResult = cppSelf->QPainter::deviceMatrix();
            pyResult = Shiboken::Converter<const QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_deviceTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // deviceTransform()const
            const QTransform & cppResult = cppSelf->QPainter::deviceTransform();
            pyResult = Shiboken::Converter<const QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_drawArc(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterFunc_drawArc_TypeError;

    if (!PyArg_UnpackTuple(args, "drawArc", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawArc(QRect,int,int)
    // 1: drawArc(QRectF,int,int)
    // 2: drawArc(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawArc(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawArc(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawArc(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawArc_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawArc(QRect,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawArc(QRect,int,int)
                cppSelf->QPainter::drawArc(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawArc(QRectF,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawArc(QRectF,int,int)
                cppSelf->QPainter::drawArc(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // drawArc(int,int,int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // drawArc(int,int,int,int,int,int)
                cppSelf->QPainter::drawArc(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawArc_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawArc", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawChord(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterFunc_drawChord_TypeError;

    if (!PyArg_UnpackTuple(args, "drawChord", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawChord(QRect,int,int)
    // 1: drawChord(QRectF,int,int)
    // 2: drawChord(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawChord(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawChord(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawChord(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawChord_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawChord(QRect,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawChord(QRect,int,int)
                cppSelf->QPainter::drawChord(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawChord(QRectF,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawChord(QRectF,int,int)
                cppSelf->QPainter::drawChord(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // drawChord(int,int,int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // drawChord(int,int,int,int,int,int)
                cppSelf->QPainter::drawChord(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawChord_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawChord", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawConvexPolygon(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawConvexPolygon(QPolygon)
    // 1: drawConvexPolygon(QPolygonF)
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // drawConvexPolygon(QPolygon)
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 1; // drawConvexPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawConvexPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawConvexPolygon(QPolygon)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawConvexPolygon(QPolygon)
                cppSelf->QPainter::drawConvexPolygon(*cpp_arg0);
                }
                break;
            }
            case 1: // drawConvexPolygon(QPolygonF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawConvexPolygon(QPolygonF)
                cppSelf->QPainter::drawConvexPolygon(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawConvexPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawConvexPolygon", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawEllipse(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQPainterFunc_drawEllipse_TypeError;

    if (!PyArg_UnpackTuple(args, "drawEllipse", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawEllipse(QPoint,int,int)
    // 1: drawEllipse(QPointF,qreal,qreal)
    // 2: drawEllipse(QRect)
    // 3: drawEllipse(QRectF)
    // 4: drawEllipse(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // drawEllipse(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 2; // drawEllipse(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 3; // drawEllipse(QRectF)
    } else if (numArgs == 3 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawEllipse(QPoint,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawEllipse(QPointF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawEllipse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawEllipse(QPoint,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawEllipse(QPoint,int,int)
                cppSelf->QPainter::drawEllipse(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawEllipse(QPointF,qreal,qreal)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawEllipse(QPointF,qreal,qreal)
                cppSelf->QPainter::drawEllipse(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // drawEllipse(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // drawEllipse(QRect)
                cppSelf->QPainter::drawEllipse(*cpp_arg0);
                }
                break;
            }
            case 3: // drawEllipse(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawEllipse(QRectF)
                cppSelf->QPainter::drawEllipse(*cpp_arg0);
                }
                break;
            }
            case 4: // drawEllipse(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // drawEllipse(int,int,int,int)
                cppSelf->QPainter::drawEllipse(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawEllipse_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int, int", "PySide.QtCore.QPointF, float, float", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawEllipse", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags", "sh", "sw", "sx", "sy" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 5, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:drawImage", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: drawImage(QPoint,QImage)
    // 1: drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
    // 2: drawImage(QPointF,QImage)
    // 3: drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
    // 4: drawImage(QRect,QImage)
    // 5: drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
    // 6: drawImage(QRectF,QImage)
    // 7: drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
    // 8: drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QImage & >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                } else if (SbkNumber_Check(pyargs[5])) {
                    if (numArgs == 6) {
                        overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                    } else if (SbkNumber_Check(pyargs[6])) {
                        if (numArgs == 7) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[7])) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        }
                    }
                }
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QImage & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // drawImage(QRect,QImage)
        } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QImage & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 6; // drawImage(QRectF,QImage)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QImage & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawImage(QPoint,QImage)
        } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QImage & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // drawImage(QPointF,QImage)
        } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[3])) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawImage_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawImage(QPoint,QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawImage(QPoint,QImage)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 2: // drawImage(QPointF,QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawImage(QPointF,QImage)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
                QRectF* cpp_arg2 = Shiboken::Converter<QRectF* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);
                QFlags<Qt::ImageConversionFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 4: // drawImage(QRect,QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawImage(QRect,QImage)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 5: // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);
                QFlags<Qt::ImageConversionFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 6: // drawImage(QRectF,QImage)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawImage(QRectF,QImage)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 7: // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QImage* cpp_arg1 = Shiboken::Converter<QImage* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
                QRectF* cpp_arg2 = Shiboken::Converter<QRectF* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);
                QFlags<Qt::ImageConversionFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[3]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                cppSelf->QPainter::drawImage(*cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 8: // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sx");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "sx";
                        else
                            pyargs[3] = value;
                    }
                    value = PyDict_GetItemString(kwds, "sy");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "sy";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "sw");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "sw";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "sh");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "sh";
                        else
                            pyargs[6] = value;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "flags";
                        else
                            pyargs[7] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QImage* cpp_arg2 = Shiboken::Converter<QImage* >::toCpp(pyargs[2]);
                int cpp_arg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;
                int cpp_arg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : -1;
                int cpp_arg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : -1;
                QFlags<Qt::ImageConversionFlag> cpp_arg7 = pyargs[7] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[7]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                cppSelf->QPainter::drawImage(cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawImage_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QImage", "PySide.QtCore.QPoint, PySide.QtGui.QImage, PySide.QtCore.QRect, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QPointF, PySide.QtGui.QImage", "PySide.QtCore.QPointF, PySide.QtGui.QImage, PySide.QtCore.QRectF, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QRect, PySide.QtGui.QImage", "PySide.QtCore.QRect, PySide.QtGui.QImage, PySide.QtCore.QRect, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtCore.QRectF, PySide.QtGui.QImage", "PySide.QtCore.QRectF, PySide.QtGui.QImage, PySide.QtCore.QRectF, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "int, int, PySide.QtGui.QImage, int = 0, int = 0, int = -1, int = -1, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawImage", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawLine(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto SbkQPainterFunc_drawLine_TypeError;

    if (!PyArg_UnpackTuple(args, "drawLine", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawLine(QLine)
    // 1: drawLine(QLineF)
    // 2: drawLine(QPoint,QPoint)
    // 3: drawLine(QPointF,QPointF)
    // 4: drawLine(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // drawLine(int,int,int,int)
    } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        overloadId = 2; // drawLine(QPoint,QPoint)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[1])) {
        overloadId = 3; // drawLine(QPointF,QPointF)
    } else if (numArgs == 1 && Shiboken::Converter<const QLine & >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawLine(QLine)
    } else if (numArgs == 1 && Shiboken::Converter<const QLineF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawLine(QLineF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawLine_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawLine(QLine)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QLine* cpp_arg0 = Shiboken::Converter<QLine* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // drawLine(QLine)
                cppSelf->QPainter::drawLine(*cpp_arg0);
                }
                break;
            }
            case 1: // drawLine(QLineF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QLineF > cpp_arg0_auto_ptr;
                QLineF* cpp_arg0 = Shiboken::Converter<QLineF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QLineF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QLineF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawLine(QLineF)
                cppSelf->QPainter::drawLine(*cpp_arg0);
                }
                break;
            }
            case 2: // drawLine(QPoint,QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawLine(QPoint,QPoint)
                cppSelf->QPainter::drawLine(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // drawLine(QPointF,QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg1_auto_ptr;
                QPointF* cpp_arg1 = Shiboken::Converter<QPointF* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPointF >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // drawLine(QPointF,QPointF)
                cppSelf->QPainter::drawLine(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 4: // drawLine(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // drawLine(int,int,int,int)
                cppSelf->QPainter::drawLine(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawLine_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QPoint, PySide.QtCore.QPoint", "PySide.QtCore.QPointF, PySide.QtCore.QPointF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawLine", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawLines(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawLines(QVector<QLine>)
    // 1: drawLines(QVector<QLineF>)
    // 2: drawLines(QVector<QPoint>)
    // 3: drawLines(QVector<QPointF>)
    if (Shiboken::Converter< QVector<QLine >  >::isConvertible(arg)) {
        overloadId = 0; // drawLines(QVector<QLine>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawLines_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawLines(QVector<QLine>)
            {
                QVector<QLine > cpp_arg0 = Shiboken::Converter<QVector<QLine > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawLines(QVector<QLine>)
                cppSelf->QPainter::drawLines(cpp_arg0);
                }
                break;
            }
            case 1: // drawLines(QVector<QLineF>)
            {
                QVector<QLineF > cpp_arg0 = Shiboken::Converter<QVector<QLineF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawLines(QVector<QLineF>)
                cppSelf->QPainter::drawLines(cpp_arg0);
                }
                break;
            }
            case 2: // drawLines(QVector<QPoint>)
            {
                QVector<QPoint > cpp_arg0 = Shiboken::Converter<QVector<QPoint > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawLines(QVector<QPoint>)
                cppSelf->QPainter::drawLines(cpp_arg0);
                }
                break;
            }
            case 3: // drawLines(QVector<QPointF>)
            {
                QVector<QPointF > cpp_arg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawLines(QVector<QPointF>)
                cppSelf->QPainter::drawLines(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawLines_TypeError:
        const char* overloads[] = {"list", "list", "list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawLines", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPath(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPath(QPainterPath)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(arg)) {
        overloadId = 0; // drawPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // drawPath(QPainterPath)
            cppSelf->QPainter::drawPath(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPath", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPicture(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPicture", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawPicture(QPoint,QPicture)
    // 1: drawPicture(QPointF,QPicture)
    // 2: drawPicture(int,int,QPicture)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<const QPicture & >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawPicture(int,int,QPicture)
    } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPicture & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawPicture(QPoint,QPicture)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPicture & >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawPicture(QPointF,QPicture)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPicture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPicture(QPoint,QPicture)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPicture* cpp_arg1 = Shiboken::Converter<QPicture* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawPicture(QPoint,QPicture)
                cppSelf->QPainter::drawPicture(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // drawPicture(QPointF,QPicture)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPicture* cpp_arg1 = Shiboken::Converter<QPicture* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawPicture(QPointF,QPicture)
                cppSelf->QPainter::drawPicture(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // drawPicture(int,int,QPicture)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QPicture* cpp_arg2 = Shiboken::Converter<QPicture* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawPicture(int,int,QPicture)
                cppSelf->QPainter::drawPicture(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPicture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QPicture", "PySide.QtCore.QPointF, PySide.QtGui.QPicture", "int, int, PySide.QtGui.QPicture", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPicture", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPie(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterFunc_drawPie_TypeError;

    if (!PyArg_UnpackTuple(args, "drawPie", 3, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawPie(QRect,int,int)
    // 1: drawPie(QRectF,int,int)
    // 2: drawPie(int,int,int,int,int,int)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // drawPie(int,int,int,int,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // drawPie(QRect,int,int)
    } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // drawPie(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPie_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPie(QRect,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawPie(QRect,int,int)
                cppSelf->QPainter::drawPie(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawPie(QRectF,int,int)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawPie(QRectF,int,int)
                cppSelf->QPainter::drawPie(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // drawPie(int,int,int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // drawPie(int,int,int,int,int,int)
                cppSelf->QPainter::drawPie(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPie_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, int", "PySide.QtCore.QRectF, int, int", "int, int, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPie", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPixmap(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 6 || numArgs == 8)
        goto SbkQPainterFunc_drawPixmap_TypeError;

    if (!PyArg_UnpackTuple(args, "drawPixmap", 2, 9, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return 0;


    // Overloaded function decisor
    // 0: drawPixmap(QPoint,QPixmap)
    // 1: drawPixmap(QPoint,QPixmap,QRect)
    // 2: drawPixmap(QPointF,QPixmap)
    // 3: drawPixmap(QPointF,QPixmap,QRectF)
    // 4: drawPixmap(QRect,QPixmap)
    // 5: drawPixmap(QRect,QPixmap,QRect)
    // 6: drawPixmap(QRectF,QPixmap,QRectF)
    // 7: drawPixmap(int,int,QPixmap)
    // 8: drawPixmap(int,int,QPixmap,int,int,int,int)
    // 9: drawPixmap(int,int,int,int,QPixmap)
    // 10: drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs >= 5 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 9; // drawPixmap(int,int,int,int,QPixmap)
            } else if (numArgs == 9 && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6]) && SbkNumber_Check(pyargs[7]) && SbkNumber_Check(pyargs[8])) {
                overloadId = 10; // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
            }
        } else if (Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 7; // drawPixmap(int,int,QPixmap)
            } else if (numArgs == 7 && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5]) && SbkNumber_Check(pyargs[6])) {
                overloadId = 8; // drawPixmap(int,int,QPixmap,int,int,int,int)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 4; // drawPixmap(QRect,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            overloadId = 5; // drawPixmap(QRect,QPixmap,QRect)
        }
    } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1]) && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
        overloadId = 6; // drawPixmap(QRectF,QPixmap,QRectF)
    } else if (numArgs >= 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawPixmap(QPoint,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            overloadId = 1; // drawPixmap(QPoint,QPixmap,QRect)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // drawPixmap(QPointF,QPixmap)
        } else if (numArgs == 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[2])) {
            overloadId = 3; // drawPixmap(QPointF,QPixmap,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPixmap(QPoint,QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // drawPixmap(QPoint,QPixmap)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // drawPixmap(QPoint,QPixmap,QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawPixmap(QPoint,QPixmap,QRect)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 2: // drawPixmap(QPointF,QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // drawPixmap(QPointF,QPixmap)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 3: // drawPixmap(QPointF,QPixmap,QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
                QRectF* cpp_arg2 = Shiboken::Converter<QRectF* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // drawPixmap(QPointF,QPixmap,QRectF)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 4: // drawPixmap(QRect,QPixmap)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // drawPixmap(QRect,QPixmap)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 5: // drawPixmap(QRect,QPixmap,QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawPixmap(QRect,QPixmap,QRect)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 6: // drawPixmap(QRectF,QPixmap,QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg2_auto_ptr;
                QRectF* cpp_arg2 = Shiboken::Converter<QRectF* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRectF >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // drawPixmap(QRectF,QPixmap,QRectF)
                cppSelf->QPainter::drawPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 7: // drawPixmap(int,int,QPixmap)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg2_auto_ptr;
                QPixmap* cpp_arg2 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // drawPixmap(int,int,QPixmap)
                cppSelf->QPainter::drawPixmap(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 8: // drawPixmap(int,int,QPixmap,int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg2_auto_ptr;
                QPixmap* cpp_arg2 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[2]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg2);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);
                int cpp_arg6 = Shiboken::Converter<int >::toCpp(pyargs[6]);

                if(!PyErr_Occurred()) {
                // drawPixmap(int,int,QPixmap,int,int,int,int)
                cppSelf->QPainter::drawPixmap(cpp_arg0, cpp_arg1, *cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6);
                }
                break;
            }
            case 9: // drawPixmap(int,int,int,int,QPixmap)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg4_auto_ptr;
                QPixmap* cpp_arg4 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[4]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // drawPixmap(int,int,int,int,QPixmap)
                cppSelf->QPainter::drawPixmap(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                }
                break;
            }
            case 10: // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg4_auto_ptr;
                QPixmap* cpp_arg4 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[4]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg4);
                int cpp_arg5 = Shiboken::Converter<int >::toCpp(pyargs[5]);
                int cpp_arg6 = Shiboken::Converter<int >::toCpp(pyargs[6]);
                int cpp_arg7 = Shiboken::Converter<int >::toCpp(pyargs[7]);
                int cpp_arg8 = Shiboken::Converter<int >::toCpp(pyargs[8]);

                if(!PyErr_Occurred()) {
                // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
                cppSelf->QPainter::drawPixmap(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4, cpp_arg5, cpp_arg6, cpp_arg7, cpp_arg8);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QPixmap", "PySide.QtCore.QPoint, PySide.QtGui.QPixmap, PySide.QtCore.QRect", "PySide.QtCore.QPointF, PySide.QtGui.QPixmap", "PySide.QtCore.QPointF, PySide.QtGui.QPixmap, PySide.QtCore.QRectF", "PySide.QtCore.QRect, PySide.QtGui.QPixmap", "PySide.QtCore.QRect, PySide.QtGui.QPixmap, PySide.QtCore.QRect", "PySide.QtCore.QRectF, PySide.QtGui.QPixmap, PySide.QtCore.QRectF", "int, int, PySide.QtGui.QPixmap", "int, int, PySide.QtGui.QPixmap, int, int, int, int", "int, int, int, int, PySide.QtGui.QPixmap", "int, int, int, int, PySide.QtGui.QPixmap, int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPixmap", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPoint(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawPoint", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPoint(QPoint)
    // 1: drawPoint(QPointF)
    // 2: drawPoint(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // drawPoint(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawPoint(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPoint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPoint(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // drawPoint(QPoint)
                cppSelf->QPainter::drawPoint(*cpp_arg0);
                }
                break;
            }
            case 1: // drawPoint(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawPoint(QPointF)
                cppSelf->QPainter::drawPoint(*cpp_arg0);
                }
                break;
            }
            case 2: // drawPoint(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawPoint(int,int)
                cppSelf->QPainter::drawPoint(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPoint", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPoints(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPoints(QPolygon)
    // 1: drawPoints(QPolygonF)
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // drawPoints(QPolygon)
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 1; // drawPoints(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPoints_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPoints(QPolygon)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawPoints(QPolygon)
                cppSelf->QPainter::drawPoints(*cpp_arg0);
                }
                break;
            }
            case 1: // drawPoints(QPolygonF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawPoints(QPolygonF)
                cppSelf->QPainter::drawPoints(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPoints_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPoints", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPolygon(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "fillRule" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:drawPolygon", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawPolygon(QPolygon,Qt::FillRule)
    // 1: drawPolygon(QPolygonF,Qt::FillRule)
    if (Shiboken::Converter<const QPolygon & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // drawPolygon(QPolygon,Qt::FillRule)
        } else if (Shiboken::Converter<Qt::FillRule >::isConvertible(pyargs[1])) {
            overloadId = 0; // drawPolygon(QPolygon,Qt::FillRule)
        }
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // drawPolygon(QPolygonF,Qt::FillRule)
        } else if (Shiboken::Converter<Qt::FillRule >::isConvertible(pyargs[1])) {
            overloadId = 1; // drawPolygon(QPolygonF,Qt::FillRule)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPolygon_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPolygon(QPolygon,Qt::FillRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillRule");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fillRule";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygon >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);
                Qt::FillRule cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]) : Qt::OddEvenFill;

                if(!PyErr_Occurred()) {
                // drawPolygon(QPolygon,Qt::FillRule)
                cppSelf->QPainter::drawPolygon(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // drawPolygon(QPolygonF,Qt::FillRule)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "fillRule");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "fillRule";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPolygonF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);
                Qt::FillRule cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]) : Qt::OddEvenFill;

                if(!PyErr_Occurred()) {
                // drawPolygon(QPolygonF,Qt::FillRule)
                cppSelf->QPainter::drawPolygon(*cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPolygon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon, PySide.QtCore.Qt.FillRule = Qt.OddEvenFill", "PySide.QtGui.QPolygonF, PySide.QtCore.Qt.FillRule = Qt.OddEvenFill", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawPolygon", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawPolyline(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawPolyline(QPolygon)
    // 1: drawPolyline(QPolygonF)
    if (Shiboken::Converter<const QPolygon & >::isConvertible(arg)) {
        overloadId = 0; // drawPolyline(QPolygon)
    } else if (Shiboken::Converter<const QPolygonF & >::isConvertible(arg)) {
        overloadId = 1; // drawPolyline(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawPolyline_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawPolyline(QPolygon)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygon > cpp_arg0_auto_ptr;
                QPolygon* cpp_arg0 = Shiboken::Converter<QPolygon* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygon >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygon >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawPolyline(QPolygon)
                cppSelf->QPainter::drawPolyline(*cpp_arg0);
                }
                break;
            }
            case 1: // drawPolyline(QPolygonF)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPolygonF > cpp_arg0_auto_ptr;
                QPolygonF* cpp_arg0 = Shiboken::Converter<QPolygonF* >::toCpp(arg);
                if (!Shiboken::Converter<QPolygonF >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPolygonF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawPolyline(QPolygonF)
                cppSelf->QPainter::drawPolyline(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawPolyline_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawPolyline", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQPainterFunc_drawRect_TypeError;

    if (!PyArg_UnpackTuple(args, "drawRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawRect(QRect)
    // 1: drawRect(QRectF)
    // 2: drawRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // drawRect(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // drawRect(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // drawRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRect(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // drawRect(QRect)
                cppSelf->QPainter::drawRect(*cpp_arg0);
                }
                break;
            }
            case 1: // drawRect(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // drawRect(QRectF)
                cppSelf->QPainter::drawRect(*cpp_arg0);
                }
                break;
            }
            case 2: // drawRect(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // drawRect(int,int,int,int)
                cppSelf->QPainter::drawRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawRects(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawRects(QVector<QRect>)
    // 1: drawRects(QVector<QRectF>)
    if (Shiboken::Converter< QVector<QRect >  >::isConvertible(arg)) {
        overloadId = 0; // drawRects(QVector<QRect>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawRects_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRects(QVector<QRect>)
            {
                QVector<QRect > cpp_arg0 = Shiboken::Converter<QVector<QRect > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawRects(QVector<QRect>)
                cppSelf->QPainter::drawRects(cpp_arg0);
                }
                break;
            }
            case 1: // drawRects(QVector<QRectF>)
            {
                QVector<QRectF > cpp_arg0 = Shiboken::Converter<QVector<QRectF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // drawRects(QVector<QRectF>)
                cppSelf->QPainter::drawRects(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawRects_TypeError:
        const char* overloads[] = {"list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.drawRects", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawRoundRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "xRound", "xround", "yRound", "yround" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawRoundRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawRoundRect(QRect,int,int)
    // 1: drawRoundRect(QRectF,int,int)
    // 2: drawRoundRect(int,int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
            } else if (SbkNumber_Check(pyargs[5])) {
                overloadId = 2; // drawRoundRect(int,int,int,int,int,int)
            }
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // drawRoundRect(QRect,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // drawRoundRect(QRect,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // drawRoundRect(QRect,int,int)
            }
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // drawRoundRect(QRectF,int,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // drawRoundRect(QRectF,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // drawRoundRect(QRectF,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawRoundRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRoundRect(QRect,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xround");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xround";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "yround");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "yround";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 25;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 25;

                if(!PyErr_Occurred()) {
                // drawRoundRect(QRect,int,int)
                cppSelf->QPainter::drawRoundRect(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 1: // drawRoundRect(QRectF,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xround");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "xround";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "yround");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "yround";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 25;
                int cpp_arg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 25;

                if(!PyErr_Occurred()) {
                // drawRoundRect(QRectF,int,int)
                cppSelf->QPainter::drawRoundRect(*cpp_arg0, cpp_arg1, cpp_arg2);
                }
                break;
            }
            case 2: // drawRoundRect(int,int,int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "xRound");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "xRound";
                        else
                            pyargs[4] = value;
                    }
                    value = PyDict_GetItemString(kwds, "yRound");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "yRound";
                        else
                            pyargs[5] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 25;
                int cpp_arg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 25;

                if(!PyErr_Occurred()) {
                // drawRoundRect(int,int,int,int,int,int)
                cppSelf->QPainter::drawRoundRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawRoundRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int = 25, int = 25", "PySide.QtCore.QRectF, int = 25, int = 25", "int, int, int, int, int = 25, int = 25", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRoundRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawRoundedRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): not enough arguments");
        return 0;
    } else if (numArgs == 5)
        goto SbkQPainterFunc_drawRoundedRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawRoundedRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
    // 1: drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
    // 2: drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
    if (numArgs >= 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter<Qt::SizeMode >::isConvertible(pyargs[6])) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter<Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        } else if (Shiboken::Converter<Qt::SizeMode >::isConvertible(pyargs[3])) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawRoundedRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
                cppSelf->QPainter::drawRoundedRect(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cpp_arg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                Qt::SizeMode cpp_arg3 = pyargs[3] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[3]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
                cppSelf->QPainter::drawRoundedRect(*cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 2: // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else
                            pyargs[6] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawRoundedRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                qreal cpp_arg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cpp_arg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);
                Qt::SizeMode cpp_arg6 = pyargs[6] ? Shiboken::Converter<Qt::SizeMode >::toCpp(pyargs[6]) : Qt::AbsoluteSize;

                if(!PyErr_Occurred()) {
                // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
                cppSelf->QPainter::drawRoundedRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, cpp_arg6);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawRoundedRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "PySide.QtCore.QRectF, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", "int, int, int, int, float, float, PySide.QtCore.Qt.SizeMode = Qt.AbsoluteSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawRoundedRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "o" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): not enough arguments");
        return 0;
    } else if (numArgs == 4 || numArgs == 5)
        goto SbkQPainterFunc_drawText_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOO:drawText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: drawText(QPoint,QString)
    // 1: drawText(QPointF,QString)
    // 2: drawText(QRect,int,QString,QRect*)
    // 3: drawText(QRectF,QString,QTextOption)
    // 4: drawText(QRectF,int,QString,QRectF*)
    // 5: drawText(int,int,QString)
    // 6: drawText(int,int,int,int,int,QString,QRect*)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 6 && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter<QString >::isConvertible(pyargs[5])) {
            overloadId = 6; // drawText(int,int,int,int,int,QString,QRect*)
        } else if (numArgs == 3 && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 5; // drawText(int,int,QString)
        }
    } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawText(QRect,int,QString,QRect*)
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter<QString >::isConvertible(pyargs[2])) {
            overloadId = 4; // drawText(QRectF,int,QString,QRectF*)
        } else if (Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            } else if (Shiboken::Converter<const QTextOption & >::isConvertible(pyargs[2])) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            }
        }
    } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawText(QPoint,QString)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter<QString >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawText(QPointF,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawText(QPoint,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawText(QPoint,QString)
                cppSelf->QPainter::drawText(*cpp_arg0, cpp_arg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // drawText(QPointF,QString)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawText(QPointF,QString)
                cppSelf->QPainter::drawText(*cpp_arg0, cpp_arg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // drawText(QRect,int,QString,QRect*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawText(QRect,int,QString,QRect*)
                // Begin code injection
                
                // TEMPLATE - fix_args,QRect* - START
                QRect rect_;
                cppSelf->drawText(*cpp_arg0, cpp_arg1, cpp_arg2, &rect_);
                pyResult = Shiboken::Converter<QRect >::toPython(rect_);
                // TEMPLATE - fix_args,QRect* - END
                
                // End of code injection


                }
                break;
            }
            case 3: // drawText(QRectF,QString,QTextOption)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "o");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "o";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawText(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                QString cpp_arg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QTextOption > cpp_arg2_auto_ptr;
                QTextOption cpp_arg2_tmp = QTextOption();
                QTextOption* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QTextOption* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QTextOption >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QTextOption >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // drawText(QRectF,QString,QTextOption)
                cppSelf->QPainter::drawText(*cpp_arg0, cpp_arg1, *cpp_arg2);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 4: // drawText(QRectF,int,QString,QRectF*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawText(QRectF,int,QString,QRectF*)
                // Begin code injection
                
                // TEMPLATE - fix_args,QRectF* - START
                QRectF rect_;
                cppSelf->drawText(*cpp_arg0, cpp_arg1, cpp_arg2, &rect_);
                pyResult = Shiboken::Converter<QRectF >::toPython(rect_);
                // TEMPLATE - fix_args,QRectF* - END
                
                // End of code injection


                }
                break;
            }
            case 5: // drawText(int,int,QString)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QString cpp_arg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawText(int,int,QString)
                cppSelf->QPainter::drawText(cpp_arg0, cpp_arg1, cpp_arg2);
                pyResult = Py_None;
                Py_INCREF(Py_None);
                }
                break;
            }
            case 6: // drawText(int,int,int,int,int,QString,QRect*)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cpp_arg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QString cpp_arg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                // drawText(int,int,int,int,int,QString,QRect*)
                // Begin code injection
                
                // TEMPLATE - fix_args,QRect* - START
                QRect rect_;
                cppSelf->drawText(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4, cpp_arg5, &rect_);
                pyResult = Shiboken::Converter<QRect >::toPython(rect_);
                // TEMPLATE - fix_args,QRect* - END
                
                // End of code injection


                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterFunc_drawText_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, QString", "PySide.QtCore.QPointF, QString", "PySide.QtCore.QRect, int, QString, PySide.QtCore.QRect", "PySide.QtCore.QRectF, QString, PySide.QtGui.QTextOption = QTextOption()", "PySide.QtCore.QRectF, int, QString, PySide.QtCore.QRectF", "int, int, QString", "int, int, int, int, int, QString, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawText", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawTextItem(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawTextItem", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTextItem(QPoint,QTextItem)
    // 1: drawTextItem(QPointF,QTextItem)
    // 2: drawTextItem(int,int,QTextItem)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QTextItem & >::isConvertible(pyargs[2])) {
        overloadId = 2; // drawTextItem(int,int,QTextItem)
    } else if (numArgs == 2 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0]) && Shiboken::Converter< QTextItem & >::isConvertible(pyargs[1])) {
        overloadId = 0; // drawTextItem(QPoint,QTextItem)
    } else if (numArgs == 2 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0]) && Shiboken::Converter< QTextItem & >::isConvertible(pyargs[1])) {
        overloadId = 1; // drawTextItem(QPointF,QTextItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawTextItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTextItem(QPoint,QTextItem)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextItem* cpp_arg1 = Shiboken::Converter<QTextItem* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawTextItem(QPoint,QTextItem)
                cppSelf->QPainter::drawTextItem(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // drawTextItem(QPointF,QTextItem)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QTextItem* cpp_arg1 = Shiboken::Converter<QTextItem* >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // drawTextItem(QPointF,QTextItem)
                cppSelf->QPainter::drawTextItem(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // drawTextItem(int,int,QTextItem)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QTextItem* cpp_arg2 = Shiboken::Converter<QTextItem* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // drawTextItem(int,int,QTextItem)
                cppSelf->QPainter::drawTextItem(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawTextItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtGui.QTextItem", "PySide.QtCore.QPointF, PySide.QtGui.QTextItem", "int, int, PySide.QtGui.QTextItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawTextItem", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_drawTiledPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "offset", "pos", "sx", "sy" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 4, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): not enough arguments");
        return 0;
    } else if (numArgs == 4)
        goto SbkQPainterFunc_drawTiledPixmap_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawTiledPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawTiledPixmap(QRect,QPixmap,QPoint)
    // 1: drawTiledPixmap(QRectF,QPixmap,QPointF)
    // 2: drawTiledPixmap(int,int,int,int,QPixmap,int,int)
    if (numArgs >= 5 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[4])) {
        if (numArgs == 5) {
            overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
        } else if (SbkNumber_Check(pyargs[5])) {
            if (numArgs == 6) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            } else if (SbkNumber_Check(pyargs[6])) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        } else if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[2])) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPixmap & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        } else if (Shiboken::Converter<const QPointF & >::isConvertible(pyargs[2])) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_drawTiledPixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTiledPixmap(QRect,QPixmap,QPoint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "pos");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "pos";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QPoint cpp_arg2_tmp = QPoint();
                QPoint* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QPoint* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

                if(!PyErr_Occurred()) {
                // drawTiledPixmap(QRect,QPixmap,QPoint)
                cppSelf->QPainter::drawTiledPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 1: // drawTiledPixmap(QRectF,QPixmap,QPointF)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "offset");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "offset";
                        else
                            pyargs[2] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg1_auto_ptr;
                QPixmap* cpp_arg1 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg1);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg2_auto_ptr;
                QPointF cpp_arg2_tmp = QPointF();
                QPointF* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QPointF* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QPointF >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QPointF >(cpp_arg2);

                if(!PyErr_Occurred()) {
                // drawTiledPixmap(QRectF,QPixmap,QPointF)
                cppSelf->QPainter::drawTiledPixmap(*cpp_arg0, *cpp_arg1, *cpp_arg2);
                }
                break;
            }
            case 2: // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sx");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "sx";
                        else
                            pyargs[5] = value;
                    }
                    value = PyDict_GetItemString(kwds, "sy");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "sy";
                        else
                            pyargs[6] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.drawTiledPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QPixmap > cpp_arg4_auto_ptr;
                QPixmap* cpp_arg4 = Shiboken::Converter<QPixmap* >::toCpp(pyargs[4]);
                if (!Shiboken::Converter<QPixmap >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QPixmap >(cpp_arg4);
                int cpp_arg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 0;
                int cpp_arg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 0;

                if(!PyErr_Occurred()) {
                // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
                cppSelf->QPainter::drawTiledPixmap(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4, cpp_arg5, cpp_arg6);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_drawTiledPixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QPixmap, PySide.QtCore.QPoint = QPoint()", "PySide.QtCore.QRectF, PySide.QtGui.QPixmap, PySide.QtCore.QPointF = QPointF()", "int, int, int, int, PySide.QtGui.QPixmap, int = 0, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.drawTiledPixmap", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_end(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // end()
            bool cppResult = cppSelf->QPainter::end();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_endNativePainting(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // endNativePainting()
            cppSelf->QPainter::endNativePainting();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_eraseRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQPainterFunc_eraseRect_TypeError;

    if (!PyArg_UnpackTuple(args, "eraseRect", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: eraseRect(QRect)
    // 1: eraseRect(QRectF)
    // 2: eraseRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 2; // eraseRect(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // eraseRect(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // eraseRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_eraseRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // eraseRect(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // eraseRect(QRect)
                cppSelf->QPainter::eraseRect(*cpp_arg0);
                }
                break;
            }
            case 1: // eraseRect(QRectF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // eraseRect(QRectF)
                cppSelf->QPainter::eraseRect(*cpp_arg0);
                }
                break;
            }
            case 2: // eraseRect(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // eraseRect(int,int,int,int)
                cppSelf->QPainter::eraseRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_eraseRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.eraseRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_fillPath(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fillPath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fillPath(QPainterPath,QBrush)
    if (numArgs == 2 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[1])) {
        overloadId = 0; // fillPath(QPainterPath,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_fillPath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QBrush > cpp_arg1_auto_ptr;
            QBrush* cpp_arg1 = Shiboken::Converter<QBrush* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QBrush >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QBrush >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // fillPath(QPainterPath,QBrush)
            cppSelf->QPainter::fillPath(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_fillPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.fillPath", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_fillRect(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        goto SbkQPainterFunc_fillRect_TypeError;

    if (!PyArg_UnpackTuple(args, "fillRect", 2, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fillRect(QRect,QBrush)
    // 1: fillRect(QRect,QColor)
    // 2: fillRect(QRect,Qt::BrushStyle)
    // 3: fillRect(QRect,Qt::GlobalColor)
    // 4: fillRect(QRectF,QBrush)
    // 5: fillRect(QRectF,QColor)
    // 6: fillRect(QRectF,Qt::BrushStyle)
    // 7: fillRect(QRectF,Qt::GlobalColor)
    // 8: fillRect(int,int,int,int,Qt::BrushStyle)
    // 9: fillRect(int,int,int,int,Qt::GlobalColor)
    // 10: fillRect(int,int,int,int,QBrush)
    // 11: fillRect(int,int,int,int,QColor)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 5 && Shiboken::Converter<Qt::GlobalColor >::isConvertible(pyargs[4])) {
            overloadId = 9; // fillRect(int,int,int,int,Qt::GlobalColor)
        } else if (numArgs == 5 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[4])) {
            overloadId = 11; // fillRect(int,int,int,int,QColor)
        } else if (numArgs == 5 && Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[4])) {
            overloadId = 8; // fillRect(int,int,int,int,Qt::BrushStyle)
        } else if (numArgs == 5 && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[4])) {
            overloadId = 10; // fillRect(int,int,int,int,QBrush)
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<Qt::GlobalColor >::isConvertible(pyargs[1])) {
            overloadId = 3; // fillRect(QRect,Qt::GlobalColor)
        } else if (numArgs == 2 && Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 2; // fillRect(QRect,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 1; // fillRect(QRect,QColor)
        } else if (numArgs == 2 && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[1])) {
            overloadId = 0; // fillRect(QRect,QBrush)
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter<Qt::GlobalColor >::isConvertible(pyargs[1])) {
            overloadId = 7; // fillRect(QRectF,Qt::GlobalColor)
        } else if (numArgs == 2 && Shiboken::Converter<Qt::BrushStyle >::isConvertible(pyargs[1])) {
            overloadId = 6; // fillRect(QRectF,Qt::BrushStyle)
        } else if (numArgs == 2 && Shiboken::Converter<const QColor & >::isConvertible(pyargs[1])) {
            overloadId = 5; // fillRect(QRectF,QColor)
        } else if (numArgs == 2 && Shiboken::Converter<const QBrush & >::isConvertible(pyargs[1])) {
            overloadId = 4; // fillRect(QRectF,QBrush)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_fillRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fillRect(QRect,QBrush)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg1_auto_ptr;
                QBrush* cpp_arg1 = Shiboken::Converter<QBrush* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QBrush >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QBrush >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // fillRect(QRect,QBrush)
                cppSelf->QPainter::fillRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 1: // fillRect(QRect,QColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // fillRect(QRect,QColor)
                cppSelf->QPainter::fillRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 2: // fillRect(QRect,Qt::BrushStyle)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                Qt::BrushStyle cpp_arg1 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fillRect(QRect,Qt::BrushStyle)
                cppSelf->QPainter::fillRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 3: // fillRect(QRect,Qt::GlobalColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                Qt::GlobalColor cpp_arg1 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fillRect(QRect,Qt::GlobalColor)
                cppSelf->QPainter::fillRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 4: // fillRect(QRectF,QBrush)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg1_auto_ptr;
                QBrush* cpp_arg1 = Shiboken::Converter<QBrush* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QBrush >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QBrush >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // fillRect(QRectF,QBrush)
                cppSelf->QPainter::fillRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 5: // fillRect(QRectF,QColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg1_auto_ptr;
                QColor* cpp_arg1 = Shiboken::Converter<QColor* >::toCpp(pyargs[1]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[1]))
                    cpp_arg1_auto_ptr = std::auto_ptr<QColor >(cpp_arg1);

                if(!PyErr_Occurred()) {
                // fillRect(QRectF,QColor)
                cppSelf->QPainter::fillRect(*cpp_arg0, *cpp_arg1);
                }
                break;
            }
            case 6: // fillRect(QRectF,Qt::BrushStyle)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::BrushStyle cpp_arg1 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fillRect(QRectF,Qt::BrushStyle)
                cppSelf->QPainter::fillRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 7: // fillRect(QRectF,Qt::GlobalColor)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::GlobalColor cpp_arg1 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // fillRect(QRectF,Qt::GlobalColor)
                cppSelf->QPainter::fillRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 8: // fillRect(int,int,int,int,Qt::BrushStyle)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::BrushStyle cpp_arg4 = Shiboken::Converter<Qt::BrushStyle >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // fillRect(int,int,int,int,Qt::BrushStyle)
                cppSelf->QPainter::fillRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 9: // fillRect(int,int,int,int,Qt::GlobalColor)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::GlobalColor cpp_arg4 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                // fillRect(int,int,int,int,Qt::GlobalColor)
                cppSelf->QPainter::fillRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
            case 10: // fillRect(int,int,int,int,QBrush)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg4_auto_ptr;
                QBrush* cpp_arg4 = Shiboken::Converter<QBrush* >::toCpp(pyargs[4]);
                if (!Shiboken::Converter<QBrush >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QBrush >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // fillRect(int,int,int,int,QBrush)
                cppSelf->QPainter::fillRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                }
                break;
            }
            case 11: // fillRect(int,int,int,int,QColor)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                if (Shiboken::cppObjectIsInvalid(pyargs[4]))
                    return 0;
                std::auto_ptr<QColor > cpp_arg4_auto_ptr;
                QColor* cpp_arg4 = Shiboken::Converter<QColor* >::toCpp(pyargs[4]);
                if (!Shiboken::Converter<QColor >::checkType(pyargs[4]))
                    cpp_arg4_auto_ptr = std::auto_ptr<QColor >(cpp_arg4);

                if(!PyErr_Occurred()) {
                // fillRect(int,int,int,int,QColor)
                cppSelf->QPainter::fillRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, *cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_fillRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QBrush", "PySide.QtCore.QRect, PySide.QtGui.QColor", "PySide.QtCore.QRect, PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.QRect, PySide.QtCore.Qt.GlobalColor", "PySide.QtCore.QRectF, PySide.QtGui.QBrush", "PySide.QtCore.QRectF, PySide.QtGui.QColor", "PySide.QtCore.QRectF, PySide.QtCore.Qt.BrushStyle", "PySide.QtCore.QRectF, PySide.QtCore.Qt.GlobalColor", "int, int, int, int, PySide.QtCore.Qt.BrushStyle", "int, int, int, int, PySide.QtCore.Qt.GlobalColor", "int, int, int, int, PySide.QtGui.QBrush", "int, int, int, int, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.fillRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_font(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            const QFont & cppResult = cppSelf->QPainter::font();
            pyResult = Shiboken::Converter<const QFont & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_fontMetrics(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontMetrics()const
            QFontMetrics cppResult = cppSelf->QPainter::fontMetrics();
            pyResult = Shiboken::Converter<QFontMetrics >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_hasClipping(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasClipping()const
            bool cppResult = cppSelf->QPainter::hasClipping();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_initFrom(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initFrom(const QWidget*)
    if (Shiboken::Converter<const QWidget * >::isConvertible(arg)) {
        overloadId = 0; // initFrom(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_initFrom_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // initFrom(const QWidget*)
            cppSelf->QPainter::initFrom(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_initFrom_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.initFrom", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_isActive(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActive()const
            bool cppResult = cppSelf->QPainter::isActive();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_layoutDirection(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // layoutDirection()const
            Qt::LayoutDirection cppResult = cppSelf->QPainter::layoutDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_opacity(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // opacity()const
            qreal cppResult = cppSelf->QPainter::opacity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_paintEngine(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintEngine()const
            QPaintEngine * cppResult = cppSelf->QPainter::paintEngine();
            pyResult = Shiboken::Converter<QPaintEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_pen(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pen()const
            const QPen & cppResult = cppSelf->QPainter::pen();
            pyResult = Shiboken::Converter<const QPen & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_renderHints(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // renderHints()const
            QFlags<QPainter::RenderHint> cppResult = cppSelf->QPainter::renderHints();
            pyResult = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_resetMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetMatrix()
            cppSelf->QPainter::resetMatrix();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_resetTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetTransform()
            cppSelf->QPainter::resetTransform();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_restore(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // restore()
            cppSelf->QPainter::restore();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_restoreRedirected(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreRedirected(const QPaintDevice*)
    if (Shiboken::Converter< QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // restoreRedirected(const QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_restoreRedirected_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // restoreRedirected(const QPaintDevice*)
            QPainter::restoreRedirected(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_restoreRedirected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.restoreRedirected", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_rotate(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // rotate(qreal)
            cppSelf->QPainter::rotate(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.rotate", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_save(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // save()
            cppSelf->QPainter::save();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQPainterFunc_scale(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scale(qreal,qreal)
            cppSelf->QPainter::scale(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.scale", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setBackground(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackground(QBrush)
    if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setBackground_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
            QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
            if (!Shiboken::Converter<QBrush >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setBackground(QBrush)
            cppSelf->QPainter::setBackground(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBackground", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setBackgroundMode(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundMode(Qt::BGMode)
    if (Shiboken::Converter<Qt::BGMode >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundMode(Qt::BGMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setBackgroundMode_TypeError;

    // Call function/method
    {
        {
            Qt::BGMode cpp_arg0 = Shiboken::Converter<Qt::BGMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBackgroundMode(Qt::BGMode)
            cppSelf->QPainter::setBackgroundMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setBackgroundMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BGMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBackgroundMode", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setBrush(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBrush(Qt::BrushStyle)
    // 1: setBrush(QBrush)
    if (Shiboken::Converter<Qt::BrushStyle >::isConvertible(arg)) {
        overloadId = 0; // setBrush(Qt::BrushStyle)
    } else if (Shiboken::Converter<const QBrush & >::isConvertible(arg)) {
        overloadId = 1; // setBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setBrush_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBrush(Qt::BrushStyle)
            {
                Qt::BrushStyle cpp_arg0 = Shiboken::Converter<Qt::BrushStyle >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setBrush(Qt::BrushStyle)
                cppSelf->QPainter::setBrush(cpp_arg0);
                }
                break;
            }
            case 1: // setBrush(QBrush)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QBrush > cpp_arg0_auto_ptr;
                QBrush* cpp_arg0 = Shiboken::Converter<QBrush* >::toCpp(arg);
                if (!Shiboken::Converter<QBrush >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QBrush >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setBrush(QBrush)
                cppSelf->QPainter::setBrush(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setBrush_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.BrushStyle", "PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setBrush", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setBrushOrigin(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBrushOrigin", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBrushOrigin(QPoint)
    // 1: setBrushOrigin(QPointF)
    // 2: setBrushOrigin(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // setBrushOrigin(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setBrushOrigin(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // setBrushOrigin(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setBrushOrigin_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBrushOrigin(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setBrushOrigin(QPoint)
                cppSelf->QPainter::setBrushOrigin(*cpp_arg0);
                }
                break;
            }
            case 1: // setBrushOrigin(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setBrushOrigin(QPointF)
                cppSelf->QPainter::setBrushOrigin(*cpp_arg0);
                }
                break;
            }
            case 2: // setBrushOrigin(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setBrushOrigin(int,int)
                cppSelf->QPainter::setBrushOrigin(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setBrushOrigin_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setBrushOrigin", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setClipPath(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "op" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setClipPath", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setClipPath(QPainterPath,Qt::ClipOperation)
    if (Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        } else if (Shiboken::Converter<Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setClipPath_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "op");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "op";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipPath(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
            Qt::ClipOperation cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

            if(!PyErr_Occurred()) {
            // setClipPath(QPainterPath,Qt::ClipOperation)
            cppSelf->QPainter::setClipPath(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setClipPath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipPath", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setClipRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "op" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): not enough arguments");
        return 0;
    } else if (numArgs == 3)
        goto SbkQPainterFunc_setClipRect_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOO:setClipRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setClipRect(QRect,Qt::ClipOperation)
    // 1: setClipRect(QRectF,Qt::ClipOperation)
    // 2: setClipRect(int,int,int,int,Qt::ClipOperation)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        } else if (Shiboken::Converter<Qt::ClipOperation >::isConvertible(pyargs[4])) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        }
    } else if (Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        } else if (Shiboken::Converter<Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        }
    } else if (Shiboken::Converter<const QRectF & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        } else if (Shiboken::Converter<Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setClipRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setClipRect(QRect,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "op";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);
                Qt::ClipOperation cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                // setClipRect(QRect,Qt::ClipOperation)
                cppSelf->QPainter::setClipRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // setClipRect(QRectF,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "op";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRectF > cpp_arg0_auto_ptr;
                QRectF* cpp_arg0 = Shiboken::Converter<QRectF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRectF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRectF >(cpp_arg0);
                Qt::ClipOperation cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                // setClipRect(QRectF,Qt::ClipOperation)
                cppSelf->QPainter::setClipRect(*cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 2: // setClipRect(int,int,int,int,Qt::ClipOperation)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "op");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "op";
                        else
                            pyargs[4] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRect(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                Qt::ClipOperation cpp_arg4 = pyargs[4] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[4]) : Qt::ReplaceClip;

                if(!PyErr_Occurred()) {
                // setClipRect(int,int,int,int,Qt::ClipOperation)
                cppSelf->QPainter::setClipRect(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3, cpp_arg4);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setClipRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", "PySide.QtCore.QRectF, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", "int, int, int, int, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipRect", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setClipRegion(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "op" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setClipRegion", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setClipRegion(QRegion,Qt::ClipOperation)
    if (Shiboken::Converter<const QRegion & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        } else if (Shiboken::Converter<Qt::ClipOperation >::isConvertible(pyargs[1])) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setClipRegion_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "op");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "op";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setClipRegion(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
            QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QRegion >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);
            Qt::ClipOperation cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ClipOperation >::toCpp(pyargs[1]) : Qt::ReplaceClip;

            if(!PyErr_Occurred()) {
            // setClipRegion(QRegion,Qt::ClipOperation)
            cppSelf->QPainter::setClipRegion(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setClipRegion_TypeError:
        const char* overloads[] = {"PySide.QtGui.QRegion, PySide.QtCore.Qt.ClipOperation = Qt.ReplaceClip", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setClipRegion", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setClipping(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClipping(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setClipping(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setClipping_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setClipping(bool)
            cppSelf->QPainter::setClipping(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setClipping_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setClipping", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setCompositionMode(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCompositionMode(QPainter::CompositionMode)
    if (Shiboken::Converter<QPainter::CompositionMode >::isConvertible(arg)) {
        overloadId = 0; // setCompositionMode(QPainter::CompositionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setCompositionMode_TypeError;

    // Call function/method
    {
        {
            QPainter::CompositionMode cpp_arg0 = Shiboken::Converter<QPainter::CompositionMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCompositionMode(QPainter::CompositionMode)
            cppSelf->QPainter::setCompositionMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setCompositionMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.CompositionMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setCompositionMode", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setFont(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            cppSelf->QPainter::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setFont", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter<Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cpp_arg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLayoutDirection(Qt::LayoutDirection)
            cppSelf->QPainter::setLayoutDirection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setLayoutDirection", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setOpacity(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOpacity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setOpacity_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOpacity(qreal)
            cppSelf->QPainter::setOpacity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setOpacity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setOpacity", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setPen(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPen(Qt::PenStyle)
    // 1: setPen(QColor)
    // 2: setPen(QPen)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 1; // setPen(QColor)
    } else if (Shiboken::Converter<Qt::PenStyle >::isConvertible(arg)) {
        overloadId = 0; // setPen(Qt::PenStyle)
    } else if (Shiboken::Converter<const QPen & >::isConvertible(arg)) {
        overloadId = 2; // setPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setPen_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPen(Qt::PenStyle)
            {
                Qt::PenStyle cpp_arg0 = Shiboken::Converter<Qt::PenStyle >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setPen(Qt::PenStyle)
                cppSelf->QPainter::setPen(cpp_arg0);
                }
                break;
            }
            case 1: // setPen(QColor)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QColor > cpp_arg0_auto_ptr;
                QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
                if (!Shiboken::Converter<QColor >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setPen(QColor)
                cppSelf->QPainter::setPen(*cpp_arg0);
                }
                break;
            }
            case 2: // setPen(QPen)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QPen > cpp_arg0_auto_ptr;
                QPen* cpp_arg0 = Shiboken::Converter<QPen* >::toCpp(arg);
                if (!Shiboken::Converter<QPen >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPen >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setPen(QPen)
                cppSelf->QPainter::setPen(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setPen_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.PenStyle", "PySide.QtGui.QColor", "PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setPen", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setRedirected(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "offset" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setRedirected", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
    if (numArgs >= 2 && Shiboken::Converter< QPaintDevice * >::isConvertible(pyargs[0]) && Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
        } else if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[2])) {
            overloadId = 0; // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setRedirected_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "offset";
                    else
                        pyargs[2] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRedirected(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QPaintDevice* cpp_arg1 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[1]);
            if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                return 0;
            QPoint cpp_arg2_tmp = QPoint();
            QPoint* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QPoint* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;

            if(!PyErr_Occurred()) {
            // setRedirected(const QPaintDevice*,QPaintDevice*,QPoint)
            QPainter::setRedirected(cpp_arg0, cpp_arg1, *cpp_arg2);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setRedirected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtGui.QPaintDevice, PySide.QtCore.QPoint = QPoint()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRedirected", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setRenderHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "on" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHint", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHint(QPainter::RenderHint,bool)
    if (Shiboken::Converter<QPainter::RenderHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setRenderHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QPainter::RenderHint cpp_arg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setRenderHint(QPainter::RenderHint,bool)
            cppSelf->QPainter::setRenderHint(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRenderHint", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setRenderHints(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "on" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setRenderHints", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRenderHints(QFlags<QPainter::RenderHint>,bool)
    if (Shiboken::Converter<QFlags<QPainter::RenderHint> >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setRenderHints_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setRenderHints(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QPainter::RenderHint> cpp_arg0 = Shiboken::Converter<QFlags<QPainter::RenderHint> >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setRenderHints(QFlags<QPainter::RenderHint>,bool)
            cppSelf->QPainter::setRenderHints(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setRenderHints_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHints, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setRenderHints", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTransform(QTransform,bool)
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setTransform(QTransform,bool)
            cppSelf->QPainter::setTransform(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setTransform", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setViewTransformEnabled(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewTransformEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setViewTransformEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setViewTransformEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setViewTransformEnabled(bool)
            cppSelf->QPainter::setViewTransformEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setViewTransformEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setViewTransformEnabled", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setViewport(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQPainterFunc_setViewport_TypeError;

    if (!PyArg_UnpackTuple(args, "setViewport", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setViewport(QRect)
    // 1: setViewport(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setViewport(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setViewport(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setViewport_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setViewport(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setViewport(QRect)
                cppSelf->QPainter::setViewport(*cpp_arg0);
                }
                break;
            }
            case 1: // setViewport(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setViewport(int,int,int,int)
                cppSelf->QPainter::setViewport(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setViewport_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setViewport", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setWindow(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQPainterFunc_setWindow_TypeError;

    if (!PyArg_UnpackTuple(args, "setWindow", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setWindow(QRect)
    // 1: setWindow(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setWindow(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setWindow(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setWindow_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setWindow(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setWindow(QRect)
                cppSelf->QPainter::setWindow(*cpp_arg0);
                }
                break;
            }
            case 1: // setWindow(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setWindow(int,int,int,int)
                cppSelf->QPainter::setWindow(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setWindow_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWindow", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setWorldMatrix(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setWorldMatrix", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWorldMatrix(QMatrix,bool)
    if (Shiboken::Converter<const QMatrix & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setWorldMatrix(QMatrix,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setWorldMatrix(QMatrix,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setWorldMatrix_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldMatrix(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QMatrix* cpp_arg0 = Shiboken::Converter<QMatrix* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setWorldMatrix(QMatrix,bool)
            cppSelf->QPainter::setWorldMatrix(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setWorldMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWorldMatrix", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setWorldMatrixEnabled(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorldMatrixEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWorldMatrixEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setWorldMatrixEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWorldMatrixEnabled(bool)
            cppSelf->QPainter::setWorldMatrixEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setWorldMatrixEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.setWorldMatrixEnabled", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_setWorldTransform(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "combine" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setWorldTransform", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWorldTransform(QTransform,bool)
    if (Shiboken::Converter<const QTransform & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_setWorldTransform_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "combine");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "combine";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPainter.setWorldTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QTransform* cpp_arg0 = Shiboken::Converter<QTransform* >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
            // setWorldTransform(QTransform,bool)
            cppSelf->QPainter::setWorldTransform(*cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_setWorldTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.setWorldTransform", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_shear(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            cppSelf->QPainter::shear(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.shear", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_strokePath(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "strokePath", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: strokePath(QPainterPath,QPen)
    if (numArgs == 2 && Shiboken::Converter<const QPainterPath & >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPen & >::isConvertible(pyargs[1])) {
        overloadId = 0; // strokePath(QPainterPath,QPen)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_strokePath_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QPainterPath* cpp_arg0 = Shiboken::Converter<QPainterPath* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QPen > cpp_arg1_auto_ptr;
            QPen* cpp_arg1 = Shiboken::Converter<QPen* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QPen >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QPen >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // strokePath(QPainterPath,QPen)
            cppSelf->QPainter::strokePath(*cpp_arg0, *cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_strokePath_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainterPath, PySide.QtGui.QPen", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.strokePath", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_testRenderHint(PyObject* self, PyObject* arg)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testRenderHint(QPainter::RenderHint)const
    if (Shiboken::Converter<QPainter::RenderHint >::isConvertible(arg)) {
        overloadId = 0; // testRenderHint(QPainter::RenderHint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_testRenderHint_TypeError;

    // Call function/method
    {
        {
            QPainter::RenderHint cpp_arg0 = Shiboken::Converter<QPainter::RenderHint >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // testRenderHint(QPainter::RenderHint)const
            bool cppResult = cppSelf->QPainter::testRenderHint(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQPainterFunc_testRenderHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter.RenderHint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPainter.testRenderHint", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_transform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // transform()const
            const QTransform & cppResult = cppSelf->QPainter::transform();
            pyResult = Shiboken::Converter<const QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_translate(PyObject* self, PyObject* args)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(QPointF)
    // 2: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 2; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter<const QPointF & >::isConvertible(pyargs[0])) {
        overloadId = 1; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQPainterFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // translate(QPoint)
                cppSelf->QPainter::translate(*cpp_arg0);
                }
                break;
            }
            case 1: // translate(QPointF)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QPointF > cpp_arg0_auto_ptr;
                QPointF* cpp_arg0 = Shiboken::Converter<QPointF* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QPointF >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QPointF >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // translate(QPointF)
                cppSelf->QPainter::translate(*cpp_arg0);
                }
                break;
            }
            case 2: // translate(qreal,qreal)
            {
                qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cpp_arg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                cppSelf->QPainter::translate(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQPainterFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPainter.translate", overloads);
        return 0;
}

static PyObject* SbkQPainterFunc_viewTransformEnabled(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewTransformEnabled()const
            bool cppResult = cppSelf->QPainter::viewTransformEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_viewport(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // viewport()const
            QRect cppResult = cppSelf->QPainter::viewport();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_window(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // window()const
            QRect cppResult = cppSelf->QPainter::window();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_worldMatrix(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // worldMatrix()const
            const QMatrix & cppResult = cppSelf->QPainter::worldMatrix();
            pyResult = Shiboken::Converter<const QMatrix & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_worldMatrixEnabled(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // worldMatrixEnabled()const
            bool cppResult = cppSelf->QPainter::worldMatrixEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQPainterFunc_worldTransform(PyObject* self)
{
    QPainter* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QPainter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // worldTransform()const
            const QTransform & cppResult = cppSelf->QPainter::worldTransform();
            pyResult = Shiboken::Converter<const QTransform & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQPainter_methods[] = {
    {"background", (PyCFunction)SbkQPainterFunc_background, METH_NOARGS},
    {"backgroundMode", (PyCFunction)SbkQPainterFunc_backgroundMode, METH_NOARGS},
    {"begin", (PyCFunction)SbkQPainterFunc_begin, METH_O},
    {"beginNativePainting", (PyCFunction)SbkQPainterFunc_beginNativePainting, METH_NOARGS},
    {"boundingRect", (PyCFunction)SbkQPainterFunc_boundingRect, METH_VARARGS|METH_KEYWORDS},
    {"brush", (PyCFunction)SbkQPainterFunc_brush, METH_NOARGS},
    {"brushOrigin", (PyCFunction)SbkQPainterFunc_brushOrigin, METH_NOARGS},
    {"clipPath", (PyCFunction)SbkQPainterFunc_clipPath, METH_NOARGS},
    {"clipRegion", (PyCFunction)SbkQPainterFunc_clipRegion, METH_NOARGS},
    {"combinedMatrix", (PyCFunction)SbkQPainterFunc_combinedMatrix, METH_NOARGS},
    {"combinedTransform", (PyCFunction)SbkQPainterFunc_combinedTransform, METH_NOARGS},
    {"compositionMode", (PyCFunction)SbkQPainterFunc_compositionMode, METH_NOARGS},
    {"device", (PyCFunction)SbkQPainterFunc_device, METH_NOARGS},
    {"deviceMatrix", (PyCFunction)SbkQPainterFunc_deviceMatrix, METH_NOARGS},
    {"deviceTransform", (PyCFunction)SbkQPainterFunc_deviceTransform, METH_NOARGS},
    {"drawArc", (PyCFunction)SbkQPainterFunc_drawArc, METH_VARARGS},
    {"drawChord", (PyCFunction)SbkQPainterFunc_drawChord, METH_VARARGS},
    {"drawConvexPolygon", (PyCFunction)SbkQPainterFunc_drawConvexPolygon, METH_O},
    {"drawEllipse", (PyCFunction)SbkQPainterFunc_drawEllipse, METH_VARARGS},
    {"drawImage", (PyCFunction)SbkQPainterFunc_drawImage, METH_VARARGS|METH_KEYWORDS},
    {"drawLine", (PyCFunction)SbkQPainterFunc_drawLine, METH_VARARGS},
    {"drawLines", (PyCFunction)SbkQPainterFunc_drawLines, METH_O},
    {"drawPath", (PyCFunction)SbkQPainterFunc_drawPath, METH_O},
    {"drawPicture", (PyCFunction)SbkQPainterFunc_drawPicture, METH_VARARGS},
    {"drawPie", (PyCFunction)SbkQPainterFunc_drawPie, METH_VARARGS},
    {"drawPixmap", (PyCFunction)SbkQPainterFunc_drawPixmap, METH_VARARGS},
    {"drawPoint", (PyCFunction)SbkQPainterFunc_drawPoint, METH_VARARGS},
    {"drawPoints", (PyCFunction)SbkQPainterFunc_drawPoints, METH_O},
    {"drawPolygon", (PyCFunction)SbkQPainterFunc_drawPolygon, METH_VARARGS|METH_KEYWORDS},
    {"drawPolyline", (PyCFunction)SbkQPainterFunc_drawPolyline, METH_O},
    {"drawRect", (PyCFunction)SbkQPainterFunc_drawRect, METH_VARARGS},
    {"drawRects", (PyCFunction)SbkQPainterFunc_drawRects, METH_O},
    {"drawRoundRect", (PyCFunction)SbkQPainterFunc_drawRoundRect, METH_VARARGS|METH_KEYWORDS},
    {"drawRoundedRect", (PyCFunction)SbkQPainterFunc_drawRoundedRect, METH_VARARGS|METH_KEYWORDS},
    {"drawText", (PyCFunction)SbkQPainterFunc_drawText, METH_VARARGS|METH_KEYWORDS},
    {"drawTextItem", (PyCFunction)SbkQPainterFunc_drawTextItem, METH_VARARGS},
    {"drawTiledPixmap", (PyCFunction)SbkQPainterFunc_drawTiledPixmap, METH_VARARGS|METH_KEYWORDS},
    {"end", (PyCFunction)SbkQPainterFunc_end, METH_NOARGS},
    {"endNativePainting", (PyCFunction)SbkQPainterFunc_endNativePainting, METH_NOARGS},
    {"eraseRect", (PyCFunction)SbkQPainterFunc_eraseRect, METH_VARARGS},
    {"fillPath", (PyCFunction)SbkQPainterFunc_fillPath, METH_VARARGS},
    {"fillRect", (PyCFunction)SbkQPainterFunc_fillRect, METH_VARARGS},
    {"font", (PyCFunction)SbkQPainterFunc_font, METH_NOARGS},
    {"fontMetrics", (PyCFunction)SbkQPainterFunc_fontMetrics, METH_NOARGS},
    {"hasClipping", (PyCFunction)SbkQPainterFunc_hasClipping, METH_NOARGS},
    {"initFrom", (PyCFunction)SbkQPainterFunc_initFrom, METH_O},
    {"isActive", (PyCFunction)SbkQPainterFunc_isActive, METH_NOARGS},
    {"layoutDirection", (PyCFunction)SbkQPainterFunc_layoutDirection, METH_NOARGS},
    {"opacity", (PyCFunction)SbkQPainterFunc_opacity, METH_NOARGS},
    {"paintEngine", (PyCFunction)SbkQPainterFunc_paintEngine, METH_NOARGS},
    {"pen", (PyCFunction)SbkQPainterFunc_pen, METH_NOARGS},
    {"renderHints", (PyCFunction)SbkQPainterFunc_renderHints, METH_NOARGS},
    {"resetMatrix", (PyCFunction)SbkQPainterFunc_resetMatrix, METH_NOARGS},
    {"resetTransform", (PyCFunction)SbkQPainterFunc_resetTransform, METH_NOARGS},
    {"restore", (PyCFunction)SbkQPainterFunc_restore, METH_NOARGS},
    {"restoreRedirected", (PyCFunction)SbkQPainterFunc_restoreRedirected, METH_O|METH_STATIC},
    {"rotate", (PyCFunction)SbkQPainterFunc_rotate, METH_O},
    {"save", (PyCFunction)SbkQPainterFunc_save, METH_NOARGS},
    {"scale", (PyCFunction)SbkQPainterFunc_scale, METH_VARARGS},
    {"setBackground", (PyCFunction)SbkQPainterFunc_setBackground, METH_O},
    {"setBackgroundMode", (PyCFunction)SbkQPainterFunc_setBackgroundMode, METH_O},
    {"setBrush", (PyCFunction)SbkQPainterFunc_setBrush, METH_O},
    {"setBrushOrigin", (PyCFunction)SbkQPainterFunc_setBrushOrigin, METH_VARARGS},
    {"setClipPath", (PyCFunction)SbkQPainterFunc_setClipPath, METH_VARARGS|METH_KEYWORDS},
    {"setClipRect", (PyCFunction)SbkQPainterFunc_setClipRect, METH_VARARGS|METH_KEYWORDS},
    {"setClipRegion", (PyCFunction)SbkQPainterFunc_setClipRegion, METH_VARARGS|METH_KEYWORDS},
    {"setClipping", (PyCFunction)SbkQPainterFunc_setClipping, METH_O},
    {"setCompositionMode", (PyCFunction)SbkQPainterFunc_setCompositionMode, METH_O},
    {"setFont", (PyCFunction)SbkQPainterFunc_setFont, METH_O},
    {"setLayoutDirection", (PyCFunction)SbkQPainterFunc_setLayoutDirection, METH_O},
    {"setOpacity", (PyCFunction)SbkQPainterFunc_setOpacity, METH_O},
    {"setPen", (PyCFunction)SbkQPainterFunc_setPen, METH_O},
    {"setRedirected", (PyCFunction)SbkQPainterFunc_setRedirected, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setRenderHint", (PyCFunction)SbkQPainterFunc_setRenderHint, METH_VARARGS|METH_KEYWORDS},
    {"setRenderHints", (PyCFunction)SbkQPainterFunc_setRenderHints, METH_VARARGS|METH_KEYWORDS},
    {"setTransform", (PyCFunction)SbkQPainterFunc_setTransform, METH_VARARGS|METH_KEYWORDS},
    {"setViewTransformEnabled", (PyCFunction)SbkQPainterFunc_setViewTransformEnabled, METH_O},
    {"setViewport", (PyCFunction)SbkQPainterFunc_setViewport, METH_VARARGS},
    {"setWindow", (PyCFunction)SbkQPainterFunc_setWindow, METH_VARARGS},
    {"setWorldMatrix", (PyCFunction)SbkQPainterFunc_setWorldMatrix, METH_VARARGS|METH_KEYWORDS},
    {"setWorldMatrixEnabled", (PyCFunction)SbkQPainterFunc_setWorldMatrixEnabled, METH_O},
    {"setWorldTransform", (PyCFunction)SbkQPainterFunc_setWorldTransform, METH_VARARGS|METH_KEYWORDS},
    {"shear", (PyCFunction)SbkQPainterFunc_shear, METH_VARARGS},
    {"strokePath", (PyCFunction)SbkQPainterFunc_strokePath, METH_VARARGS},
    {"testRenderHint", (PyCFunction)SbkQPainterFunc_testRenderHint, METH_O},
    {"transform", (PyCFunction)SbkQPainterFunc_transform, METH_NOARGS},
    {"translate", (PyCFunction)SbkQPainterFunc_translate, METH_VARARGS},
    {"viewTransformEnabled", (PyCFunction)SbkQPainterFunc_viewTransformEnabled, METH_NOARGS},
    {"viewport", (PyCFunction)SbkQPainterFunc_viewport, METH_NOARGS},
    {"window", (PyCFunction)SbkQPainterFunc_window, METH_NOARGS},
    {"worldMatrix", (PyCFunction)SbkQPainterFunc_worldMatrix, METH_NOARGS},
    {"worldMatrixEnabled", (PyCFunction)SbkQPainterFunc_worldMatrixEnabled, METH_NOARGS},
    {"worldTransform", (PyCFunction)SbkQPainterFunc_worldTransform, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQPainter_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPainter",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQPainter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&Shiboken::SbkBaseWrapper_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQPainter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      0,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QPainter >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QPainter*",
    /*user_data*/           0
};
} //extern

static PyGetSetDef SbkPySide_QtGui_QPainter_CompositionMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPainter_CompositionMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPainter_CompositionMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "CompositionMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPainter_CompositionMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPainter_CompositionMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPainter_CompositionMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::RenderHints >::checkType(self) && Shiboken::Converter<QPainter::RenderHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        & Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::RenderHints >::checkType(self) && Shiboken::Converter<QPainter::RenderHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        | Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::RenderHints >::checkType(self) && Shiboken::Converter<QPainter::RenderHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        Shiboken::Converter<QPainter::RenderHints>::toCpp(self)
        ^ Shiboken::Converter< QPainter::RenderHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_RenderHint___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::RenderHints >::toPython(
        ~Shiboken::Converter<QPainter::RenderHints >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPainter_RenderHint_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPainter_RenderHint___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPainter_RenderHint___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QPainter_RenderHint_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPainter_RenderHint_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPainter_RenderHint_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderHint",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QPainter_RenderHint_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPainter_RenderHint_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPainter_RenderHint_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPainter_RenderHint_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPainter_RenderHints_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderHints",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QPainter_RenderHint_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(self) && Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        & Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(self) && Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        | Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(self) && Shiboken::Converter<QPainter::PixmapFragmentHints >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        Shiboken::Converter<QPainter::PixmapFragmentHints>::toCpp(self)
        ^ Shiboken::Converter< QPainter::PixmapFragmentHints >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QPainter::PixmapFragmentHints >::toPython(
        ~Shiboken::Converter<QPainter::PixmapFragmentHints >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QPainter_PixmapFragmentHint_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QPainter_PixmapFragmentHint___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QPainter_PixmapFragmentHint_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PixmapFragmentHint",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QPainter_PixmapFragmentHint_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QPainter_PixmapFragmentHint_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QPainter_PixmapFragmentHint_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QPainter_PixmapFragmentHint_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PixmapFragmentHints",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QPainter(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTER_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQPainter_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQPainter_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQPainter_Type));
    PyModule_AddObject(module, "QPainter",
        ((PyObject*)&SbkQPainter_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: CompositionMode
    SbkPySide_QtGuiTypes[SBK_QPAINTER_COMPOSITIONMODE_IDX] = &SbkPySide_QtGui_QPainter_CompositionMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_CompositionMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainter_CompositionMode_Type);
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
            "CompositionMode",((PyObject*)&SbkPySide_QtGui_QPainter_CompositionMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_SourceOver, "CompositionMode_SourceOver");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_SourceOver", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_SourceOver", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_DestinationOver, "CompositionMode_DestinationOver");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_DestinationOver", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_DestinationOver", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Clear, "CompositionMode_Clear");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Clear", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Clear", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Source, "CompositionMode_Source");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Source", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Source", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Destination, "CompositionMode_Destination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Destination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Destination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_SourceIn, "CompositionMode_SourceIn");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_SourceIn", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_SourceIn", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_DestinationIn, "CompositionMode_DestinationIn");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_DestinationIn", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_DestinationIn", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_SourceOut, "CompositionMode_SourceOut");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_SourceOut", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_SourceOut", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_DestinationOut, "CompositionMode_DestinationOut");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_DestinationOut", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_DestinationOut", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_SourceAtop, "CompositionMode_SourceAtop");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_SourceAtop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_SourceAtop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_DestinationAtop, "CompositionMode_DestinationAtop");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_DestinationAtop", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_DestinationAtop", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Xor, "CompositionMode_Xor");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Xor", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Xor", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Plus, "CompositionMode_Plus");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Plus", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Plus", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Multiply, "CompositionMode_Multiply");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Multiply", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Multiply", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Screen, "CompositionMode_Screen");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Screen", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Screen", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Overlay, "CompositionMode_Overlay");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Overlay", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Overlay", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Darken, "CompositionMode_Darken");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Darken", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Darken", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Lighten, "CompositionMode_Lighten");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Lighten", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Lighten", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_ColorDodge, "CompositionMode_ColorDodge");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_ColorDodge", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_ColorDodge", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_ColorBurn, "CompositionMode_ColorBurn");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_ColorBurn", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_ColorBurn", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_HardLight, "CompositionMode_HardLight");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_HardLight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_HardLight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_SoftLight, "CompositionMode_SoftLight");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_SoftLight", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_SoftLight", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Difference, "CompositionMode_Difference");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Difference", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Difference", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::CompositionMode_Exclusion, "CompositionMode_Exclusion");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "CompositionMode_Exclusion", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "CompositionMode_Exclusion", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_SourceOrDestination, "RasterOp_SourceOrDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_SourceOrDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_SourceOrDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_SourceAndDestination, "RasterOp_SourceAndDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_SourceAndDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_SourceAndDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_SourceXorDestination, "RasterOp_SourceXorDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_SourceXorDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_SourceXorDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_NotSourceAndNotDestination, "RasterOp_NotSourceAndNotDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_NotSourceAndNotDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_NotSourceAndNotDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_NotSourceOrNotDestination, "RasterOp_NotSourceOrNotDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_NotSourceOrNotDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_NotSourceOrNotDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_NotSourceXorDestination, "RasterOp_NotSourceXorDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_NotSourceXorDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_NotSourceXorDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_NotSource, "RasterOp_NotSource");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_NotSource", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_NotSource", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_NotSourceAndDestination, "RasterOp_NotSourceAndDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_NotSourceAndDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_NotSourceAndDestination", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_CompositionMode_Type,
        (long) QPainter::RasterOp_SourceAndNotDestination, "RasterOp_SourceAndNotDestination");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "RasterOp_SourceAndNotDestination", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_CompositionMode_Type.tp_dict,
        "RasterOp_SourceAndNotDestination", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::CompositionMode");

    // init enum class: RenderHint
    SbkPySide_QtGuiTypes[SBK_QPAINTER_RENDERHINT_IDX] = &SbkPySide_QtGui_QPainter_RenderHint_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_RenderHint_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainter_RenderHint_Type);
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
            "RenderHint",((PyObject*)&SbkPySide_QtGui_QPainter_RenderHint_Type));

    // init flags class: QFlags<QPainter::RenderHint>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPAINTER_RENDERHINT__IDX] = &SbkPySide_QtGui_QPainter_RenderHints_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_RenderHints_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainter_RenderHints_Type);
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
            "RenderHints",((PyObject*)&SbkPySide_QtGui_QPainter_RenderHints_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_RenderHint_Type,
        (long) QPainter::Antialiasing, "Antialiasing");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "Antialiasing", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint_Type.tp_dict,
        "Antialiasing", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_RenderHint_Type,
        (long) QPainter::TextAntialiasing, "TextAntialiasing");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "TextAntialiasing", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint_Type.tp_dict,
        "TextAntialiasing", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_RenderHint_Type,
        (long) QPainter::SmoothPixmapTransform, "SmoothPixmapTransform");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "SmoothPixmapTransform", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint_Type.tp_dict,
        "SmoothPixmapTransform", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_RenderHint_Type,
        (long) QPainter::HighQualityAntialiasing, "HighQualityAntialiasing");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "HighQualityAntialiasing", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint_Type.tp_dict,
        "HighQualityAntialiasing", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_RenderHint_Type,
        (long) QPainter::NonCosmeticDefaultPen, "NonCosmeticDefaultPen");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "NonCosmeticDefaultPen", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_RenderHint_Type.tp_dict,
        "NonCosmeticDefaultPen", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::RenderHint");

    // init enum class: PixmapFragmentHint
    SbkPySide_QtGuiTypes[SBK_QPAINTER_PIXMAPFRAGMENTHINT_IDX] = &SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type);
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
            "PixmapFragmentHint",((PyObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type));

    // init flags class: QFlags<QPainter::PixmapFragmentHint>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QPAINTER_PIXMAPFRAGMENTHINT__IDX] = &SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type);
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
            "PixmapFragmentHints",((PyObject*)&SbkPySide_QtGui_QPainter_PixmapFragmentHints_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type,
        (long) QPainter::OpaqueHint, "OpaqueHint");
    PyDict_SetItemString(SbkQPainter_Type.super.ht_type.tp_dict,
        "OpaqueHint", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QPainter_PixmapFragmentHint_Type.tp_dict,
        "OpaqueHint", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPainter::PixmapFragmentHint");


    Shiboken::TypeResolver::createObjectTypeResolver<QPainter >("QPainter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainter >(typeid(QPainter).name());
    PySide::initQtMetaType<QPainter* >();
}

