/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qtextedit_wrapper.h"
#include "qtextedit_extraselection_wrapper.h"

// Extra includes
#include <QList>
#include <QTextCursor>
#include <QTextEdit>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcolor.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmenu.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qprinter.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextedit.h>
#include <qtextformat.h>
#include <qurl.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QTextEditWrapper::QTextEditWrapper(QWidget * parent) : QTextEdit(parent), m_metaObject(0) {
    // ... middle
}

QTextEditWrapper::QTextEditWrapper(const QString & text, QWidget * parent) : QTextEdit(text, parent), m_metaObject(0) {
    // ... middle
}

void QTextEditWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTextEditWrapper::canInsertFromMimeData(const QMimeData * source) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "canInsertFromMimeData"));
    if (py_override.isNull()) {
        return this->QTextEdit::canInsertFromMimeData(source);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QMimeData * >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.canInsertFromMimeData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::changeEvent(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::changeEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::contextMenuEvent(QContextMenuEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::contextMenuEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QMimeData * QTextEditWrapper::createMimeDataFromSelection() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "createMimeDataFromSelection"));
    if (py_override.isNull()) {
        return this->QTextEdit::createMimeDataFromSelection();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QMimeData * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.createMimeDataFromSelection", SbkType<QMimeData * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMimeData * cppResult(Shiboken::Converter<QMimeData * >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QTextEditWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::dragEnterEvent(QDragEnterEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::dragEnterEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::dragLeaveEvent(QDragLeaveEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::dragLeaveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::dragMoveEvent(QDragMoveEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::dragMoveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::dropEvent(QDropEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::dropEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTextEditWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QTextEdit::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QTextEditWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::focusInEvent(QFocusEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::focusInEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTextEditWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QTextEdit::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::focusOutEvent(QFocusEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::focusOutEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QTextEditWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QTextEditWrapper::inputMethodQuery(Qt::InputMethodQuery property) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QTextEdit::inputMethodQuery(property);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(property)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::insertFromMimeData(const QMimeData * source)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "insertFromMimeData"));
    if (py_override.isNull()) {
        return this->QTextEdit::insertFromMimeData(source);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const QMimeData * >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::keyPressEvent(QKeyEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::keyPressEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::keyReleaseEvent(QKeyEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::keyReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QTextEditWrapper::loadResource(int type, const QUrl & name)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "loadResource"));
    if (py_override.isNull()) {
        return this->QTextEdit::loadResource(type, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iN)",
        type,
        Shiboken::Converter<const QUrl & >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.loadResource", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

int QTextEditWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QTextEditWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::mouseDoubleClickEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::mouseDoubleClickEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::mouseMoveEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::mouseMoveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::mousePressEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::mousePressEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::mouseReleaseEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::mouseReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QTextEditWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QTextEdit.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QTextEditWrapper::paintEvent(QPaintEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::paintEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::resizeEvent(QResizeEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::resizeEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        return this->QTextEdit::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QTextEditWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QTextEditWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QTextEditWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextEditWrapper::timerEvent(QTimerEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::timerEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

bool QTextEditWrapper::viewportEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        return this->QAbstractScrollArea::viewportEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextEdit.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QTextEditWrapper::wheelEvent(QWheelEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QTextEdit::wheelEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTextEditWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QTextEdit::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QTextEditWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTextEdit::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTextEditWrapper::~QTextEditWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQTextEdit_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextEdit >()))
        return -1;

    QTextEditWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);

    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTextEdit", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextEdit(QWidget*)
    // 1: QTextEdit(QString,QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QTextEdit(QWidget*)
    } else if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextEdit(QString,QWidget*)
        } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextEdit(QString,QWidget*)
        }
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTextEdit(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEdit_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextEdit(QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else
                            pyargs[0] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return -1;
                QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                // QTextEdit(QWidget*)
                cptr = new QTextEditWrapper(cpp_arg0);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTextEdit(QString,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else
                            pyargs[1] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return -1;
                QWidget* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                // QTextEdit(QString,QWidget*)
                cptr = new QTextEditWrapper(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[1], self);
                }
                break;
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QTextEdit >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQTextEdit_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQTextEdit_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", "QString, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit", overloads);
        return -1;
}

static PyObject* SbkQTextEditFunc_acceptRichText(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptRichText()const
            bool cppResult = cppSelf->QTextEdit::acceptRichText();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_alignment(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // alignment()const
            QFlags<Qt::AlignmentFlag> cppResult = cppSelf->QTextEdit::alignment();
            pyResult = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_anchorAt(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: anchorAt(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // anchorAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_anchorAt_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // anchorAt(QPoint)const
            QString cppResult = cppSelf->QTextEdit::anchorAt(*cpp_arg0);
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_anchorAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.anchorAt", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_append(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // append(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_append_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // append(QString)
            cppSelf->QTextEdit::append(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_append_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.append", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_autoFormatting(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoFormatting()const
            QFlags<QTextEdit::AutoFormattingFlag> cppResult = cppSelf->QTextEdit::autoFormatting();
            pyResult = Shiboken::Converter<QFlags<QTextEdit::AutoFormattingFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_canInsertFromMimeData(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: canInsertFromMimeData(const QMimeData*)const
    if (Shiboken::Converter<const QMimeData * >::isConvertible(arg)) {
        overloadId = 0; // canInsertFromMimeData(const QMimeData*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_canInsertFromMimeData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMimeData* cpp_arg0 = Shiboken::Converter<QMimeData* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // canInsertFromMimeData(const QMimeData*)const
            bool cppResult = cppSelf->QTextEdit::canInsertFromMimeData(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_canInsertFromMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.canInsertFromMimeData", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_canPaste(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // canPaste()const
            bool cppResult = cppSelf->QTextEdit::canPaste();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // changeEvent(QEvent*)
            cppSelf->QTextEdit::changeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.changeEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_clear(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clear()
            cppSelf->QTextEdit::clear();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter<QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QContextMenuEvent* cpp_arg0 = Shiboken::Converter<QContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QContextMenuEvent*)
            cppSelf->QTextEdit::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_copy(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // copy()
            cppSelf->QTextEdit::copy();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_createMimeDataFromSelection(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // createMimeDataFromSelection()const
            QMimeData * cppResult = cppSelf->QTextEdit::createMimeDataFromSelection();
            pyResult = Shiboken::Converter<QMimeData * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_createStandardContextMenu(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: createStandardContextMenu()
    // 1: createStandardContextMenu(QPoint)
    if (numArgs == 0) {
        overloadId = 0; // createStandardContextMenu()
    } else if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 1; // createStandardContextMenu(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_createStandardContextMenu_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // createStandardContextMenu()
            {

                if(!PyErr_Occurred()) {
                // createStandardContextMenu()
                QMenu * cppResult = cppSelf->QTextEdit::createStandardContextMenu();
                pyResult = Shiboken::Converter<QMenu * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // createStandardContextMenu(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // createStandardContextMenu(QPoint)
                QMenu * cppResult = cppSelf->QTextEdit::createStandardContextMenu(*cpp_arg0);
                pyResult = Shiboken::Converter<QMenu * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_createStandardContextMenu_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.createStandardContextMenu", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_currentCharFormat(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentCharFormat()const
            QTextCharFormat cppResult = cppSelf->QTextEdit::currentCharFormat();
            pyResult = Shiboken::Converter<QTextCharFormat >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_currentFont(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // currentFont()const
            QFont cppResult = cppSelf->QTextEdit::currentFont();
            pyResult = Shiboken::Converter<QFont >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_cursorForPosition(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cursorForPosition(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // cursorForPosition(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_cursorForPosition_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // cursorForPosition(QPoint)const
            QTextCursor cppResult = cppSelf->QTextEdit::cursorForPosition(*cpp_arg0);
            pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_cursorForPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.cursorForPosition", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_cursorRect(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: cursorRect()const
    // 1: cursorRect(QTextCursor)const
    if (numArgs == 0) {
        overloadId = 0; // cursorRect()const
    } else if (Shiboken::Converter<const QTextCursor & >::isConvertible(arg)) {
        overloadId = 1; // cursorRect(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_cursorRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // cursorRect()const
            {

                if(!PyErr_Occurred()) {
                // cursorRect()const
                QRect cppResult = cppSelf->QTextEdit::cursorRect();
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // cursorRect(QTextCursor)const
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                QTextCursor* cpp_arg0 = Shiboken::Converter<QTextCursor* >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // cursorRect(QTextCursor)const
                QRect cppResult = cppSelf->QTextEdit::cursorRect(*cpp_arg0);
                pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_cursorRect_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.cursorRect", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_cursorWidth(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cursorWidth()const
            int cppResult = cppSelf->QTextEdit::cursorWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_cut(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cut()
            cppSelf->QTextEdit::cut();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_document(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // document()const
            QTextDocument * cppResult = cppSelf->QTextEdit::document();
            pyResult = Shiboken::Converter<QTextDocument * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_documentTitle(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // documentTitle()const
            QString cppResult = cppSelf->QTextEdit::documentTitle();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter<QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragEnterEvent* cpp_arg0 = Shiboken::Converter<QDragEnterEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QDragEnterEvent*)
            cppSelf->QTextEdit::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter<QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragLeaveEvent* cpp_arg0 = Shiboken::Converter<QDragLeaveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QDragLeaveEvent*)
            cppSelf->QTextEdit::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter<QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragMoveEvent* cpp_arg0 = Shiboken::Converter<QDragMoveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QDragMoveEvent*)
            cppSelf->QTextEdit::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter<QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDropEvent* cpp_arg0 = Shiboken::Converter<QDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QDropEvent*)
            cppSelf->QTextEdit::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_ensureCursorVisible(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ensureCursorVisible()
            cppSelf->QTextEdit::ensureCursorVisible();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_event(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QTextEdit::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.event", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_extraSelections(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // extraSelections()const
            QList<QTextEdit::ExtraSelection > cppResult = cppSelf->QTextEdit::extraSelections();
            pyResult = Shiboken::Converter<QList<QTextEdit::ExtraSelection > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_find(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "options" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:find", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: find(QString,QFlags<QTextDocument::FindFlag>)
    if (Shiboken::Converter<QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // find(QString,QFlags<QTextDocument::FindFlag>)
        } else if (Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // find(QString,QFlags<QTextDocument::FindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_find_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "options";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.find(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QTextDocument::FindFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[1]) : QFlags<QTextDocument::FindFlag>(0);

            if(!PyErr_Occurred()) {
            // find(QString,QFlags<QTextDocument::FindFlag>)
            bool cppResult = cppSelf->QTextEdit::find(cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_find_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QTextDocument.FindFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.find", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QTextEdit::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            bool cppResult = cppSelf->QTextEdit::focusNextPrevChild(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QTextEdit::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_fontFamily(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontFamily()const
            QString cppResult = cppSelf->QTextEdit::fontFamily();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_fontItalic(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontItalic()const
            bool cppResult = cppSelf->QTextEdit::fontItalic();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_fontPointSize(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontPointSize()const
            qreal cppResult = cppSelf->QTextEdit::fontPointSize();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_fontUnderline(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontUnderline()const
            bool cppResult = cppSelf->QTextEdit::fontUnderline();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_fontWeight(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontWeight()const
            int cppResult = cppSelf->QTextEdit::fontWeight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QTextEdit::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QTextEdit::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_insertFromMimeData(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertFromMimeData(const QMimeData*)
    if (Shiboken::Converter<const QMimeData * >::isConvertible(arg)) {
        overloadId = 0; // insertFromMimeData(const QMimeData*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_insertFromMimeData_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMimeData* cpp_arg0 = Shiboken::Converter<QMimeData* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertFromMimeData(const QMimeData*)
            cppSelf->QTextEdit::insertFromMimeData(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_insertFromMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.insertFromMimeData", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_insertHtml(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertHtml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // insertHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_insertHtml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertHtml(QString)
            cppSelf->QTextEdit::insertHtml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_insertHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.insertHtml", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_insertPlainText(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertPlainText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // insertPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_insertPlainText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // insertPlainText(QString)
            cppSelf->QTextEdit::insertPlainText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_insertPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.insertPlainText", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_isReadOnly(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isReadOnly()const
            bool cppResult = cppSelf->QTextEdit::isReadOnly();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_isUndoRedoEnabled(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isUndoRedoEnabled()const
            bool cppResult = cppSelf->QTextEdit::isUndoRedoEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QTextEdit::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QTextEdit::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_lineWrapColumnOrWidth(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineWrapColumnOrWidth()const
            int cppResult = cppSelf->QTextEdit::lineWrapColumnOrWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_lineWrapMode(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lineWrapMode()const
            QTextEdit::LineWrapMode cppResult = cppSelf->QTextEdit::lineWrapMode();
            pyResult = Shiboken::Converter<QTextEdit::LineWrapMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_loadResource(PyObject* self, PyObject* args)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadResource(int,QUrl)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter<const QUrl & >::isConvertible(pyargs[1])) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_loadResource_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            std::auto_ptr<QUrl > cpp_arg1_auto_ptr;
            QUrl* cpp_arg1 = Shiboken::Converter<QUrl* >::toCpp(pyargs[1]);
            if (!Shiboken::Converter<QUrl >::checkType(pyargs[1]))
                cpp_arg1_auto_ptr = std::auto_ptr<QUrl >(cpp_arg1);

            if(!PyErr_Occurred()) {
            // loadResource(int,QUrl)
            QVariant cppResult = cppSelf->QTextEdit::loadResource(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQTextEditFunc_loadResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.loadResource", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_mergeCurrentCharFormat(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mergeCurrentCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // mergeCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_mergeCurrentCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mergeCurrentCharFormat(QTextCharFormat)
            cppSelf->QTextEdit::mergeCurrentCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_mergeCurrentCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.mergeCurrentCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QMouseEvent*)
            cppSelf->QTextEdit::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QMouseEvent*)
            cppSelf->QTextEdit::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QMouseEvent*)
            cppSelf->QTextEdit::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QMouseEvent*)
            cppSelf->QTextEdit::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_moveCursor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "mode" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:moveCursor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
    if (Shiboken::Converter<QTextCursor::MoveOperation >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        } else if (Shiboken::Converter<QTextCursor::MoveMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_moveCursor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.moveCursor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QTextCursor::MoveOperation cpp_arg0 = Shiboken::Converter<QTextCursor::MoveOperation >::toCpp(pyargs[0]);
            QTextCursor::MoveMode cpp_arg1 = pyargs[1] ? Shiboken::Converter<QTextCursor::MoveMode >::toCpp(pyargs[1]) : QTextCursor::MoveAnchor;

            if(!PyErr_Occurred()) {
            // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
            cppSelf->QTextEdit::moveCursor(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_moveCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor.MoveOperation, PySide.QtGui.QTextCursor.MoveMode = QTextCursor.MoveAnchor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.moveCursor", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_overwriteMode(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // overwriteMode()const
            bool cppResult = cppSelf->QTextEdit::overwriteMode();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter<QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintEvent* cpp_arg0 = Shiboken::Converter<QPaintEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // paintEvent(QPaintEvent*)
            cppSelf->QTextEdit::paintEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.paintEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_paste(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paste()
            cppSelf->QTextEdit::paste();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_print_(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: print(QPrinter*)const
    if (Shiboken::Converter<QPrinter * >::isConvertible(arg)) {
        overloadId = 0; // print(QPrinter*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_print__TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPrinter* cpp_arg0 = Shiboken::Converter<QPrinter* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // print(QPrinter*)const
            cppSelf->QTextEdit::print(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_print__TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.print_", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_redo(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // redo()
            cppSelf->QTextEdit::redo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QTextEdit::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // scrollContentsBy(int,int)
            cppSelf->QTextEdit::scrollContentsBy(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextEdit.scrollContentsBy", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_scrollToAnchor(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: scrollToAnchor(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // scrollToAnchor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_scrollToAnchor_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // scrollToAnchor(QString)
            cppSelf->QTextEdit::scrollToAnchor(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_scrollToAnchor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.scrollToAnchor", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_selectAll(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // selectAll()
            cppSelf->QTextEdit::selectAll();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_setAcceptRichText(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptRichText(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptRichText(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setAcceptRichText_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptRichText(bool)
            cppSelf->QTextEdit::setAcceptRichText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setAcceptRichText_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setAcceptRichText", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAlignment(QFlags<Qt::AlignmentFlag>)
            cppSelf->QTextEdit::setAlignment(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setAlignment", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setAutoFormatting(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
    if (Shiboken::Converter<QFlags<QTextEdit::AutoFormattingFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setAutoFormatting_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextEdit::AutoFormattingFlag> cpp_arg0 = Shiboken::Converter<QFlags<QTextEdit::AutoFormattingFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoFormatting(QFlags<QTextEdit::AutoFormattingFlag>)
            cppSelf->QTextEdit::setAutoFormatting(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setAutoFormatting_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextEdit.AutoFormatting", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setAutoFormatting", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setCurrentCharFormat(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentCharFormat(QTextCharFormat)
    if (Shiboken::Converter<const QTextCharFormat & >::isConvertible(arg)) {
        overloadId = 0; // setCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setCurrentCharFormat_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCharFormat* cpp_arg0 = Shiboken::Converter<QTextCharFormat* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCurrentCharFormat(QTextCharFormat)
            cppSelf->QTextEdit::setCurrentCharFormat(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setCurrentCharFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCharFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setCurrentCharFormat", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setCurrentFont(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setCurrentFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setCurrentFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setCurrentFont(QFont)
            cppSelf->QTextEdit::setCurrentFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setCurrentFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setCurrentFont", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setCursorWidth(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursorWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCursorWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setCursorWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setCursorWidth(int)
            cppSelf->QTextEdit::setCursorWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setCursorWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setCursorWidth", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setDocument(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocument(QTextDocument*)
    if (Shiboken::Converter<QTextDocument * >::isConvertible(arg)) {
        overloadId = 0; // setDocument(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setDocument_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextDocument* cpp_arg0 = Shiboken::Converter<QTextDocument* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocument(QTextDocument*)
            cppSelf->QTextEdit::setDocument(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setDocument_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setDocument", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setDocumentTitle(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentTitle(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setDocumentTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setDocumentTitle_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDocumentTitle(QString)
            cppSelf->QTextEdit::setDocumentTitle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setDocumentTitle_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setDocumentTitle", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setExtraSelections(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setExtraSelections(QList<QTextEdit::ExtraSelection>)
    if (Shiboken::Converter< QList<QTextEdit::ExtraSelection >  >::isConvertible(arg)) {
        overloadId = 0; // setExtraSelections(QList<QTextEdit::ExtraSelection>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setExtraSelections_TypeError;

    // Call function/method
    {
        {
            QList<QTextEdit::ExtraSelection > cpp_arg0 = Shiboken::Converter<QList<QTextEdit::ExtraSelection > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setExtraSelections(QList<QTextEdit::ExtraSelection>)
            cppSelf->QTextEdit::setExtraSelections(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setExtraSelections_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setExtraSelections", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setFontFamily(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontFamily(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setFontFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setFontFamily_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontFamily(QString)
            cppSelf->QTextEdit::setFontFamily(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setFontFamily_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setFontFamily", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setFontItalic(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontItalic(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setFontItalic_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontItalic(bool)
            cppSelf->QTextEdit::setFontItalic(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setFontItalic_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setFontItalic", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setFontPointSize(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontPointSize(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontPointSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setFontPointSize_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontPointSize(qreal)
            cppSelf->QTextEdit::setFontPointSize(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setFontPointSize_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setFontPointSize", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setFontUnderline(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontUnderline(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setFontUnderline_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontUnderline(bool)
            cppSelf->QTextEdit::setFontUnderline(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setFontUnderline_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setFontUnderline", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setFontWeight(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFontWeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFontWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setFontWeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFontWeight(int)
            cppSelf->QTextEdit::setFontWeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setFontWeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setFontWeight", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setHtml(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHtml(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setHtml_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHtml(QString)
            cppSelf->QTextEdit::setHtml(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setHtml", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setLineWrapColumnOrWidth(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineWrapColumnOrWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLineWrapColumnOrWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setLineWrapColumnOrWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLineWrapColumnOrWidth(int)
            cppSelf->QTextEdit::setLineWrapColumnOrWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setLineWrapColumnOrWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setLineWrapColumnOrWidth", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setLineWrapMode(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLineWrapMode(QTextEdit::LineWrapMode)
    if (Shiboken::Converter<QTextEdit::LineWrapMode >::isConvertible(arg)) {
        overloadId = 0; // setLineWrapMode(QTextEdit::LineWrapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setLineWrapMode_TypeError;

    // Call function/method
    {
        {
            QTextEdit::LineWrapMode cpp_arg0 = Shiboken::Converter<QTextEdit::LineWrapMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLineWrapMode(QTextEdit::LineWrapMode)
            cppSelf->QTextEdit::setLineWrapMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setLineWrapMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextEdit.LineWrapMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setLineWrapMode", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setOverwriteMode(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverwriteMode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOverwriteMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setOverwriteMode_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setOverwriteMode(bool)
            cppSelf->QTextEdit::setOverwriteMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setOverwriteMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setOverwriteMode", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setPlainText(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setPlainText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setPlainText(QString)
            cppSelf->QTextEdit::setPlainText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setPlainText", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setReadOnly(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadOnly(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setReadOnly_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setReadOnly(bool)
            cppSelf->QTextEdit::setReadOnly(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setReadOnly_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setReadOnly", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTabChangesFocus(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabChangesFocus(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTabChangesFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTabChangesFocus_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabChangesFocus(bool)
            cppSelf->QTextEdit::setTabChangesFocus(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTabChangesFocus_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTabChangesFocus", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTabStopWidth(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabStopWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTabStopWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTabStopWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTabStopWidth(int)
            cppSelf->QTextEdit::setTabStopWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTabStopWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTabStopWidth", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setText(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setText(QString)
            cppSelf->QTextEdit::setText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setText", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTextBackgroundColor(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextBackgroundColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setTextBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTextBackgroundColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTextBackgroundColor(QColor)
            cppSelf->QTextEdit::setTextBackgroundColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTextBackgroundColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTextBackgroundColor", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTextColor(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextColor(QColor)
    if (Shiboken::Converter<const QColor & >::isConvertible(arg)) {
        overloadId = 0; // setTextColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTextColor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QColor > cpp_arg0_auto_ptr;
            QColor* cpp_arg0 = Shiboken::Converter<QColor* >::toCpp(arg);
            if (!Shiboken::Converter<QColor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QColor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setTextColor(QColor)
            cppSelf->QTextEdit::setTextColor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTextColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTextColor", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTextCursor(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextCursor(QTextCursor)
    if (Shiboken::Converter<const QTextCursor & >::isConvertible(arg)) {
        overloadId = 0; // setTextCursor(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTextCursor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTextCursor* cpp_arg0 = Shiboken::Converter<QTextCursor* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextCursor(QTextCursor)
            cppSelf->QTextEdit::setTextCursor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTextCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTextCursor", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setTextInteractionFlags(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    if (Shiboken::Converter<QFlags<Qt::TextInteractionFlag> >::isConvertible(arg)) {
        overloadId = 0; // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setTextInteractionFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::TextInteractionFlag> cpp_arg0 = Shiboken::Converter<QFlags<Qt::TextInteractionFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
            cppSelf->QTextEdit::setTextInteractionFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setTextInteractionFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.TextInteractionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setTextInteractionFlags", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setUndoRedoEnabled(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUndoRedoEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setUndoRedoEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUndoRedoEnabled(bool)
            cppSelf->QTextEdit::setUndoRedoEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setUndoRedoEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setUndoRedoEnabled", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_setWordWrapMode(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWordWrapMode(QTextOption::WrapMode)
    if (Shiboken::Converter<QTextOption::WrapMode >::isConvertible(arg)) {
        overloadId = 0; // setWordWrapMode(QTextOption::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_setWordWrapMode_TypeError;

    // Call function/method
    {
        {
            QTextOption::WrapMode cpp_arg0 = Shiboken::Converter<QTextOption::WrapMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWordWrapMode(QTextOption::WrapMode)
            cppSelf->QTextEdit::setWordWrapMode(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_setWordWrapMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption.WrapMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.setWordWrapMode", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_showEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter<QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QShowEvent* cpp_arg0 = Shiboken::Converter<QShowEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // showEvent(QShowEvent*)
            cppSelf->QTextEdit::showEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.showEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_tabChangesFocus(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabChangesFocus()const
            bool cppResult = cppSelf->QTextEdit::tabChangesFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_tabStopWidth(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // tabStopWidth()const
            int cppResult = cppSelf->QTextEdit::tabStopWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_textBackgroundColor(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textBackgroundColor()const
            QColor cppResult = cppSelf->QTextEdit::textBackgroundColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_textColor(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textColor()const
            QColor cppResult = cppSelf->QTextEdit::textColor();
            pyResult = Shiboken::Converter<QColor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_textCursor(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textCursor()const
            QTextCursor cppResult = cppSelf->QTextEdit::textCursor();
            pyResult = Shiboken::Converter<QTextCursor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_textInteractionFlags(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // textInteractionFlags()const
            QFlags<Qt::TextInteractionFlag> cppResult = cppSelf->QTextEdit::textInteractionFlags();
            pyResult = Shiboken::Converter<QFlags<Qt::TextInteractionFlag> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_timerEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: timerEvent(QTimerEvent*)
    if (Shiboken::Converter<QTimerEvent * >::isConvertible(arg)) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_timerEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTimerEvent* cpp_arg0 = Shiboken::Converter<QTimerEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // timerEvent(QTimerEvent*)
            cppSelf->QTextEdit::timerEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_timerEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QTimerEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.timerEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_toHtml(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toHtml()const
            QString cppResult = cppSelf->QTextEdit::toHtml();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_toPlainText(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toPlainText()const
            QString cppResult = cppSelf->QTextEdit::toPlainText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_undo(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // undo()
            cppSelf->QTextEdit::undo();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQTextEditFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter<QWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWheelEvent* cpp_arg0 = Shiboken::Converter<QWheelEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // wheelEvent(QWheelEvent*)
            cppSelf->QTextEdit::wheelEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.wheelEvent", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_wordWrapMode(PyObject* self)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // wordWrapMode()const
            QTextOption::WrapMode cppResult = cppSelf->QTextEdit::wordWrapMode();
            pyResult = Shiboken::Converter<QTextOption::WrapMode >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQTextEditFunc_zoomIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "range" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomIn(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomIn(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:zoomIn", &arg))
        return 0;


    // Overloaded function decisor
    // 0: zoomIn(int)
    if (numArgs == 0) {
        overloadId = 0; // zoomIn(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // zoomIn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_zoomIn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "range");
                if (value) {
                    if (arg)
                        errorArgName = "range";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomIn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 1;

            if(!PyErr_Occurred()) {
            // zoomIn(int)
            cppSelf->QTextEdit::zoomIn(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_zoomIn_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.zoomIn", overloads);
        return 0;
}

static PyObject* SbkQTextEditFunc_zoomOut(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextEdit* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QTextEdit* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "range" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomOut(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* arg = 0;

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomOut(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:zoomOut", &arg))
        return 0;


    // Overloaded function decisor
    // 0: zoomOut(int)
    if (numArgs == 0) {
        overloadId = 0; // zoomOut(int)
    } else if (SbkNumber_Check(arg)) {
        overloadId = 0; // zoomOut(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQTextEditFunc_zoomOut_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "range");
                if (value) {
                    if (arg)
                        errorArgName = "range";
                    else
                        arg = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextEdit.zoomOut(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = arg ? Shiboken::Converter<int >::toCpp(arg) : 1;

            if(!PyErr_Occurred()) {
            // zoomOut(int)
            cppSelf->QTextEdit::zoomOut(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQTextEditFunc_zoomOut_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextEdit.zoomOut", overloads);
        return 0;
}

static PyMethodDef SbkQTextEdit_methods[] = {
    {"acceptRichText", (PyCFunction)SbkQTextEditFunc_acceptRichText, METH_NOARGS},
    {"alignment", (PyCFunction)SbkQTextEditFunc_alignment, METH_NOARGS},
    {"anchorAt", (PyCFunction)SbkQTextEditFunc_anchorAt, METH_O},
    {"append", (PyCFunction)SbkQTextEditFunc_append, METH_O},
    {"autoFormatting", (PyCFunction)SbkQTextEditFunc_autoFormatting, METH_NOARGS},
    {"canInsertFromMimeData", (PyCFunction)SbkQTextEditFunc_canInsertFromMimeData, METH_O},
    {"canPaste", (PyCFunction)SbkQTextEditFunc_canPaste, METH_NOARGS},
    {"changeEvent", (PyCFunction)SbkQTextEditFunc_changeEvent, METH_O},
    {"clear", (PyCFunction)SbkQTextEditFunc_clear, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)SbkQTextEditFunc_contextMenuEvent, METH_O},
    {"copy", (PyCFunction)SbkQTextEditFunc_copy, METH_NOARGS},
    {"createMimeDataFromSelection", (PyCFunction)SbkQTextEditFunc_createMimeDataFromSelection, METH_NOARGS},
    {"createStandardContextMenu", (PyCFunction)SbkQTextEditFunc_createStandardContextMenu, METH_NOARGS|METH_O},
    {"currentCharFormat", (PyCFunction)SbkQTextEditFunc_currentCharFormat, METH_NOARGS},
    {"currentFont", (PyCFunction)SbkQTextEditFunc_currentFont, METH_NOARGS},
    {"cursorForPosition", (PyCFunction)SbkQTextEditFunc_cursorForPosition, METH_O},
    {"cursorRect", (PyCFunction)SbkQTextEditFunc_cursorRect, METH_NOARGS|METH_O},
    {"cursorWidth", (PyCFunction)SbkQTextEditFunc_cursorWidth, METH_NOARGS},
    {"cut", (PyCFunction)SbkQTextEditFunc_cut, METH_NOARGS},
    {"document", (PyCFunction)SbkQTextEditFunc_document, METH_NOARGS},
    {"documentTitle", (PyCFunction)SbkQTextEditFunc_documentTitle, METH_NOARGS},
    {"dragEnterEvent", (PyCFunction)SbkQTextEditFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQTextEditFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)SbkQTextEditFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)SbkQTextEditFunc_dropEvent, METH_O},
    {"ensureCursorVisible", (PyCFunction)SbkQTextEditFunc_ensureCursorVisible, METH_NOARGS},
    {"event", (PyCFunction)SbkQTextEditFunc_event, METH_O},
    {"extraSelections", (PyCFunction)SbkQTextEditFunc_extraSelections, METH_NOARGS},
    {"find", (PyCFunction)SbkQTextEditFunc_find, METH_VARARGS|METH_KEYWORDS},
    {"focusInEvent", (PyCFunction)SbkQTextEditFunc_focusInEvent, METH_O},
    {"focusNextPrevChild", (PyCFunction)SbkQTextEditFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)SbkQTextEditFunc_focusOutEvent, METH_O},
    {"fontFamily", (PyCFunction)SbkQTextEditFunc_fontFamily, METH_NOARGS},
    {"fontItalic", (PyCFunction)SbkQTextEditFunc_fontItalic, METH_NOARGS},
    {"fontPointSize", (PyCFunction)SbkQTextEditFunc_fontPointSize, METH_NOARGS},
    {"fontUnderline", (PyCFunction)SbkQTextEditFunc_fontUnderline, METH_NOARGS},
    {"fontWeight", (PyCFunction)SbkQTextEditFunc_fontWeight, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)SbkQTextEditFunc_inputMethodEvent, METH_O},
    {"inputMethodQuery", (PyCFunction)SbkQTextEditFunc_inputMethodQuery, METH_O},
    {"insertFromMimeData", (PyCFunction)SbkQTextEditFunc_insertFromMimeData, METH_O},
    {"insertHtml", (PyCFunction)SbkQTextEditFunc_insertHtml, METH_O},
    {"insertPlainText", (PyCFunction)SbkQTextEditFunc_insertPlainText, METH_O},
    {"isReadOnly", (PyCFunction)SbkQTextEditFunc_isReadOnly, METH_NOARGS},
    {"isUndoRedoEnabled", (PyCFunction)SbkQTextEditFunc_isUndoRedoEnabled, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)SbkQTextEditFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQTextEditFunc_keyReleaseEvent, METH_O},
    {"lineWrapColumnOrWidth", (PyCFunction)SbkQTextEditFunc_lineWrapColumnOrWidth, METH_NOARGS},
    {"lineWrapMode", (PyCFunction)SbkQTextEditFunc_lineWrapMode, METH_NOARGS},
    {"loadResource", (PyCFunction)SbkQTextEditFunc_loadResource, METH_VARARGS},
    {"mergeCurrentCharFormat", (PyCFunction)SbkQTextEditFunc_mergeCurrentCharFormat, METH_O},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQTextEditFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)SbkQTextEditFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQTextEditFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQTextEditFunc_mouseReleaseEvent, METH_O},
    {"moveCursor", (PyCFunction)SbkQTextEditFunc_moveCursor, METH_VARARGS|METH_KEYWORDS},
    {"overwriteMode", (PyCFunction)SbkQTextEditFunc_overwriteMode, METH_NOARGS},
    {"paintEvent", (PyCFunction)SbkQTextEditFunc_paintEvent, METH_O},
    {"paste", (PyCFunction)SbkQTextEditFunc_paste, METH_NOARGS},
    {"print_", (PyCFunction)SbkQTextEditFunc_print_, METH_O},
    {"redo", (PyCFunction)SbkQTextEditFunc_redo, METH_NOARGS},
    {"resizeEvent", (PyCFunction)SbkQTextEditFunc_resizeEvent, METH_O},
    {"scrollContentsBy", (PyCFunction)SbkQTextEditFunc_scrollContentsBy, METH_VARARGS},
    {"scrollToAnchor", (PyCFunction)SbkQTextEditFunc_scrollToAnchor, METH_O},
    {"selectAll", (PyCFunction)SbkQTextEditFunc_selectAll, METH_NOARGS},
    {"setAcceptRichText", (PyCFunction)SbkQTextEditFunc_setAcceptRichText, METH_O},
    {"setAlignment", (PyCFunction)SbkQTextEditFunc_setAlignment, METH_O},
    {"setAutoFormatting", (PyCFunction)SbkQTextEditFunc_setAutoFormatting, METH_O},
    {"setCurrentCharFormat", (PyCFunction)SbkQTextEditFunc_setCurrentCharFormat, METH_O},
    {"setCurrentFont", (PyCFunction)SbkQTextEditFunc_setCurrentFont, METH_O},
    {"setCursorWidth", (PyCFunction)SbkQTextEditFunc_setCursorWidth, METH_O},
    {"setDocument", (PyCFunction)SbkQTextEditFunc_setDocument, METH_O},
    {"setDocumentTitle", (PyCFunction)SbkQTextEditFunc_setDocumentTitle, METH_O},
    {"setExtraSelections", (PyCFunction)SbkQTextEditFunc_setExtraSelections, METH_O},
    {"setFontFamily", (PyCFunction)SbkQTextEditFunc_setFontFamily, METH_O},
    {"setFontItalic", (PyCFunction)SbkQTextEditFunc_setFontItalic, METH_O},
    {"setFontPointSize", (PyCFunction)SbkQTextEditFunc_setFontPointSize, METH_O},
    {"setFontUnderline", (PyCFunction)SbkQTextEditFunc_setFontUnderline, METH_O},
    {"setFontWeight", (PyCFunction)SbkQTextEditFunc_setFontWeight, METH_O},
    {"setHtml", (PyCFunction)SbkQTextEditFunc_setHtml, METH_O},
    {"setLineWrapColumnOrWidth", (PyCFunction)SbkQTextEditFunc_setLineWrapColumnOrWidth, METH_O},
    {"setLineWrapMode", (PyCFunction)SbkQTextEditFunc_setLineWrapMode, METH_O},
    {"setOverwriteMode", (PyCFunction)SbkQTextEditFunc_setOverwriteMode, METH_O},
    {"setPlainText", (PyCFunction)SbkQTextEditFunc_setPlainText, METH_O},
    {"setReadOnly", (PyCFunction)SbkQTextEditFunc_setReadOnly, METH_O},
    {"setTabChangesFocus", (PyCFunction)SbkQTextEditFunc_setTabChangesFocus, METH_O},
    {"setTabStopWidth", (PyCFunction)SbkQTextEditFunc_setTabStopWidth, METH_O},
    {"setText", (PyCFunction)SbkQTextEditFunc_setText, METH_O},
    {"setTextBackgroundColor", (PyCFunction)SbkQTextEditFunc_setTextBackgroundColor, METH_O},
    {"setTextColor", (PyCFunction)SbkQTextEditFunc_setTextColor, METH_O},
    {"setTextCursor", (PyCFunction)SbkQTextEditFunc_setTextCursor, METH_O},
    {"setTextInteractionFlags", (PyCFunction)SbkQTextEditFunc_setTextInteractionFlags, METH_O},
    {"setUndoRedoEnabled", (PyCFunction)SbkQTextEditFunc_setUndoRedoEnabled, METH_O},
    {"setWordWrapMode", (PyCFunction)SbkQTextEditFunc_setWordWrapMode, METH_O},
    {"showEvent", (PyCFunction)SbkQTextEditFunc_showEvent, METH_O},
    {"tabChangesFocus", (PyCFunction)SbkQTextEditFunc_tabChangesFocus, METH_NOARGS},
    {"tabStopWidth", (PyCFunction)SbkQTextEditFunc_tabStopWidth, METH_NOARGS},
    {"textBackgroundColor", (PyCFunction)SbkQTextEditFunc_textBackgroundColor, METH_NOARGS},
    {"textColor", (PyCFunction)SbkQTextEditFunc_textColor, METH_NOARGS},
    {"textCursor", (PyCFunction)SbkQTextEditFunc_textCursor, METH_NOARGS},
    {"textInteractionFlags", (PyCFunction)SbkQTextEditFunc_textInteractionFlags, METH_NOARGS},
    {"timerEvent", (PyCFunction)SbkQTextEditFunc_timerEvent, METH_O},
    {"toHtml", (PyCFunction)SbkQTextEditFunc_toHtml, METH_NOARGS},
    {"toPlainText", (PyCFunction)SbkQTextEditFunc_toPlainText, METH_NOARGS},
    {"undo", (PyCFunction)SbkQTextEditFunc_undo, METH_NOARGS},
    {"wheelEvent", (PyCFunction)SbkQTextEditFunc_wheelEvent, METH_O},
    {"wordWrapMode", (PyCFunction)SbkQTextEditFunc_wordWrapMode, METH_NOARGS},
    {"zoomIn", (PyCFunction)SbkQTextEditFunc_zoomIn, METH_VARARGS|METH_KEYWORDS},
    {"zoomOut", (PyCFunction)SbkQTextEditFunc_zoomOut, METH_VARARGS|METH_KEYWORDS},
    {0} // Sentinel
};

} // extern "C"

static void* SbkQTextEditSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QTextEdit* me = reinterpret_cast<QTextEdit*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQTextEdit_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextEdit",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQTextEdit_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQTextEdit_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             0,
    /*mi_specialcast*/      &SbkQTextEditSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QTextEdit >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QTextEdit*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQTextEdit_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTextEdit*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQTextEdit_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QTextEdit*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQTextEdit_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(self) && Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter<QTextEdit::AutoFormatting>::toCpp(self)
        & Shiboken::Converter< QTextEdit::AutoFormatting >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(self) && Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter<QTextEdit::AutoFormatting>::toCpp(self)
        | Shiboken::Converter< QTextEdit::AutoFormatting >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(self) && Shiboken::Converter<QTextEdit::AutoFormatting >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QTextEdit::AutoFormatting >::toPython(
        Shiboken::Converter<QTextEdit::AutoFormatting>::toCpp(self)
        ^ Shiboken::Converter< QTextEdit::AutoFormatting >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextEdit::AutoFormatting >::toPython(
        ~Shiboken::Converter<QTextEdit::AutoFormatting >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextEdit_AutoFormattingFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "AutoFormattingFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextEdit_AutoFormatting_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "AutoFormatting",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};


static PyGetSetDef SbkPySide_QtGui_QTextEdit_LineWrapMode_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QTextEdit_LineWrapMode_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QTextEdit_LineWrapMode_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "LineWrapMode",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QTextEdit_LineWrapMode_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QTextEdit_LineWrapMode_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QTextEdit_LineWrapMode_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}


void init_QTextEdit(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQTextEdit_Type);

    SbkQTextEdit_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX];
    SbkQTextEdit_Type.mi_init = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX])->mi_init;

    // Fill type discovery information
    SbkQTextEdit_Type.type_discovery = &SbkQTextEdit_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]), &SbkQTextEdit_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQTextEdit_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQTextEdit_Type));
    PyModule_AddObject(module, "QTextEdit",
        ((PyObject*)&SbkQTextEdit_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: AutoFormattingFlag
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_AUTOFORMATTINGFLAG_IDX] = &SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
            "AutoFormattingFlag",((PyObject*)&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type));

    // init flags class: QFlags<QTextEdit::AutoFormattingFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTEDIT_AUTOFORMATTINGFLAG__IDX] = &SbkPySide_QtGui_QTextEdit_AutoFormatting_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextEdit_AutoFormatting_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextEdit_AutoFormatting_Type);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
            "AutoFormatting",((PyObject*)&SbkPySide_QtGui_QTextEdit_AutoFormatting_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type,
        (long) QTextEdit::AutoNone, "AutoNone");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "AutoNone", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type.tp_dict,
        "AutoNone", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type,
        (long) QTextEdit::AutoBulletList, "AutoBulletList");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "AutoBulletList", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type.tp_dict,
        "AutoBulletList", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type,
        (long) QTextEdit::AutoAll, "AutoAll");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "AutoAll", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_AutoFormattingFlag_Type.tp_dict,
        "AutoAll", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextEdit::AutoFormattingFlag");

    // init enum class: LineWrapMode
    SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_LINEWRAPMODE_IDX] = &SbkPySide_QtGui_QTextEdit_LineWrapMode_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
            "LineWrapMode",((PyObject*)&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type,
        (long) QTextEdit::NoWrap, "NoWrap");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "NoWrap", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_LineWrapMode_Type.tp_dict,
        "NoWrap", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type,
        (long) QTextEdit::WidgetWidth, "WidgetWidth");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "WidgetWidth", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_LineWrapMode_Type.tp_dict,
        "WidgetWidth", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type,
        (long) QTextEdit::FixedPixelWidth, "FixedPixelWidth");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "FixedPixelWidth", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_LineWrapMode_Type.tp_dict,
        "FixedPixelWidth", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QTextEdit_LineWrapMode_Type,
        (long) QTextEdit::FixedColumnWidth, "FixedColumnWidth");
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict,
        "FixedColumnWidth", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QTextEdit_LineWrapMode_Type.tp_dict,
        "FixedColumnWidth", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextEdit::LineWrapMode");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("undoAvailable", "bool", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "undoAvailable", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("currentCharFormatChanged", "const QTextCharFormat&", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "currentCharFormatChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("selectionChanged", "void", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "selectionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("cursorPositionChanged", "void", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "cursorPositionChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("redoAvailable", "bool", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "redoAvailable", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("textChanged", "void", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "textChanged", signal_item);
    Py_DECREF(signal_item);
    signal_item = PySide::signalNew("copyAvailable", "bool", NULL);
    PyDict_SetItemString(SbkQTextEdit_Type.super.ht_type.tp_dict, "copyAvailable", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTextEdit >("QTextEdit*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextEdit >(typeid(QTextEdit).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextEdit >(typeid(QTextEditWrapper).name());
    PySide::initQtMetaType<QTextEdit* >();
}

