/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <vector>
#include <algorithm>
#include <qsignal.h>
#include <qproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <dynamicqmetaobject.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qwidget_wrapper.h"

// Extra includes
#include <QIcon>
#include <QList>
#include <QMessageBox>
#include "glue/qwidget_glue.h"
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qthread.h>
#include <qwidget.h>
#include <qx11info_x11.h>

using namespace Shiboken;

// Native ---------------------------------------------------------

QWidgetWrapper::QWidgetWrapper(QWidget * parent, QFlags<Qt::WindowType> f) : QWidget(parent, f), m_metaObject(0) {
    // ... middle
}

void QWidgetWrapper::actionEvent(QActionEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        return this->QWidget::actionEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QActionEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        return this->QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QCloseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        return this->QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        return this->QWidget::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QContextMenuEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        return this->QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

int QWidgetWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        return this->QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        return this->QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::dragEnterEvent(QDragEnterEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragEnterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragEnterEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dragLeaveEvent(QDragLeaveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragLeaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragLeaveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dragMoveEvent(QDragMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dragMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDragMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::dropEvent(QDropEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        return this->QWidget::dropEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QDropEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::enterEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        return this->QWidget::enterEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWidgetWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        return this->QWidget::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

bool QWidgetWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        return this->QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter<QObject * >::toPython(arg__1),
        Shiboken::Converter<QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::focusInEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusInEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

bool QWidgetWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        return this->QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter<bool >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::focusOutEvent(QFocusEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        return this->QWidget::focusOutEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QFocusEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QWidgetWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        return this->QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::hideEvent(QHideEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        return this->QWidget::hideEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QHideEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::inputMethodEvent(QInputMethodEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QInputMethodEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QWidgetWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        return this->QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter<QVariant >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::keyReleaseEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::keyReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QKeyEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        return this->QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::leaveEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::leaveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

int QWidgetWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        return this->QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter<int >::toCpp(pyResult));
    return cppResult;
}

QSize QWidgetWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        return this->QWidget::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.minimumSizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::mouseDoubleClickEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseDoubleClickEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mouseMoveEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseMoveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mousePressEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mousePressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::mouseReleaseEvent(QMouseEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        return this->QWidget::mouseReleaseEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMouseEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::moveEvent(QMoveEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        return this->QWidget::moveEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QMoveEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QWidgetWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        return this->QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.paintEngine", SbkType<QPaintEngine * >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter<QPaintEngine * >::toCpp(pyResult));
    if (pyResult->ob_refcnt < 2) {
        PyErr_SetString(PyExc_ReferenceError, "Returning last python reference on virutal function: QWidget.paintEngine");
        PyErr_Print();
        assert(false);
    }
    return cppResult;
}

void QWidgetWrapper::paintEvent(QPaintEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        return this->QWidget::paintEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QPaintEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::resizeEvent(QResizeEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        return this->QWidget::resizeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QResizeEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        return this->QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        return this->QWidget::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QShowEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QWidgetWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        return this->QWidget::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter<QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWidget.sizeHint", SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter<QSize >::toCpp(pyResult));
    return cppResult;
}

void QWidgetWrapper::tabletEvent(QTabletEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        return this->QWidget::tabletEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTabletEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

void QWidgetWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        return this->QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
}

void QWidgetWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        return this->QWidget::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter<QWheelEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    BindingManager::instance().invalidateWrapper(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QWidgetWrapper::metaObject() const
{
    if (!m_metaObject) {
        PyObject *pySelf = BindingManager::instance().retrieveWrapper(this);
        void *typeData = Shiboken::getTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf));
        if (!typeData) {
            m_metaObject = PySide::DynamicQMetaObject::createBasedOn(pySelf, pySelf->ob_type, &QWidget::staticMetaObject);
            Shiboken::setTypeUserData(reinterpret_cast<Shiboken::SbkBaseWrapper*>(pySelf), m_metaObject, PySide::deleteDynamicQMetaObject);
        } else {
            m_metaObject = reinterpret_cast<PySide::DynamicQMetaObject*>(typeData);
        }
    }
    return m_metaObject;
}

int QWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QWidgetWrapper::~QWidgetWrapper()
{
    BindingManager::instance().invalidateWrapper(this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
SbkQWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::isUserType(self) && !Shiboken::canCallConstructor(self->ob_type, Shiboken::SbkType<QWidget >()))
        return -1;

    QWidgetWrapper* cptr = 0;
    int overloadId = -1;
    SbkBaseWrapper* sbkSelf = reinterpret_cast<SbkBaseWrapper*>(self);
    SbkBaseWrapperType* type = reinterpret_cast<SbkBaseWrapperType*>(self->ob_type);
    SbkBaseWrapperType* myType = reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]);
    if (type != myType) {
        type->mi_init = myType->mi_init;
        type->mi_offsets = myType->mi_offsets;
        type->mi_specialcast = myType->mi_specialcast;
    }


    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "f", "parent" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                propertyKeys.push_back(argName);
            }
        }
    }

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QWidget", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QWidget(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QWidget(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidget_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "f";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return -1;
            QWidget* cpp_arg0 = pyargs[0] ? Shiboken::Converter<QWidget* >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
            // QWidget(QWidget*,QFlags<Qt::WindowType>)
            cptr = new QWidgetWrapper(cpp_arg0, cpp_arg1);
            Shiboken::setParent(pyargs[0], self);
            }
        }
        }
    if (PyErr_Occurred() || !Shiboken::setCppPointer(sbkSelf, Shiboken::SbkType<QWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto SbkQWidget_Init_TypeError;

    sbkSelf->validCppObject = 1;
    sbkSelf->containsCppWrapper = 1;
    BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::signalUpdateSource(self);
    cptr->metaObject();
    for (std::vector<PyObject*>::size_type i = 0; i < propertyKeys.size(); i++) {
        const char* propName = PyString_AS_STRING(propertyKeys[i]);
        const QMetaObject* mo = cptr->metaObject();
        if (mo->indexOfProperty(propName) != -1) {
            cptr->setProperty(propName, Shiboken::Converter<QVariant>::toCpp(PyDict_GetItem(kwds, propertyKeys[i])));
        } else {
            QString signalSignature = QString("%1()").arg(propName);
            if (mo->indexOfSignal(qPrintable(signalSignature)) != -1) {
                signalSignature = '2' + signalSignature;
                PySide::signal_connect(self, qPrintable(signalSignature), PyDict_GetItem(kwds, propertyKeys[i]));
            } else {
                delete cptr;
                PyErr_Format(PyExc_AttributeError, "'%s' is not a Qt property or a signal", propName);
                return -1;
            };
        }
    }


    return 1;

    SbkQWidget_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget", overloads);
        return -1;
}

static PyObject* SbkQWidgetFunc_acceptDrops(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // acceptDrops()const
            bool cppResult = cppSelf->QWidget::acceptDrops();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_accessibleDescription(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // accessibleDescription()const
            QString cppResult = cppSelf->QWidget::accessibleDescription();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_accessibleName(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // accessibleName()const
            QString cppResult = cppSelf->QWidget::accessibleName();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_actionEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: actionEvent(QActionEvent*)
    if (Shiboken::Converter<QActionEvent * >::isConvertible(arg)) {
        overloadId = 0; // actionEvent(QActionEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_actionEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QActionEvent* cpp_arg0 = Shiboken::Converter<QActionEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // actionEvent(QActionEvent*)
            cppSelf->QWidget::actionEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_actionEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QActionEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.actionEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_actions(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // actions()const
            QList<QAction * > cppResult = cppSelf->QWidget::actions();
            pyResult = Shiboken::Converter<QList<QAction * > >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_activateWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // activateWindow()
            cppSelf->QWidget::activateWindow();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_addAction(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addAction(QAction*)
    if (Shiboken::Converter<QAction * >::isConvertible(arg)) {
        overloadId = 0; // addAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_addAction_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addAction(QAction*)
            cppSelf->QWidget::addAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_addAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.addAction", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_addActions(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addActions(QList<QAction*>)
    if (Shiboken::Converter<QList<QAction * > >::isConvertible(arg)) {
        overloadId = 0; // addActions(QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_addActions_TypeError;

    // Call function/method
    {
        {
            QList<QAction * > cpp_arg0 = Shiboken::Converter<QList<QAction * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // addActions(QList<QAction*>)
            cppSelf->QWidget::addActions(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_addActions_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.addActions", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_adjustSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // adjustSize()
            cppSelf->QWidget::adjustSize();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_autoFillBackground(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // autoFillBackground()const
            bool cppResult = cppSelf->QWidget::autoFillBackground();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_backgroundRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // backgroundRole()const
            QPalette::ColorRole cppResult = cppSelf->QWidget::backgroundRole();
            pyResult = Shiboken::Converter<QPalette::ColorRole >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_baseSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // baseSize()const
            QSize cppResult = cppSelf->QWidget::baseSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_changeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_changeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // changeEvent(QEvent*)
            cppSelf->QWidget::changeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_changeEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.changeEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_childAt(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "childAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: childAt(QPoint)const
    // 1: childAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // childAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // childAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_childAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // childAt(QPoint)const
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // childAt(QPoint)const
                QWidget * cppResult = cppSelf->QWidget::childAt(*cpp_arg0);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
            case 1: // childAt(int,int)const
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // childAt(int,int)const
                QWidget * cppResult = cppSelf->QWidget::childAt(cpp_arg0, cpp_arg1);
                pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
                Shiboken::setParent(self, pyResult);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_childAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.childAt", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_childrenRect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childrenRect()const
            QRect cppResult = cppSelf->QWidget::childrenRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_childrenRegion(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // childrenRegion()const
            QRegion cppResult = cppSelf->QWidget::childrenRegion();
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_clearFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearFocus()
            cppSelf->QWidget::clearFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_clearMask(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // clearMask()
            cppSelf->QWidget::clearMask();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_close(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // close()
            bool cppResult = cppSelf->QWidget::close();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_closeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closeEvent(QCloseEvent*)
    if (Shiboken::Converter<QCloseEvent * >::isConvertible(arg)) {
        overloadId = 0; // closeEvent(QCloseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_closeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QCloseEvent* cpp_arg0 = Shiboken::Converter<QCloseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // closeEvent(QCloseEvent*)
            cppSelf->QWidget::closeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_closeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCloseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.closeEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_contentsMargins(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentsMargins()const
            QMargins cppResult = cppSelf->QWidget::contentsMargins();
            pyResult = Shiboken::Converter<QMargins >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_contentsRect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contentsRect()const
            QRect cppResult = cppSelf->QWidget::contentsRect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter<QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QContextMenuEvent* cpp_arg0 = Shiboken::Converter<QContextMenuEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // contextMenuEvent(QContextMenuEvent*)
            cppSelf->QWidget::contextMenuEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.contextMenuEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_contextMenuPolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // contextMenuPolicy()const
            Qt::ContextMenuPolicy cppResult = cppSelf->QWidget::contextMenuPolicy();
            pyResult = Shiboken::Converter<Qt::ContextMenuPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_createWinId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // createWinId()
            cppSelf->QWidget::createWinId();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_cursor(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // cursor()const
            QCursor cppResult = cppSelf->QWidget::cursor();
            pyResult = Shiboken::Converter<QCursor >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_destroy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "destroySubWindows", "destroyWindow" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 2, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.destroy(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.destroy(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:destroy", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: destroy(bool,bool)
    if (numArgs == 0) {
        overloadId = 0; // destroy(bool,bool)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // destroy(bool,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // destroy(bool,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_destroy_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "destroyWindow");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "destroyWindow";
                    else
                        pyargs[0] = value;
                }
                value = PyDict_GetItemString(kwds, "destroySubWindows");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "destroySubWindows";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.destroy(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cpp_arg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // destroy(bool,bool)
            cppSelf->QWidget::destroy(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_destroy_TypeError:
        const char* overloads[] = {"bool = true, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.destroy", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_devType(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // devType()const
            int cppResult = cppSelf->QWidget::devType();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_dragEnterEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragEnterEvent(QDragEnterEvent*)
    if (Shiboken::Converter<QDragEnterEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_dragEnterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragEnterEvent* cpp_arg0 = Shiboken::Converter<QDragEnterEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragEnterEvent(QDragEnterEvent*)
            cppSelf->QWidget::dragEnterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_dragEnterEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragEnterEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragEnterEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_dragLeaveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragLeaveEvent(QDragLeaveEvent*)
    if (Shiboken::Converter<QDragLeaveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_dragLeaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragLeaveEvent* cpp_arg0 = Shiboken::Converter<QDragLeaveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragLeaveEvent(QDragLeaveEvent*)
            cppSelf->QWidget::dragLeaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_dragLeaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragLeaveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragLeaveEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_dragMoveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dragMoveEvent(QDragMoveEvent*)
    if (Shiboken::Converter<QDragMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_dragMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDragMoveEvent* cpp_arg0 = Shiboken::Converter<QDragMoveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dragMoveEvent(QDragMoveEvent*)
            cppSelf->QWidget::dragMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_dragMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDragMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dragMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter<QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QDropEvent* cpp_arg0 = Shiboken::Converter<QDropEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // dropEvent(QDropEvent*)
            cppSelf->QWidget::dropEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.dropEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_effectiveWinId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // effectiveWinId()const
            unsigned long cppResult = cppSelf->QWidget::effectiveWinId();
            pyResult = Shiboken::Converter<unsigned long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_ensurePolished(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // ensurePolished()const
            cppSelf->QWidget::ensurePolished();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_enterEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: enterEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // enterEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_enterEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // enterEvent(QEvent*)
            cppSelf->QWidget::enterEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_enterEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.enterEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_event(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_event_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // event(QEvent*)
            bool cppResult = cppSelf->QWidget::event(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.event", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_focusInEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusInEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_focusInEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusInEvent(QFocusEvent*)
            cppSelf->QWidget::focusInEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_focusInEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusInEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_focusNextChild(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusNextChild()
            bool cppResult = cppSelf->QWidget::focusNextChild();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusNextPrevChild(bool)
            bool cppResult = cppSelf->QWidget::focusNextPrevChild(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_focusOutEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusOutEvent(QFocusEvent*)
    if (Shiboken::Converter<QFocusEvent * >::isConvertible(arg)) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_focusOutEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QFocusEvent* cpp_arg0 = Shiboken::Converter<QFocusEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // focusOutEvent(QFocusEvent*)
            cppSelf->QWidget::focusOutEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_focusOutEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFocusEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.focusOutEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_focusPolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusPolicy()const
            Qt::FocusPolicy cppResult = cppSelf->QWidget::focusPolicy();
            pyResult = Shiboken::Converter<Qt::FocusPolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_focusPreviousChild(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusPreviousChild()
            bool cppResult = cppSelf->QWidget::focusPreviousChild();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_focusProxy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusProxy()const
            QWidget * cppResult = cppSelf->QWidget::focusProxy();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_focusWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // focusWidget()const
            QWidget * cppResult = cppSelf->QWidget::focusWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_font(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // font()const
            const QFont & cppResult = cppSelf->QWidget::font();
            pyResult = Shiboken::Converter<const QFont & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_fontInfo(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontInfo()const
            QFontInfo cppResult = cppSelf->QWidget::fontInfo();
            pyResult = Shiboken::Converter<QFontInfo >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_fontMetrics(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // fontMetrics()const
            QFontMetrics cppResult = cppSelf->QWidget::fontMetrics();
            pyResult = Shiboken::Converter<QFontMetrics >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_foregroundRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // foregroundRole()const
            QPalette::ColorRole cppResult = cppSelf->QWidget::foregroundRole();
            pyResult = Shiboken::Converter<QPalette::ColorRole >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_frameGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frameGeometry()const
            QRect cppResult = cppSelf->QWidget::frameGeometry();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_frameSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // frameSize()const
            QSize cppResult = cppSelf->QWidget::frameSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_geometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // geometry()const
            const QRect & cppResult = cppSelf->QWidget::geometry();
            pyResult = Shiboken::Converter<const QRect & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_grabGesture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "flags" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:grabGesture", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
    if (Shiboken::Converter<Qt::GestureType >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
        } else if (Shiboken::Converter<QFlags<Qt::GestureFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_grabGesture_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabGesture(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::GestureType cpp_arg0 = Shiboken::Converter<Qt::GestureType >::toCpp(pyargs[0]);
            QFlags<Qt::GestureFlag> cpp_arg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::GestureFlag> >::toCpp(pyargs[1]) : Qt::GestureFlags();

            if(!PyErr_Occurred()) {
            // grabGesture(Qt::GestureType,QFlags<Qt::GestureFlag>)
            cppSelf->QWidget::grabGesture(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_grabGesture_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GestureType, PySide.QtCore.Qt.GestureFlags = Qt.GestureFlags()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.grabGesture", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_grabKeyboard(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // grabKeyboard()
            cppSelf->QWidget::grabKeyboard();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_grabMouse(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: grabMouse()
    // 1: grabMouse(QCursor)
    if (numArgs == 0) {
        overloadId = 0; // grabMouse()
    } else if (Shiboken::Converter<const QCursor & >::isConvertible(arg)) {
        overloadId = 1; // grabMouse(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_grabMouse_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // grabMouse()
            {

                if(!PyErr_Occurred()) {
                // grabMouse()
                cppSelf->QWidget::grabMouse();
                }
                break;
            }
            case 1: // grabMouse(QCursor)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QCursor > cpp_arg0_auto_ptr;
                QCursor* cpp_arg0 = Shiboken::Converter<QCursor* >::toCpp(arg);
                if (!Shiboken::Converter<QCursor >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QCursor >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // grabMouse(QCursor)
                cppSelf->QWidget::grabMouse(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_grabMouse_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.grabMouse", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_grabShortcut(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "context" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:grabShortcut", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: grabShortcut(QKeySequence,Qt::ShortcutContext)
    if (Shiboken::Converter<const QKeySequence & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        } else if (Shiboken::Converter<Qt::ShortcutContext >::isConvertible(pyargs[1])) {
            overloadId = 0; // grabShortcut(QKeySequence,Qt::ShortcutContext)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_grabShortcut_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "context");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "context";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.grabShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            std::auto_ptr<QKeySequence > cpp_arg0_auto_ptr;
            QKeySequence* cpp_arg0 = Shiboken::Converter<QKeySequence* >::toCpp(pyargs[0]);
            if (!Shiboken::Converter<QKeySequence >::checkType(pyargs[0]))
                cpp_arg0_auto_ptr = std::auto_ptr<QKeySequence >(cpp_arg0);
            Qt::ShortcutContext cpp_arg1 = pyargs[1] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[1]) : Qt::WindowShortcut;

            if(!PyErr_Occurred()) {
            // grabShortcut(QKeySequence,Qt::ShortcutContext)
            int cppResult = cppSelf->QWidget::grabShortcut(*cpp_arg0, cpp_arg1);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_grabShortcut_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.grabShortcut", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_graphicsEffect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // graphicsEffect()const
            QGraphicsEffect * cppResult = cppSelf->QWidget::graphicsEffect();
            pyResult = Shiboken::Converter<QGraphicsEffect * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_graphicsProxyWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // graphicsProxyWidget()const
            QGraphicsProxyWidget * cppResult = cppSelf->QWidget::graphicsProxyWidget();
            pyResult = Shiboken::Converter<QGraphicsProxyWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_hasFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasFocus()const
            bool cppResult = cppSelf->QWidget::hasFocus();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_hasMouseTracking(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hasMouseTracking()const
            bool cppResult = cppSelf->QWidget::hasMouseTracking();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_height(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // height()const
            int cppResult = cppSelf->QWidget::height();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_heightForWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: heightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // heightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_heightForWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // heightForWidth(int)const
            int cppResult = cppSelf->QWidget::heightForWidth(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_heightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.heightForWidth", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_hide(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // hide()
            cppSelf->QWidget::hide();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_hideEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hideEvent(QHideEvent*)
    if (Shiboken::Converter<QHideEvent * >::isConvertible(arg)) {
        overloadId = 0; // hideEvent(QHideEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_hideEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QHideEvent* cpp_arg0 = Shiboken::Converter<QHideEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // hideEvent(QHideEvent*)
            cppSelf->QWidget::hideEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_hideEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QHideEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.hideEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_inputContext(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inputContext()
            QInputContext * cppResult = cppSelf->QWidget::inputContext();
            pyResult = Shiboken::Converter<QInputContext * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_inputMethodEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodEvent(QInputMethodEvent*)
    if (Shiboken::Converter<QInputMethodEvent * >::isConvertible(arg)) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_inputMethodEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputMethodEvent* cpp_arg0 = Shiboken::Converter<QInputMethodEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodEvent(QInputMethodEvent*)
            cppSelf->QWidget::inputMethodEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_inputMethodEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.inputMethodEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_inputMethodHints(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // inputMethodHints()const
            QFlags<Qt::InputMethodHint> cppResult = cppSelf->QWidget::inputMethodHints();
            pyResult = Shiboken::Converter<QFlags<Qt::InputMethodHint> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter<Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cpp_arg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = cppSelf->QWidget::inputMethodQuery(cpp_arg0);
            pyResult = Shiboken::Converter<QVariant >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.inputMethodQuery", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_insertAction(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertAction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertAction(QAction*,QAction*)
    if (numArgs == 2 && Shiboken::Converter<QAction * >::isConvertible(pyargs[0]) && Shiboken::Converter<QAction * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertAction(QAction*,QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_insertAction_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QAction* cpp_arg1 = Shiboken::Converter<QAction* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertAction(QAction*,QAction*)
            cppSelf->QWidget::insertAction(cpp_arg0, cpp_arg1);
            Shiboken::setParent(self, pyargs[1]);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_insertAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction, PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.insertAction", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_insertActions(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertActions", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertActions(QAction*,QList<QAction*>)
    if (numArgs == 2 && Shiboken::Converter<QAction * >::isConvertible(pyargs[0]) && Shiboken::Converter<QList<QAction * > >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertActions(QAction*,QList<QAction*>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_insertActions_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(pyargs[0]);
            QList<QAction * > cpp_arg1 = Shiboken::Converter<QList<QAction * > >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // insertActions(QAction*,QList<QAction*>)
            cppSelf->QWidget::insertActions(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_insertActions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.insertActions", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_isActiveWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isActiveWindow()const
            bool cppResult = cppSelf->QWidget::isActiveWindow();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isAncestorOf(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isAncestorOf(const QWidget*)const
    if (Shiboken::Converter<const QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isAncestorOf(const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_isAncestorOf_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isAncestorOf(const QWidget*)const
            bool cppResult = cppSelf->QWidget::isAncestorOf(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_isAncestorOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isAncestorOf", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_isEnabled(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isEnabled()const
            bool cppResult = cppSelf->QWidget::isEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isEnabledTo(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isEnabledTo(QWidget*)const
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isEnabledTo(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_isEnabledTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isEnabledTo(QWidget*)const
            bool cppResult = cppSelf->QWidget::isEnabledTo(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_isEnabledTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isEnabledTo", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_isFullScreen(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isFullScreen()const
            bool cppResult = cppSelf->QWidget::isFullScreen();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isHidden(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isHidden()const
            bool cppResult = cppSelf->QWidget::isHidden();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isLeftToRight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isLeftToRight()const
            bool cppResult = cppSelf->QWidget::isLeftToRight();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isMaximized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isMaximized()const
            bool cppResult = cppSelf->QWidget::isMaximized();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isMinimized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isMinimized()const
            bool cppResult = cppSelf->QWidget::isMinimized();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isModal(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isModal()const
            bool cppResult = cppSelf->QWidget::isModal();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isRightToLeft(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isRightToLeft()const
            bool cppResult = cppSelf->QWidget::isRightToLeft();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isVisible(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isVisible()const
            bool cppResult = cppSelf->QWidget::isVisible();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isVisibleTo(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isVisibleTo(QWidget*)const
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // isVisibleTo(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_isVisibleTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // isVisibleTo(QWidget*)const
            bool cppResult = cppSelf->QWidget::isVisibleTo(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_isVisibleTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.isVisibleTo", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_isWindow(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWindow()const
            bool cppResult = cppSelf->QWidget::isWindow();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_isWindowModified(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // isWindowModified()const
            bool cppResult = cppSelf->QWidget::isWindowModified();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_keyPressEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyPressEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_keyPressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyPressEvent(QKeyEvent*)
            cppSelf->QWidget::keyPressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_keyPressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.keyPressEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_keyReleaseEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: keyReleaseEvent(QKeyEvent*)
    if (Shiboken::Converter<QKeyEvent * >::isConvertible(arg)) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_keyReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QKeyEvent* cpp_arg0 = Shiboken::Converter<QKeyEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // keyReleaseEvent(QKeyEvent*)
            cppSelf->QWidget::keyReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_keyReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeyEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.keyReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_keyboardGrabber(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // keyboardGrabber()
            QWidget * cppResult = QWidget::keyboardGrabber();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_languageChange(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // languageChange()
            cppSelf->QWidget::languageChange();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_layout(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // layout()const
            QLayout * cppResult = cppSelf->QWidget::layout();
            pyResult = Shiboken::Converter<QLayout * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_layoutDirection(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // layoutDirection()const
            Qt::LayoutDirection cppResult = cppSelf->QWidget::layoutDirection();
            pyResult = Shiboken::Converter<Qt::LayoutDirection >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_leaveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: leaveEvent(QEvent*)
    if (Shiboken::Converter<QEvent * >::isConvertible(arg)) {
        overloadId = 0; // leaveEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_leaveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QEvent* cpp_arg0 = Shiboken::Converter<QEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // leaveEvent(QEvent*)
            cppSelf->QWidget::leaveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_leaveEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.leaveEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_locale(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // locale()const
            QLocale cppResult = cppSelf->QWidget::locale();
            pyResult = Shiboken::Converter<QLocale >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_lower(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // lower()
            cppSelf->QWidget::lower();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_mapFrom(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "mapFrom", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mapFrom(QWidget*,QPoint)const
    if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        overloadId = 0; // mapFrom(QWidget*,QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapFrom_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // mapFrom(QWidget*,QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapFrom(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapFrom_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.mapFrom", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mapFromGlobal(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapFromGlobal(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // mapFromGlobal(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapFromGlobal_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapFromGlobal(QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapFromGlobal(*cpp_arg0);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapFromGlobal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapFromGlobal", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mapFromParent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapFromParent(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // mapFromParent(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapFromParent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapFromParent(QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapFromParent(*cpp_arg0);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapFromParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapFromParent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mapTo(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "mapTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mapTo(QWidget*,QPoint)const
    if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        overloadId = 0; // mapTo(QWidget*,QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapTo_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // mapTo(QWidget*,QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapTo(cpp_arg0, *cpp_arg1);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.mapTo", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mapToGlobal(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToGlobal(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // mapToGlobal(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapToGlobal_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapToGlobal(QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapToGlobal(*cpp_arg0);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapToGlobal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapToGlobal", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mapToParent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToParent(QPoint)const
    if (Shiboken::Converter<const QPoint & >::isConvertible(arg)) {
        overloadId = 0; // mapToParent(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mapToParent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mapToParent(QPoint)const
            QPoint cppResult = cppSelf->QWidget::mapToParent(*cpp_arg0);
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_mapToParent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mapToParent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mask(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mask()const
            QRegion cppResult = cppSelf->QWidget::mask();
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_maximumHeight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumHeight()const
            int cppResult = cppSelf->QWidget::maximumHeight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_maximumSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumSize()const
            QSize cppResult = cppSelf->QWidget::maximumSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_maximumWidth(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // maximumWidth()const
            int cppResult = cppSelf->QWidget::maximumWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_metric(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cpp_arg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // metric(QPaintDevice::PaintDeviceMetric)const
            int cppResult = cppSelf->QWidget::metric(cpp_arg0);
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.metric", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_minimumHeight(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumHeight()const
            int cppResult = cppSelf->QWidget::minimumHeight();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_minimumSize(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumSize()const
            QSize cppResult = cppSelf->QWidget::minimumSize();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_minimumSizeHint(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumSizeHint()const
            QSize cppResult = cppSelf->QWidget::minimumSizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_minimumWidth(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // minimumWidth()const
            int cppResult = cppSelf->QWidget::minimumWidth();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseDoubleClickEvent(QMouseEvent*)
            cppSelf->QWidget::mouseDoubleClickEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mouseGrabber(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // mouseGrabber()
            QWidget * cppResult = QWidget::mouseGrabber();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseMoveEvent(QMouseEvent*)
            cppSelf->QWidget::mouseMoveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mousePressEvent(QMouseEvent*)
            cppSelf->QWidget::mousePressEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mousePressEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter<QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMouseEvent* cpp_arg0 = Shiboken::Converter<QMouseEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // mouseReleaseEvent(QMouseEvent*)
            cppSelf->QWidget::mouseReleaseEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_move(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "move", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: move(QPoint)
    // 1: move(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // move(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[0])) {
        overloadId = 0; // move(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_move_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // move(QPoint)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPoint* cpp_arg0 = Shiboken::Converter<QPoint* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // move(QPoint)
                cppSelf->QWidget::move(*cpp_arg0);
                }
                break;
            }
            case 1: // move(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // move(int,int)
                cppSelf->QWidget::move(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_move_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.move", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_moveEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveEvent(QMoveEvent*)
    if (Shiboken::Converter<QMoveEvent * >::isConvertible(arg)) {
        overloadId = 0; // moveEvent(QMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_moveEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QMoveEvent* cpp_arg0 = Shiboken::Converter<QMoveEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // moveEvent(QMoveEvent*)
            cppSelf->QWidget::moveEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_moveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMoveEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.moveEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_nativeParentWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nativeParentWidget()const
            QWidget * cppResult = cppSelf->QWidget::nativeParentWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_nextInFocusChain(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // nextInFocusChain()const
            QWidget * cppResult = cppSelf->QWidget::nextInFocusChain();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_normalGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // normalGeometry()const
            QRect cppResult = cppSelf->QWidget::normalGeometry();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_overrideWindowFlags(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: overrideWindowFlags(QFlags<Qt::WindowType>)
    if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(arg)) {
        overloadId = 0; // overrideWindowFlags(QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_overrideWindowFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowType> cpp_arg0 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // overrideWindowFlags(QFlags<Qt::WindowType>)
            cppSelf->QWidget::overrideWindowFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_overrideWindowFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.overrideWindowFlags", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_overrideWindowState(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: overrideWindowState(QFlags<Qt::WindowState>)
    if (Shiboken::Converter<QFlags<Qt::WindowState> >::isConvertible(arg)) {
        overloadId = 0; // overrideWindowState(QFlags<Qt::WindowState>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_overrideWindowState_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowState> cpp_arg0 = Shiboken::Converter<QFlags<Qt::WindowState> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // overrideWindowState(QFlags<Qt::WindowState>)
            cppSelf->QWidget::overrideWindowState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_overrideWindowState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowStates", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.overrideWindowState", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_paintEngine(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // paintEngine()const
            QPaintEngine * cppResult = cppSelf->QWidget::paintEngine();
            pyResult = Shiboken::Converter<QPaintEngine * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter<QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QPaintEvent* cpp_arg0 = Shiboken::Converter<QPaintEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // paintEvent(QPaintEvent*)
            cppSelf->QWidget::paintEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.paintEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_palette(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // palette()const
            const QPalette & cppResult = cppSelf->QWidget::palette();
            pyResult = Shiboken::Converter<const QPalette & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_parentWidget(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // parentWidget()const
            QWidget * cppResult = cppSelf->QWidget::parentWidget();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);

            // Ownership transferences.
            SbkBaseWrapper_setOwnership(pyResult, true);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_pos(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // pos()const
            QPoint cppResult = cppSelf->QWidget::pos();
            pyResult = Shiboken::Converter<QPoint >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_previousInFocusChain(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // previousInFocusChain()const
            QWidget * cppResult = cppSelf->QWidget::previousInFocusChain();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_raise_(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // raise()
            cppSelf->QWidget::raise();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_rect(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // rect()const
            QRect cppResult = cppSelf->QWidget::rect();
            pyResult = Shiboken::Converter<QRect >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_releaseKeyboard(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // releaseKeyboard()
            cppSelf->QWidget::releaseKeyboard();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_releaseMouse(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // releaseMouse()
            cppSelf->QWidget::releaseMouse();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_releaseShortcut(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: releaseShortcut(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // releaseShortcut(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_releaseShortcut_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // releaseShortcut(int)
            cppSelf->QWidget::releaseShortcut(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_releaseShortcut_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.releaseShortcut", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_removeAction(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAction(QAction*)
    if (Shiboken::Converter<QAction * >::isConvertible(arg)) {
        overloadId = 0; // removeAction(QAction*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_removeAction_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QAction* cpp_arg0 = Shiboken::Converter<QAction* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // removeAction(QAction*)
            cppSelf->QWidget::removeAction(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_removeAction_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.removeAction", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_render(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "renderFlags", "sourceRegion", "targetOffset" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 3, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.render(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.render(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.render(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:render", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
    // 1: render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
    if (numArgs >= 2 && Shiboken::Converter<QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
        } else if (Shiboken::Converter<const QRegion & >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            } else if (Shiboken::Converter<QFlags<QWidget::RenderFlag> >::isConvertible(pyargs[3])) {
                overloadId = 1; // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            }
        }
    } else if (Shiboken::Converter<QPaintDevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
        } else if (Shiboken::Converter<const QPoint & >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            } else if (Shiboken::Converter<const QRegion & >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                } else if (Shiboken::Converter<QFlags<QWidget::RenderFlag> >::isConvertible(pyargs[3])) {
                    overloadId = 0; // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_render_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "targetOffset");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "targetOffset";
                        else
                            pyargs[1] = value;
                    }
                    value = PyDict_GetItemString(kwds, "sourceRegion");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sourceRegion";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "renderFlags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "renderFlags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPaintDevice* cpp_arg0 = Shiboken::Converter<QPaintDevice* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint cpp_arg1_tmp = QPoint();
                QPoint* cpp_arg1 = pyargs[1] ? Shiboken::Converter<QPoint* >::toCpp(pyargs[1]) : &cpp_arg1_tmp;
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg2_auto_ptr;
                QRegion cpp_arg2_tmp = QRegion();
                QRegion* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegion* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QRegion >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRegion >(cpp_arg2);
                QFlags<QWidget::RenderFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QWidget::RenderFlag> >::toCpp(pyargs[3]) : QWidget::RenderFlags(QWidget::DrawWindowBackground |QWidget:: DrawChildren);

                if(!PyErr_Occurred()) {
                // render(QPaintDevice*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                cppSelf->QWidget::render(cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
            case 1: // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "sourceRegion");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "sourceRegion";
                        else
                            pyargs[2] = value;
                    }
                    value = PyDict_GetItemString(kwds, "renderFlags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "renderFlags";
                        else
                            pyargs[3] = value;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.render(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QPainter* cpp_arg0 = Shiboken::Converter<QPainter* >::toCpp(pyargs[0]);
                if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                    return 0;
                QPoint* cpp_arg1 = Shiboken::Converter<QPoint* >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg2_auto_ptr;
                QRegion cpp_arg2_tmp = QRegion();
                QRegion* cpp_arg2 = pyargs[2] ? Shiboken::Converter<QRegion* >::toCpp(pyargs[2]) : &cpp_arg2_tmp;
                if (pyargs[2] && !Shiboken::Converter<QRegion >::checkType(pyargs[2]))
                    cpp_arg2_auto_ptr = std::auto_ptr<QRegion >(cpp_arg2);
                QFlags<QWidget::RenderFlag> cpp_arg3 = pyargs[3] ? Shiboken::Converter<QFlags<QWidget::RenderFlag> >::toCpp(pyargs[3]) : QWidget::RenderFlags(QWidget::DrawWindowBackground |QWidget:: DrawChildren);

                if(!PyErr_Occurred()) {
                // render(QPainter*,QPoint,QRegion,QFlags<QWidget::RenderFlag>)
                cppSelf->QWidget::render(cpp_arg0, *cpp_arg1, *cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice, PySide.QtCore.QPoint = QPoint(), PySide.QtGui.QRegion = QRegion(), PySide.QtGui.QWidget.RenderFlags = QWidget.RenderFlags(DrawWindowBackground | DrawChildren)", "PySide.QtGui.QPainter, PySide.QtCore.QPoint, PySide.QtGui.QRegion = QRegion(), PySide.QtGui.QWidget.RenderFlags = QWidget.RenderFlags(DrawWindowBackground | DrawChildren)", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.render", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_repaint(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQWidgetFunc_repaint_TypeError;

    if (!PyArg_UnpackTuple(args, "repaint", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: repaint()
    // 1: repaint(QRect)
    // 2: repaint(QRegion)
    // 3: repaint(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // repaint()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 3; // repaint(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 1; // repaint(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRegion & >::isConvertible(pyargs[0])) {
        overloadId = 2; // repaint(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_repaint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // repaint()
            {

                if(!PyErr_Occurred()) {
                // repaint()
                cppSelf->QWidget::repaint();
                }
                break;
            }
            case 1: // repaint(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // repaint(QRect)
                cppSelf->QWidget::repaint(*cpp_arg0);
                }
                break;
            }
            case 2: // repaint(QRegion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRegion >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // repaint(QRegion)
                cppSelf->QWidget::repaint(*cpp_arg0);
                }
                break;
            }
            case 3: // repaint(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // repaint(int,int,int,int)
                cppSelf->QWidget::repaint(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_repaint_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", "PySide.QtGui.QRegion", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.repaint", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_resetInputContext(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // resetInputContext()
            cppSelf->QWidget::resetInputContext();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_resize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resize(QSize)
    // 1: resize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // resize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // resize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_resize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resize(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // resize(QSize)
                cppSelf->QWidget::resize(*cpp_arg0);
                }
                break;
            }
            case 1: // resize(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // resize(int,int)
                cppSelf->QWidget::resize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_resize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.resize", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_resizeEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeEvent(QResizeEvent*)
    if (Shiboken::Converter<QResizeEvent * >::isConvertible(arg)) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_resizeEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QResizeEvent* cpp_arg0 = Shiboken::Converter<QResizeEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // resizeEvent(QResizeEvent*)
            cppSelf->QWidget::resizeEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_resizeEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QResizeEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.resizeEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_restoreGeometry(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreGeometry(QByteArray)
    if (Shiboken::Converter<const QByteArray & >::isConvertible(arg)) {
        overloadId = 0; // restoreGeometry(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_restoreGeometry_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QByteArray > cpp_arg0_auto_ptr;
            QByteArray* cpp_arg0 = Shiboken::Converter<QByteArray* >::toCpp(arg);
            if (!Shiboken::Converter<QByteArray >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QByteArray >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // restoreGeometry(QByteArray)
            bool cppResult = cppSelf->QWidget::restoreGeometry(*cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_restoreGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.restoreGeometry", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_saveGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // saveGeometry()const
            QByteArray cppResult = cppSelf->QWidget::saveGeometry();
            pyResult = Shiboken::Converter<QByteArray >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_scroll(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scroll", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: scroll(int,int)
    // 1: scroll(int,int,QRect)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // scroll(int,int)
        } else if (numArgs == 3 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[2])) {
            overloadId = 1; // scroll(int,int,QRect)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_scroll_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scroll(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // scroll(int,int)
                cppSelf->QWidget::scroll(cpp_arg0, cpp_arg1);
                }
                break;
            }
            case 1: // scroll(int,int,QRect)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (Shiboken::cppObjectIsInvalid(pyargs[2]))
                    return 0;
                QRect* cpp_arg2 = Shiboken::Converter<QRect* >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                // scroll(int,int,QRect)
                cppSelf->QWidget::scroll(cpp_arg0, cpp_arg1, *cpp_arg2);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_scroll_TypeError:
        const char* overloads[] = {"int, int", "int, int, PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.scroll", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setAcceptDrops(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAcceptDrops(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAcceptDrops(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setAcceptDrops_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAcceptDrops(bool)
            cppSelf->QWidget::setAcceptDrops(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setAcceptDrops_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAcceptDrops", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setAccessibleDescription(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleDescription(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setAccessibleDescription_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAccessibleDescription(QString)
            cppSelf->QWidget::setAccessibleDescription(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setAccessibleDescription_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAccessibleDescription", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setAccessibleName(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAccessibleName(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setAccessibleName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setAccessibleName_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAccessibleName(QString)
            cppSelf->QWidget::setAccessibleName(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setAccessibleName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAccessibleName", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setAttribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "on" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setAttribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(Qt::WidgetAttribute,bool)
    if (Shiboken::Converter<Qt::WidgetAttribute >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setAttribute(Qt::WidgetAttribute,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setAttribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::WidgetAttribute cpp_arg0 = Shiboken::Converter<Qt::WidgetAttribute >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setAttribute(Qt::WidgetAttribute,bool)
            cppSelf->QWidget::setAttribute(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WidgetAttribute, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setAttribute", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setAutoFillBackground(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoFillBackground(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoFillBackground(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setAutoFillBackground_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setAutoFillBackground(bool)
            cppSelf->QWidget::setAutoFillBackground(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setAutoFillBackground_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setAutoFillBackground", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setBackgroundRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackgroundRole(QPalette::ColorRole)
    if (Shiboken::Converter<QPalette::ColorRole >::isConvertible(arg)) {
        overloadId = 0; // setBackgroundRole(QPalette::ColorRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setBackgroundRole_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorRole cpp_arg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setBackgroundRole(QPalette::ColorRole)
            cppSelf->QWidget::setBackgroundRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setBackgroundRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setBackgroundRole", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setBaseSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBaseSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBaseSize(QSize)
    // 1: setBaseSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setBaseSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setBaseSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setBaseSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBaseSize(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setBaseSize(QSize)
                cppSelf->QWidget::setBaseSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setBaseSize(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setBaseSize(int,int)
                cppSelf->QWidget::setBaseSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setBaseSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setBaseSize", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setContentsMargins(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQWidgetFunc_setContentsMargins_TypeError;

    if (!PyArg_UnpackTuple(args, "setContentsMargins", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setContentsMargins(QMargins)
    // 1: setContentsMargins(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setContentsMargins(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QMargins & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setContentsMargins(QMargins)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setContentsMargins_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setContentsMargins(QMargins)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QMargins* cpp_arg0 = Shiboken::Converter<QMargins* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setContentsMargins(QMargins)
                cppSelf->QWidget::setContentsMargins(*cpp_arg0);
                }
                break;
            }
            case 1: // setContentsMargins(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setContentsMargins(int,int,int,int)
                cppSelf->QWidget::setContentsMargins(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setContentsMargins_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMargins", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setContentsMargins", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setContextMenuPolicy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContextMenuPolicy(Qt::ContextMenuPolicy)
    if (Shiboken::Converter<Qt::ContextMenuPolicy >::isConvertible(arg)) {
        overloadId = 0; // setContextMenuPolicy(Qt::ContextMenuPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setContextMenuPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::ContextMenuPolicy cpp_arg0 = Shiboken::Converter<Qt::ContextMenuPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setContextMenuPolicy(Qt::ContextMenuPolicy)
            cppSelf->QWidget::setContextMenuPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setContextMenuPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ContextMenuPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setContextMenuPolicy", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setCursor(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursor(QCursor)
    if (Shiboken::Converter<const QCursor & >::isConvertible(arg)) {
        overloadId = 0; // setCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setCursor_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QCursor > cpp_arg0_auto_ptr;
            QCursor* cpp_arg0 = Shiboken::Converter<QCursor* >::toCpp(arg);
            if (!Shiboken::Converter<QCursor >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QCursor >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setCursor(QCursor)
            cppSelf->QWidget::setCursor(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setCursor", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setDisabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDisabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDisabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setDisabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setDisabled(bool)
            cppSelf->QWidget::setDisabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setDisabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setDisabled", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setEnabled(bool)
            cppSelf->QWidget::setEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setEnabled", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFixedHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFixedHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFixedHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFixedHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFixedHeight(int)
            cppSelf->QWidget::setFixedHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFixedHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFixedHeight", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFixedSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFixedSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFixedSize(QSize)
    // 1: setFixedSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setFixedSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setFixedSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFixedSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFixedSize(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setFixedSize(QSize)
                cppSelf->QWidget::setFixedSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setFixedSize(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setFixedSize(int,int)
                cppSelf->QWidget::setFixedSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFixedSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setFixedSize", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFixedWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFixedWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFixedWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFixedWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFixedWidth(int)
            cppSelf->QWidget::setFixedWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFixedWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFixedWidth", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFocus(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = (arg == 0 ? 0 : 1);

    // Overloaded function decisor
    // 0: setFocus()
    // 1: setFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // setFocus()
    } else if (Shiboken::Converter<Qt::FocusReason >::isConvertible(arg)) {
        overloadId = 1; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFocus_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFocus()
            {

                if(!PyErr_Occurred()) {
                // setFocus()
                cppSelf->QWidget::setFocus();
                }
                break;
            }
            case 1: // setFocus(Qt::FocusReason)
            {
                Qt::FocusReason cpp_arg0 = Shiboken::Converter<Qt::FocusReason >::toCpp(arg);

                if(!PyErr_Occurred()) {
                // setFocus(Qt::FocusReason)
                cppSelf->QWidget::setFocus(cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFocus_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.FocusReason", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFocus", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFocusPolicy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocusPolicy(Qt::FocusPolicy)
    if (Shiboken::Converter<Qt::FocusPolicy >::isConvertible(arg)) {
        overloadId = 0; // setFocusPolicy(Qt::FocusPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFocusPolicy_TypeError;

    // Call function/method
    {
        {
            Qt::FocusPolicy cpp_arg0 = Shiboken::Converter<Qt::FocusPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFocusPolicy(Qt::FocusPolicy)
            cppSelf->QWidget::setFocusPolicy(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFocusPolicy_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.FocusPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFocusPolicy", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFocusProxy(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFocusProxy(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setFocusProxy(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFocusProxy_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setFocusProxy(QWidget*)
            cppSelf->QWidget::setFocusProxy(cpp_arg0);
            Shiboken::setParent(self, arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFocusProxy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFocusProxy", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setFont(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFont(QFont)
    if (Shiboken::Converter<const QFont & >::isConvertible(arg)) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setFont_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QFont > cpp_arg0_auto_ptr;
            QFont* cpp_arg0 = Shiboken::Converter<QFont* >::toCpp(arg);
            if (!Shiboken::Converter<QFont >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QFont >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setFont(QFont)
            cppSelf->QWidget::setFont(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setFont", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setForegroundRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForegroundRole(QPalette::ColorRole)
    if (Shiboken::Converter<QPalette::ColorRole >::isConvertible(arg)) {
        overloadId = 0; // setForegroundRole(QPalette::ColorRole)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setForegroundRole_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorRole cpp_arg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setForegroundRole(QPalette::ColorRole)
            cppSelf->QWidget::setForegroundRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setForegroundRole_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setForegroundRole", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setGeometry(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQWidgetFunc_setGeometry_TypeError;

    if (!PyArg_UnpackTuple(args, "setGeometry", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setGeometry(QRect)
    // 1: setGeometry(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setGeometry(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setGeometry_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setGeometry(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setGeometry(QRect)
                cppSelf->QWidget::setGeometry(*cpp_arg0);
                }
                break;
            }
            case 1: // setGeometry(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // setGeometry(int,int,int,int)
                cppSelf->QWidget::setGeometry(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setGeometry", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setGraphicsEffect(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsEffect(QGraphicsEffect*)
    if (Shiboken::Converter<QGraphicsEffect * >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsEffect(QGraphicsEffect*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setGraphicsEffect_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QGraphicsEffect* cpp_arg0 = Shiboken::Converter<QGraphicsEffect* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setGraphicsEffect(QGraphicsEffect*)
            cppSelf->QWidget::setGraphicsEffect(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setGraphicsEffect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsEffect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setGraphicsEffect", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setHidden(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHidden(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHidden(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setHidden_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setHidden(bool)
            cppSelf->QWidget::setHidden(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setHidden_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setHidden", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setInputContext(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputContext(QInputContext*)
    if (Shiboken::Converter<QInputContext * >::isConvertible(arg)) {
        overloadId = 0; // setInputContext(QInputContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setInputContext_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QInputContext* cpp_arg0 = Shiboken::Converter<QInputContext* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInputContext(QInputContext*)
            cppSelf->QWidget::setInputContext(cpp_arg0);

            // Ownership transferences.
            BindingManager::instance().transferOwnershipToCpp(arg);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setInputContext_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setInputContext", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setInputMethodHints(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputMethodHints(QFlags<Qt::InputMethodHint>)
    if (Shiboken::Converter<QFlags<Qt::InputMethodHint> >::isConvertible(arg)) {
        overloadId = 0; // setInputMethodHints(QFlags<Qt::InputMethodHint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setInputMethodHints_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::InputMethodHint> cpp_arg0 = Shiboken::Converter<QFlags<Qt::InputMethodHint> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setInputMethodHints(QFlags<Qt::InputMethodHint>)
            cppSelf->QWidget::setInputMethodHints(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setInputMethodHints_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodHints", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setInputMethodHints", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setLayout(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayout(QLayout*)
    if (Shiboken::Converter<QLayout * >::isConvertible(arg)) {
        overloadId = 0; // setLayout(QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setLayout_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QLayout* cpp_arg0 = Shiboken::Converter<QLayout* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLayout(QLayout*)
            // Begin code injection
            
            qwidgetSetLayout(cppSelf, cpp_arg0);
            
            // End of code injection

            cppSelf->QWidget::setLayout(cpp_arg0);

            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLayout", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter<Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cpp_arg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setLayoutDirection(Qt::LayoutDirection)
            cppSelf->QWidget::setLayoutDirection(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLayoutDirection", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setLocale(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocale(QLocale)
    if (Shiboken::Converter<const QLocale & >::isConvertible(arg)) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setLocale_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QLocale > cpp_arg0_auto_ptr;
            QLocale* cpp_arg0 = Shiboken::Converter<QLocale* >::toCpp(arg);
            if (!Shiboken::Converter<QLocale >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QLocale >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setLocale(QLocale)
            cppSelf->QWidget::setLocale(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setLocale_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLocale", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setLocale", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMask(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMask(QBitmap)
    // 1: setMask(QRegion)
    if (Shiboken::Converter<const QBitmap & >::isConvertible(arg)) {
        overloadId = 0; // setMask(QBitmap)
    } else if (Shiboken::Converter<const QRegion & >::isConvertible(arg)) {
        overloadId = 1; // setMask(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMask_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMask(QBitmap)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QBitmap > cpp_arg0_auto_ptr;
                QBitmap* cpp_arg0 = Shiboken::Converter<QBitmap* >::toCpp(arg);
                if (!Shiboken::Converter<QBitmap >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QBitmap >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setMask(QBitmap)
                cppSelf->QWidget::setMask(*cpp_arg0);
                }
                break;
            }
            case 1: // setMask(QRegion)
            {
                if (Shiboken::cppObjectIsInvalid(arg))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(arg);
                if (!Shiboken::Converter<QRegion >::checkType(arg))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // setMask(QRegion)
                cppSelf->QWidget::setMask(*cpp_arg0);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMask_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBitmap", "PySide.QtGui.QRegion", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMask", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMaximumHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMaximumHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumHeight(int)
            cppSelf->QWidget::setMaximumHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMaximumHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMaximumHeight", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMaximumSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMaximumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMaximumSize(QSize)
    // 1: setMaximumSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMaximumSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMaximumSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMaximumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMaximumSize(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setMaximumSize(QSize)
                cppSelf->QWidget::setMaximumSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setMaximumSize(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setMaximumSize(int,int)
                cppSelf->QWidget::setMaximumSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMaximumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setMaximumSize", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMaximumWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMaximumWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMaximumWidth(int)
            cppSelf->QWidget::setMaximumWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMaximumWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMaximumWidth", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMinimumHeight(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMinimumHeight_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMinimumHeight(int)
            cppSelf->QWidget::setMinimumHeight(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMinimumHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMinimumHeight", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMinimumSize(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMinimumSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMinimumSize(QSize)
    // 1: setMinimumSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setMinimumSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setMinimumSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMinimumSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setMinimumSize(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setMinimumSize(QSize)
                cppSelf->QWidget::setMinimumSize(*cpp_arg0);
                }
                break;
            }
            case 1: // setMinimumSize(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setMinimumSize(int,int)
                cppSelf->QWidget::setMinimumSize(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMinimumSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setMinimumSize", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMinimumWidth(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMinimumWidth_TypeError;

    // Call function/method
    {
        {
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMinimumWidth(int)
            cppSelf->QWidget::setMinimumWidth(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMinimumWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMinimumWidth", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setMouseTracking(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMouseTracking(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMouseTracking(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setMouseTracking_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setMouseTracking(bool)
            cppSelf->QWidget::setMouseTracking(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setMouseTracking_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setMouseTracking", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setPalette(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter<const QPalette & >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QPalette > cpp_arg0_auto_ptr;
            QPalette* cpp_arg0 = Shiboken::Converter<QPalette* >::toCpp(arg);
            if (!Shiboken::Converter<QPalette >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QPalette >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setPalette(QPalette)
            cppSelf->QWidget::setPalette(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setPalette", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setParent(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setParent", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setParent(QWidget*)
    // 1: setParent(QWidget*,QFlags<Qt::WindowType>)
    if (Shiboken::Converter<QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setParent(QWidget*)
        } else if (numArgs == 2 && Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 1; // setParent(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setParent_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setParent(QWidget*)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setParent(QWidget*)
                cppSelf->QWidget::setParent(cpp_arg0);
                }
                break;
            }
            case 1: // setParent(QWidget*,QFlags<Qt::WindowType>)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
                QFlags<Qt::WindowType> cpp_arg1 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setParent(QWidget*,QFlags<Qt::WindowType>)
                cppSelf->QWidget::setParent(cpp_arg0, cpp_arg1);
                Shiboken::setParent(pyargs[0], self);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setParent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", "PySide.QtGui.QWidget, PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setParent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setShortcutAutoRepeat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enable" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setShortcutAutoRepeat", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setShortcutAutoRepeat(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setShortcutAutoRepeat(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setShortcutAutoRepeat_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutAutoRepeat(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setShortcutAutoRepeat(int,bool)
            cppSelf->QWidget::setShortcutAutoRepeat(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setShortcutAutoRepeat_TypeError:
        const char* overloads[] = {"int, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setShortcutAutoRepeat", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setShortcutEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    std::vector<PyObject*> propertyKeys;

    // Check existence of named argument.
    if (kwds) {
        std::string argNames[] = { "enable" };
        PyObject* keys = PyDict_Keys(kwds);
        Shiboken::AutoDecRef auto_keys(keys);
        for (int i = 0; i < PyList_GET_SIZE(keys); ++i) {
            PyObject* argName = PyList_GET_ITEM(keys, i);
            if (!std::binary_search(argNames, argNames + 1, std::string(PyString_AS_STRING(argName)))) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): got an unexpected keyword argument '%s'", PyString_AS_STRING(argName));
                return 0;
            }
        }
    }
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setShortcutEnabled", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setShortcutEnabled(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setShortcutEnabled(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setShortcutEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else
                        pyargs[1] = value;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QWidget.setShortcutEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cpp_arg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
            // setShortcutEnabled(int,bool)
            cppSelf->QWidget::setShortcutEnabled(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setShortcutEnabled_TypeError:
        const char* overloads[] = {"int, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setShortcutEnabled", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setSizeIncrement(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSizeIncrement", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSizeIncrement(QSize)
    // 1: setSizeIncrement(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setSizeIncrement(int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QSize & >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSizeIncrement(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setSizeIncrement_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSizeIncrement(QSize)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSize* cpp_arg0 = Shiboken::Converter<QSize* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setSizeIncrement(QSize)
                cppSelf->QWidget::setSizeIncrement(*cpp_arg0);
                }
                break;
            }
            case 1: // setSizeIncrement(int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setSizeIncrement(int,int)
                cppSelf->QWidget::setSizeIncrement(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setSizeIncrement_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setSizeIncrement", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setSizePolicy(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSizePolicy", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSizePolicy(QSizePolicy)
    // 1: setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    if (numArgs == 2 && Shiboken::Converter<QSizePolicy::Policy >::isConvertible(pyargs[0]) && Shiboken::Converter<QSizePolicy::Policy >::isConvertible(pyargs[1])) {
        overloadId = 1; // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    } else if (numArgs == 1 && Shiboken::Converter<QSizePolicy >::isConvertible(pyargs[0])) {
        overloadId = 0; // setSizePolicy(QSizePolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setSizePolicy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setSizePolicy(QSizePolicy)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QSizePolicy* cpp_arg0 = Shiboken::Converter<QSizePolicy* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // setSizePolicy(QSizePolicy)
                cppSelf->QWidget::setSizePolicy(*cpp_arg0);
                }
                break;
            }
            case 1: // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
            {
                QSizePolicy::Policy cpp_arg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[0]);
                QSizePolicy::Policy cpp_arg1 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                // setSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
                cppSelf->QWidget::setSizePolicy(cpp_arg0, cpp_arg1);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setSizePolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setSizePolicy", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setStatusTip(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setStatusTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setStatusTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStatusTip(QString)
            cppSelf->QWidget::setStatusTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setStatusTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStatusTip", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setStyle(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    if (Shiboken::Converter<QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QStyle* cpp_arg0 = Shiboken::Converter<QStyle* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyle(QStyle*)
            cppSelf->QWidget::setStyle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStyle", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setStyleSheet(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyleSheet(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setStyleSheet(QString)
            cppSelf->QWidget::setStyleSheet(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setStyleSheet", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setTabOrder(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTabOrder", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTabOrder(QWidget*,QWidget*)
    if (numArgs == 2 && Shiboken::Converter<QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter<QWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setTabOrder(QWidget*,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setTabOrder_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(pyargs[0]);
            if (Shiboken::cppObjectIsInvalid(pyargs[1]))
                return 0;
            QWidget* cpp_arg1 = Shiboken::Converter<QWidget* >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
            // setTabOrder(QWidget*,QWidget*)
            QWidget::setTabOrder(cpp_arg0, cpp_arg1);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setTabOrder_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.setTabOrder", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setToolTip(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolTip(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setToolTip(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setToolTip_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setToolTip(QString)
            cppSelf->QWidget::setToolTip(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setToolTip_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setToolTip", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setUpdatesEnabled(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUpdatesEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUpdatesEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setUpdatesEnabled_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setUpdatesEnabled(bool)
            cppSelf->QWidget::setUpdatesEnabled(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setUpdatesEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setUpdatesEnabled", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setVisible(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setVisible(bool)
            cppSelf->QWidget::setVisible(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setVisible", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWhatsThis(QString)
            cppSelf->QWidget::setWhatsThis(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWhatsThis", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowFilePath(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowFilePath(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowFilePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowFilePath_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowFilePath(QString)
            cppSelf->QWidget::setWindowFilePath(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowFilePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowFilePath", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowFlags(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowFlags(QFlags<Qt::WindowType>)
    if (Shiboken::Converter<QFlags<Qt::WindowType> >::isConvertible(arg)) {
        overloadId = 0; // setWindowFlags(QFlags<Qt::WindowType>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowFlags_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowType> cpp_arg0 = Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowFlags(QFlags<Qt::WindowType>)
            cppSelf->QWidget::setWindowFlags(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowFlags_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowFlags", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowIcon(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIcon(QIcon)
    if (Shiboken::Converter<const QIcon & >::isConvertible(arg)) {
        overloadId = 0; // setWindowIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowIcon_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            std::auto_ptr<QIcon > cpp_arg0_auto_ptr;
            QIcon* cpp_arg0 = Shiboken::Converter<QIcon* >::toCpp(arg);
            if (!Shiboken::Converter<QIcon >::checkType(arg))
                cpp_arg0_auto_ptr = std::auto_ptr<QIcon >(cpp_arg0);

            if(!PyErr_Occurred()) {
            // setWindowIcon(QIcon)
            cppSelf->QWidget::setWindowIcon(*cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowIcon", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowIconText(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIconText(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowIconText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowIconText_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowIconText(QString)
            cppSelf->QWidget::setWindowIconText(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowIconText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowIconText", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowModality(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowModality(Qt::WindowModality)
    if (Shiboken::Converter<Qt::WindowModality >::isConvertible(arg)) {
        overloadId = 0; // setWindowModality(Qt::WindowModality)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowModality_TypeError;

    // Call function/method
    {
        {
            Qt::WindowModality cpp_arg0 = Shiboken::Converter<Qt::WindowModality >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowModality(Qt::WindowModality)
            cppSelf->QWidget::setWindowModality(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowModality_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowModality", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowModality", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowModified(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowModified(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowModified_TypeError;

    // Call function/method
    {
        {
            bool cpp_arg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowModified(bool)
            cppSelf->QWidget::setWindowModified(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowModified_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowModified", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowOpacity(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowOpacity(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowOpacity_TypeError;

    // Call function/method
    {
        {
            qreal cpp_arg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowOpacity(qreal)
            cppSelf->QWidget::setWindowOpacity(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowOpacity_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowOpacity", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowRole(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowRole(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowRole(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowRole_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowRole(QString)
            cppSelf->QWidget::setWindowRole(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowRole_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowRole", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowState(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowState(QFlags<Qt::WindowState>)
    if (Shiboken::Converter<QFlags<Qt::WindowState> >::isConvertible(arg)) {
        overloadId = 0; // setWindowState(QFlags<Qt::WindowState>)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowState_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::WindowState> cpp_arg0 = Shiboken::Converter<QFlags<Qt::WindowState> >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowState(QFlags<Qt::WindowState>)
            cppSelf->QWidget::setWindowState(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowState_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WindowStates", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowState", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_setWindowTitle(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowTitle(QString)
    if (Shiboken::Converter<QString >::isConvertible(arg)) {
        overloadId = 0; // setWindowTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_setWindowTitle_TypeError;

    // Call function/method
    {
        {
            QString cpp_arg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // setWindowTitle(QString)
            cppSelf->QWidget::setWindowTitle(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_setWindowTitle_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.setWindowTitle", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_show(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // show()
            cppSelf->QWidget::show();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_showEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showEvent(QShowEvent*)
    if (Shiboken::Converter<QShowEvent * >::isConvertible(arg)) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_showEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QShowEvent* cpp_arg0 = Shiboken::Converter<QShowEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // showEvent(QShowEvent*)
            cppSelf->QWidget::showEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_showEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QShowEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.showEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_showFullScreen(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // showFullScreen()
            cppSelf->QWidget::showFullScreen();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_showMaximized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // showMaximized()
            cppSelf->QWidget::showMaximized();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_showMinimized(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // showMinimized()
            cppSelf->QWidget::showMinimized();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_showNormal(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // showNormal()
            cppSelf->QWidget::showNormal();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_size(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // size()const
            QSize cppResult = cppSelf->QWidget::size();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_sizeHint(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeHint()const
            QSize cppResult = cppSelf->QWidget::sizeHint();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_sizeIncrement(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizeIncrement()const
            QSize cppResult = cppSelf->QWidget::sizeIncrement();
            pyResult = Shiboken::Converter<QSize >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_sizePolicy(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // sizePolicy()const
            QSizePolicy cppResult = cppSelf->QWidget::sizePolicy();
            pyResult = Shiboken::Converter<QSizePolicy >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_stackUnder(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: stackUnder(QWidget*)
    if (Shiboken::Converter<QWidget * >::isConvertible(arg)) {
        overloadId = 0; // stackUnder(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_stackUnder_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWidget* cpp_arg0 = Shiboken::Converter<QWidget* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // stackUnder(QWidget*)
            cppSelf->QWidget::stackUnder(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_stackUnder_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.stackUnder", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_statusTip(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // statusTip()const
            QString cppResult = cppSelf->QWidget::statusTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_style(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // style()const
            QStyle * cppResult = cppSelf->QWidget::style();
            pyResult = Shiboken::Converter<QStyle * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_styleSheet(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // styleSheet()const
            QString cppResult = cppSelf->QWidget::styleSheet();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_tabletEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabletEvent(QTabletEvent*)
    if (Shiboken::Converter<QTabletEvent * >::isConvertible(arg)) {
        overloadId = 0; // tabletEvent(QTabletEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_tabletEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QTabletEvent* cpp_arg0 = Shiboken::Converter<QTabletEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // tabletEvent(QTabletEvent*)
            cppSelf->QWidget::tabletEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_tabletEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTabletEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.tabletEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_testAttribute(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testAttribute(Qt::WidgetAttribute)const
    if (Shiboken::Converter<Qt::WidgetAttribute >::isConvertible(arg)) {
        overloadId = 0; // testAttribute(Qt::WidgetAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_testAttribute_TypeError;

    // Call function/method
    {
        {
            Qt::WidgetAttribute cpp_arg0 = Shiboken::Converter<Qt::WidgetAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // testAttribute(Qt::WidgetAttribute)const
            bool cppResult = cppSelf->QWidget::testAttribute(cpp_arg0);
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQWidgetFunc_testAttribute_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.WidgetAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.testAttribute", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_toolTip(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // toolTip()const
            QString cppResult = cppSelf->QWidget::toolTip();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_underMouse(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // underMouse()const
            bool cppResult = cppSelf->QWidget::underMouse();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_ungrabGesture(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: ungrabGesture(Qt::GestureType)
    if (Shiboken::Converter<Qt::GestureType >::isConvertible(arg)) {
        overloadId = 0; // ungrabGesture(Qt::GestureType)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_ungrabGesture_TypeError;

    // Call function/method
    {
        {
            Qt::GestureType cpp_arg0 = Shiboken::Converter<Qt::GestureType >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // ungrabGesture(Qt::GestureType)
            cppSelf->QWidget::ungrabGesture(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_ungrabGesture_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GestureType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.ungrabGesture", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_unsetCursor(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetCursor()
            cppSelf->QWidget::unsetCursor();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_unsetLayoutDirection(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetLayoutDirection()
            cppSelf->QWidget::unsetLayoutDirection();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_unsetLocale(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // unsetLocale()
            cppSelf->QWidget::unsetLocale();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_update(PyObject* self, PyObject* args)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto SbkQWidgetFunc_update_TypeError;

    if (!PyArg_UnpackTuple(args, "update", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: update()
    // 1: update(QRect)
    // 2: update(QRegion)
    // 3: update(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // update()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 3; // update(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter<const QRect & >::isConvertible(pyargs[0])) {
        overloadId = 1; // update(QRect)
    } else if (numArgs == 1 && Shiboken::Converter<const QRegion & >::isConvertible(pyargs[0])) {
        overloadId = 2; // update(QRegion)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_update_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // update()
            {

                if(!PyErr_Occurred()) {
                // update()
                cppSelf->QWidget::update();
                }
                break;
            }
            case 1: // update(QRect)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                QRect* cpp_arg0 = Shiboken::Converter<QRect* >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                // update(QRect)
                cppSelf->QWidget::update(*cpp_arg0);
                }
                break;
            }
            case 2: // update(QRegion)
            {
                if (Shiboken::cppObjectIsInvalid(pyargs[0]))
                    return 0;
                std::auto_ptr<QRegion > cpp_arg0_auto_ptr;
                QRegion* cpp_arg0 = Shiboken::Converter<QRegion* >::toCpp(pyargs[0]);
                if (!Shiboken::Converter<QRegion >::checkType(pyargs[0]))
                    cpp_arg0_auto_ptr = std::auto_ptr<QRegion >(cpp_arg0);

                if(!PyErr_Occurred()) {
                // update(QRegion)
                cppSelf->QWidget::update(*cpp_arg0);
                }
                break;
            }
            case 3: // update(int,int,int,int)
            {
                int cpp_arg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cpp_arg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cpp_arg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cpp_arg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                // update(int,int,int,int)
                cppSelf->QWidget::update(cpp_arg0, cpp_arg1, cpp_arg2, cpp_arg3);
                }
                break;
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_update_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRect", "PySide.QtGui.QRegion", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QWidget.update", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_updateGeometry(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateGeometry()
            cppSelf->QWidget::updateGeometry();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_updateMicroFocus(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updateMicroFocus()
            cppSelf->QWidget::updateMicroFocus();
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* SbkQWidgetFunc_updatesEnabled(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // updatesEnabled()const
            bool cppResult = cppSelf->QWidget::updatesEnabled();
            pyResult = Shiboken::Converter<bool >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_visibleRegion(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // visibleRegion()const
            QRegion cppResult = cppSelf->QWidget::visibleRegion();
            pyResult = Shiboken::Converter<QRegion >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_whatsThis(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // whatsThis()const
            QString cppResult = cppSelf->QWidget::whatsThis();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_wheelEvent(PyObject* self, PyObject* arg)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: wheelEvent(QWheelEvent*)
    if (Shiboken::Converter<QWheelEvent * >::isConvertible(arg)) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQWidgetFunc_wheelEvent_TypeError;

    // Call function/method
    {
        {
            if (Shiboken::cppObjectIsInvalid(arg))
                return 0;
            QWheelEvent* cpp_arg0 = Shiboken::Converter<QWheelEvent* >::toCpp(arg);

            if(!PyErr_Occurred()) {
            // wheelEvent(QWheelEvent*)
            cppSelf->QWidget::wheelEvent(cpp_arg0);
            }
        }
        }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    SbkQWidgetFunc_wheelEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWheelEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QWidget.wheelEvent", overloads);
        return 0;
}

static PyObject* SbkQWidgetFunc_width(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // width()const
            int cppResult = cppSelf->QWidget::width();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_winId(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // winId()const
            unsigned long cppResult = cppSelf->QWidget::winId();
            pyResult = Shiboken::Converter<unsigned long >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_window(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // window()const
            QWidget * cppResult = cppSelf->QWidget::window();
            pyResult = Shiboken::Converter<QWidget * >::toPython(cppResult);
            Shiboken::setParent(self, pyResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowFilePath(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowFilePath()const
            QString cppResult = cppSelf->QWidget::windowFilePath();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowFlags(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowFlags()const
            QFlags<Qt::WindowType> cppResult = cppSelf->QWidget::windowFlags();
            pyResult = Shiboken::Converter<QFlags<Qt::WindowType> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowIcon(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowIcon()const
            QIcon cppResult = cppSelf->QWidget::windowIcon();
            pyResult = Shiboken::Converter<QIcon >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowIconText(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowIconText()const
            QString cppResult = cppSelf->QWidget::windowIconText();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowModality(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowModality()const
            Qt::WindowModality cppResult = cppSelf->QWidget::windowModality();
            pyResult = Shiboken::Converter<Qt::WindowModality >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowOpacity(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowOpacity()const
            qreal cppResult = cppSelf->QWidget::windowOpacity();
            pyResult = Shiboken::Converter<double >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowRole(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowRole()const
            QString cppResult = cppSelf->QWidget::windowRole();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowState(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowState()const
            QFlags<Qt::WindowState> cppResult = cppSelf->QWidget::windowState();
            pyResult = Shiboken::Converter<QFlags<Qt::WindowState> >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowTitle(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowTitle()const
            QString cppResult = cppSelf->QWidget::windowTitle();
            pyResult = Shiboken::Converter<QString >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_windowType(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // windowType()const
            Qt::WindowType cppResult = cppSelf->QWidget::windowType();
            pyResult = Shiboken::Converter<Qt::WindowType >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_x(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x()const
            int cppResult = cppSelf->QWidget::x();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_x11Info(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x11Info()const
            const QX11Info & cppResult = cppSelf->QWidget::x11Info();
            pyResult = Shiboken::Converter<const QX11Info & >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_x11PictureHandle(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // x11PictureHandle()const
            Qt::HANDLE cppResult = cppSelf->QWidget::x11PictureHandle();
            pyResult = Shiboken::Converter<Qt::HANDLE >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* SbkQWidgetFunc_y(PyObject* self)
{
    QWidget* cppSelf = 0;
    if (Shiboken::cppObjectIsInvalid(self))
        return 0;
    cppSelf = Shiboken::Converter<QWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
            // y()const
            int cppResult = cppSelf->QWidget::y();
            pyResult = Shiboken::Converter<int >::toPython(cppResult);
            }
        }
        }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef SbkQWidget_methods[] = {
    {"acceptDrops", (PyCFunction)SbkQWidgetFunc_acceptDrops, METH_NOARGS},
    {"accessibleDescription", (PyCFunction)SbkQWidgetFunc_accessibleDescription, METH_NOARGS},
    {"accessibleName", (PyCFunction)SbkQWidgetFunc_accessibleName, METH_NOARGS},
    {"actionEvent", (PyCFunction)SbkQWidgetFunc_actionEvent, METH_O},
    {"actions", (PyCFunction)SbkQWidgetFunc_actions, METH_NOARGS},
    {"activateWindow", (PyCFunction)SbkQWidgetFunc_activateWindow, METH_NOARGS},
    {"addAction", (PyCFunction)SbkQWidgetFunc_addAction, METH_O},
    {"addActions", (PyCFunction)SbkQWidgetFunc_addActions, METH_O},
    {"adjustSize", (PyCFunction)SbkQWidgetFunc_adjustSize, METH_NOARGS},
    {"autoFillBackground", (PyCFunction)SbkQWidgetFunc_autoFillBackground, METH_NOARGS},
    {"backgroundRole", (PyCFunction)SbkQWidgetFunc_backgroundRole, METH_NOARGS},
    {"baseSize", (PyCFunction)SbkQWidgetFunc_baseSize, METH_NOARGS},
    {"changeEvent", (PyCFunction)SbkQWidgetFunc_changeEvent, METH_O},
    {"childAt", (PyCFunction)SbkQWidgetFunc_childAt, METH_VARARGS},
    {"childrenRect", (PyCFunction)SbkQWidgetFunc_childrenRect, METH_NOARGS},
    {"childrenRegion", (PyCFunction)SbkQWidgetFunc_childrenRegion, METH_NOARGS},
    {"clearFocus", (PyCFunction)SbkQWidgetFunc_clearFocus, METH_NOARGS},
    {"clearMask", (PyCFunction)SbkQWidgetFunc_clearMask, METH_NOARGS},
    {"close", (PyCFunction)SbkQWidgetFunc_close, METH_NOARGS},
    {"closeEvent", (PyCFunction)SbkQWidgetFunc_closeEvent, METH_O},
    {"contentsMargins", (PyCFunction)SbkQWidgetFunc_contentsMargins, METH_NOARGS},
    {"contentsRect", (PyCFunction)SbkQWidgetFunc_contentsRect, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)SbkQWidgetFunc_contextMenuEvent, METH_O},
    {"contextMenuPolicy", (PyCFunction)SbkQWidgetFunc_contextMenuPolicy, METH_NOARGS},
    {"createWinId", (PyCFunction)SbkQWidgetFunc_createWinId, METH_NOARGS},
    {"cursor", (PyCFunction)SbkQWidgetFunc_cursor, METH_NOARGS},
    {"destroy", (PyCFunction)SbkQWidgetFunc_destroy, METH_VARARGS|METH_KEYWORDS},
    {"devType", (PyCFunction)SbkQWidgetFunc_devType, METH_NOARGS},
    {"dragEnterEvent", (PyCFunction)SbkQWidgetFunc_dragEnterEvent, METH_O},
    {"dragLeaveEvent", (PyCFunction)SbkQWidgetFunc_dragLeaveEvent, METH_O},
    {"dragMoveEvent", (PyCFunction)SbkQWidgetFunc_dragMoveEvent, METH_O},
    {"dropEvent", (PyCFunction)SbkQWidgetFunc_dropEvent, METH_O},
    {"effectiveWinId", (PyCFunction)SbkQWidgetFunc_effectiveWinId, METH_NOARGS},
    {"ensurePolished", (PyCFunction)SbkQWidgetFunc_ensurePolished, METH_NOARGS},
    {"enterEvent", (PyCFunction)SbkQWidgetFunc_enterEvent, METH_O},
    {"event", (PyCFunction)SbkQWidgetFunc_event, METH_O},
    {"focusInEvent", (PyCFunction)SbkQWidgetFunc_focusInEvent, METH_O},
    {"focusNextChild", (PyCFunction)SbkQWidgetFunc_focusNextChild, METH_NOARGS},
    {"focusNextPrevChild", (PyCFunction)SbkQWidgetFunc_focusNextPrevChild, METH_O},
    {"focusOutEvent", (PyCFunction)SbkQWidgetFunc_focusOutEvent, METH_O},
    {"focusPolicy", (PyCFunction)SbkQWidgetFunc_focusPolicy, METH_NOARGS},
    {"focusPreviousChild", (PyCFunction)SbkQWidgetFunc_focusPreviousChild, METH_NOARGS},
    {"focusProxy", (PyCFunction)SbkQWidgetFunc_focusProxy, METH_NOARGS},
    {"focusWidget", (PyCFunction)SbkQWidgetFunc_focusWidget, METH_NOARGS},
    {"font", (PyCFunction)SbkQWidgetFunc_font, METH_NOARGS},
    {"fontInfo", (PyCFunction)SbkQWidgetFunc_fontInfo, METH_NOARGS},
    {"fontMetrics", (PyCFunction)SbkQWidgetFunc_fontMetrics, METH_NOARGS},
    {"foregroundRole", (PyCFunction)SbkQWidgetFunc_foregroundRole, METH_NOARGS},
    {"frameGeometry", (PyCFunction)SbkQWidgetFunc_frameGeometry, METH_NOARGS},
    {"frameSize", (PyCFunction)SbkQWidgetFunc_frameSize, METH_NOARGS},
    {"geometry", (PyCFunction)SbkQWidgetFunc_geometry, METH_NOARGS},
    {"grabGesture", (PyCFunction)SbkQWidgetFunc_grabGesture, METH_VARARGS|METH_KEYWORDS},
    {"grabKeyboard", (PyCFunction)SbkQWidgetFunc_grabKeyboard, METH_NOARGS},
    {"grabMouse", (PyCFunction)SbkQWidgetFunc_grabMouse, METH_NOARGS|METH_O},
    {"grabShortcut", (PyCFunction)SbkQWidgetFunc_grabShortcut, METH_VARARGS|METH_KEYWORDS},
    {"graphicsEffect", (PyCFunction)SbkQWidgetFunc_graphicsEffect, METH_NOARGS},
    {"graphicsProxyWidget", (PyCFunction)SbkQWidgetFunc_graphicsProxyWidget, METH_NOARGS},
    {"hasFocus", (PyCFunction)SbkQWidgetFunc_hasFocus, METH_NOARGS},
    {"hasMouseTracking", (PyCFunction)SbkQWidgetFunc_hasMouseTracking, METH_NOARGS},
    {"height", (PyCFunction)SbkQWidgetFunc_height, METH_NOARGS},
    {"heightForWidth", (PyCFunction)SbkQWidgetFunc_heightForWidth, METH_O},
    {"hide", (PyCFunction)SbkQWidgetFunc_hide, METH_NOARGS},
    {"hideEvent", (PyCFunction)SbkQWidgetFunc_hideEvent, METH_O},
    {"inputContext", (PyCFunction)SbkQWidgetFunc_inputContext, METH_NOARGS},
    {"inputMethodEvent", (PyCFunction)SbkQWidgetFunc_inputMethodEvent, METH_O},
    {"inputMethodHints", (PyCFunction)SbkQWidgetFunc_inputMethodHints, METH_NOARGS},
    {"inputMethodQuery", (PyCFunction)SbkQWidgetFunc_inputMethodQuery, METH_O},
    {"insertAction", (PyCFunction)SbkQWidgetFunc_insertAction, METH_VARARGS},
    {"insertActions", (PyCFunction)SbkQWidgetFunc_insertActions, METH_VARARGS},
    {"isActiveWindow", (PyCFunction)SbkQWidgetFunc_isActiveWindow, METH_NOARGS},
    {"isAncestorOf", (PyCFunction)SbkQWidgetFunc_isAncestorOf, METH_O},
    {"isEnabled", (PyCFunction)SbkQWidgetFunc_isEnabled, METH_NOARGS},
    {"isEnabledTo", (PyCFunction)SbkQWidgetFunc_isEnabledTo, METH_O},
    {"isFullScreen", (PyCFunction)SbkQWidgetFunc_isFullScreen, METH_NOARGS},
    {"isHidden", (PyCFunction)SbkQWidgetFunc_isHidden, METH_NOARGS},
    {"isLeftToRight", (PyCFunction)SbkQWidgetFunc_isLeftToRight, METH_NOARGS},
    {"isMaximized", (PyCFunction)SbkQWidgetFunc_isMaximized, METH_NOARGS},
    {"isMinimized", (PyCFunction)SbkQWidgetFunc_isMinimized, METH_NOARGS},
    {"isModal", (PyCFunction)SbkQWidgetFunc_isModal, METH_NOARGS},
    {"isRightToLeft", (PyCFunction)SbkQWidgetFunc_isRightToLeft, METH_NOARGS},
    {"isVisible", (PyCFunction)SbkQWidgetFunc_isVisible, METH_NOARGS},
    {"isVisibleTo", (PyCFunction)SbkQWidgetFunc_isVisibleTo, METH_O},
    {"isWindow", (PyCFunction)SbkQWidgetFunc_isWindow, METH_NOARGS},
    {"isWindowModified", (PyCFunction)SbkQWidgetFunc_isWindowModified, METH_NOARGS},
    {"keyPressEvent", (PyCFunction)SbkQWidgetFunc_keyPressEvent, METH_O},
    {"keyReleaseEvent", (PyCFunction)SbkQWidgetFunc_keyReleaseEvent, METH_O},
    {"keyboardGrabber", (PyCFunction)SbkQWidgetFunc_keyboardGrabber, METH_NOARGS|METH_STATIC},
    {"languageChange", (PyCFunction)SbkQWidgetFunc_languageChange, METH_NOARGS},
    {"layout", (PyCFunction)SbkQWidgetFunc_layout, METH_NOARGS},
    {"layoutDirection", (PyCFunction)SbkQWidgetFunc_layoutDirection, METH_NOARGS},
    {"leaveEvent", (PyCFunction)SbkQWidgetFunc_leaveEvent, METH_O},
    {"locale", (PyCFunction)SbkQWidgetFunc_locale, METH_NOARGS},
    {"lower", (PyCFunction)SbkQWidgetFunc_lower, METH_NOARGS},
    {"mapFrom", (PyCFunction)SbkQWidgetFunc_mapFrom, METH_VARARGS},
    {"mapFromGlobal", (PyCFunction)SbkQWidgetFunc_mapFromGlobal, METH_O},
    {"mapFromParent", (PyCFunction)SbkQWidgetFunc_mapFromParent, METH_O},
    {"mapTo", (PyCFunction)SbkQWidgetFunc_mapTo, METH_VARARGS},
    {"mapToGlobal", (PyCFunction)SbkQWidgetFunc_mapToGlobal, METH_O},
    {"mapToParent", (PyCFunction)SbkQWidgetFunc_mapToParent, METH_O},
    {"mask", (PyCFunction)SbkQWidgetFunc_mask, METH_NOARGS},
    {"maximumHeight", (PyCFunction)SbkQWidgetFunc_maximumHeight, METH_NOARGS},
    {"maximumSize", (PyCFunction)SbkQWidgetFunc_maximumSize, METH_NOARGS},
    {"maximumWidth", (PyCFunction)SbkQWidgetFunc_maximumWidth, METH_NOARGS},
    {"metric", (PyCFunction)SbkQWidgetFunc_metric, METH_O},
    {"minimumHeight", (PyCFunction)SbkQWidgetFunc_minimumHeight, METH_NOARGS},
    {"minimumSize", (PyCFunction)SbkQWidgetFunc_minimumSize, METH_NOARGS},
    {"minimumSizeHint", (PyCFunction)SbkQWidgetFunc_minimumSizeHint, METH_NOARGS},
    {"minimumWidth", (PyCFunction)SbkQWidgetFunc_minimumWidth, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)SbkQWidgetFunc_mouseDoubleClickEvent, METH_O},
    {"mouseGrabber", (PyCFunction)SbkQWidgetFunc_mouseGrabber, METH_NOARGS|METH_STATIC},
    {"mouseMoveEvent", (PyCFunction)SbkQWidgetFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)SbkQWidgetFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)SbkQWidgetFunc_mouseReleaseEvent, METH_O},
    {"move", (PyCFunction)SbkQWidgetFunc_move, METH_VARARGS},
    {"moveEvent", (PyCFunction)SbkQWidgetFunc_moveEvent, METH_O},
    {"nativeParentWidget", (PyCFunction)SbkQWidgetFunc_nativeParentWidget, METH_NOARGS},
    {"nextInFocusChain", (PyCFunction)SbkQWidgetFunc_nextInFocusChain, METH_NOARGS},
    {"normalGeometry", (PyCFunction)SbkQWidgetFunc_normalGeometry, METH_NOARGS},
    {"overrideWindowFlags", (PyCFunction)SbkQWidgetFunc_overrideWindowFlags, METH_O},
    {"overrideWindowState", (PyCFunction)SbkQWidgetFunc_overrideWindowState, METH_O},
    {"paintEngine", (PyCFunction)SbkQWidgetFunc_paintEngine, METH_NOARGS},
    {"paintEvent", (PyCFunction)SbkQWidgetFunc_paintEvent, METH_O},
    {"palette", (PyCFunction)SbkQWidgetFunc_palette, METH_NOARGS},
    {"parentWidget", (PyCFunction)SbkQWidgetFunc_parentWidget, METH_NOARGS},
    {"pos", (PyCFunction)SbkQWidgetFunc_pos, METH_NOARGS},
    {"previousInFocusChain", (PyCFunction)SbkQWidgetFunc_previousInFocusChain, METH_NOARGS},
    {"raise_", (PyCFunction)SbkQWidgetFunc_raise_, METH_NOARGS},
    {"rect", (PyCFunction)SbkQWidgetFunc_rect, METH_NOARGS},
    {"releaseKeyboard", (PyCFunction)SbkQWidgetFunc_releaseKeyboard, METH_NOARGS},
    {"releaseMouse", (PyCFunction)SbkQWidgetFunc_releaseMouse, METH_NOARGS},
    {"releaseShortcut", (PyCFunction)SbkQWidgetFunc_releaseShortcut, METH_O},
    {"removeAction", (PyCFunction)SbkQWidgetFunc_removeAction, METH_O},
    {"render", (PyCFunction)SbkQWidgetFunc_render, METH_VARARGS|METH_KEYWORDS},
    {"repaint", (PyCFunction)SbkQWidgetFunc_repaint, METH_VARARGS},
    {"resetInputContext", (PyCFunction)SbkQWidgetFunc_resetInputContext, METH_NOARGS},
    {"resize", (PyCFunction)SbkQWidgetFunc_resize, METH_VARARGS},
    {"resizeEvent", (PyCFunction)SbkQWidgetFunc_resizeEvent, METH_O},
    {"restoreGeometry", (PyCFunction)SbkQWidgetFunc_restoreGeometry, METH_O},
    {"saveGeometry", (PyCFunction)SbkQWidgetFunc_saveGeometry, METH_NOARGS},
    {"scroll", (PyCFunction)SbkQWidgetFunc_scroll, METH_VARARGS},
    {"setAcceptDrops", (PyCFunction)SbkQWidgetFunc_setAcceptDrops, METH_O},
    {"setAccessibleDescription", (PyCFunction)SbkQWidgetFunc_setAccessibleDescription, METH_O},
    {"setAccessibleName", (PyCFunction)SbkQWidgetFunc_setAccessibleName, METH_O},
    {"setAttribute", (PyCFunction)SbkQWidgetFunc_setAttribute, METH_VARARGS|METH_KEYWORDS},
    {"setAutoFillBackground", (PyCFunction)SbkQWidgetFunc_setAutoFillBackground, METH_O},
    {"setBackgroundRole", (PyCFunction)SbkQWidgetFunc_setBackgroundRole, METH_O},
    {"setBaseSize", (PyCFunction)SbkQWidgetFunc_setBaseSize, METH_VARARGS},
    {"setContentsMargins", (PyCFunction)SbkQWidgetFunc_setContentsMargins, METH_VARARGS},
    {"setContextMenuPolicy", (PyCFunction)SbkQWidgetFunc_setContextMenuPolicy, METH_O},
    {"setCursor", (PyCFunction)SbkQWidgetFunc_setCursor, METH_O},
    {"setDisabled", (PyCFunction)SbkQWidgetFunc_setDisabled, METH_O},
    {"setEnabled", (PyCFunction)SbkQWidgetFunc_setEnabled, METH_O},
    {"setFixedHeight", (PyCFunction)SbkQWidgetFunc_setFixedHeight, METH_O},
    {"setFixedSize", (PyCFunction)SbkQWidgetFunc_setFixedSize, METH_VARARGS},
    {"setFixedWidth", (PyCFunction)SbkQWidgetFunc_setFixedWidth, METH_O},
    {"setFocus", (PyCFunction)SbkQWidgetFunc_setFocus, METH_NOARGS|METH_O},
    {"setFocusPolicy", (PyCFunction)SbkQWidgetFunc_setFocusPolicy, METH_O},
    {"setFocusProxy", (PyCFunction)SbkQWidgetFunc_setFocusProxy, METH_O},
    {"setFont", (PyCFunction)SbkQWidgetFunc_setFont, METH_O},
    {"setForegroundRole", (PyCFunction)SbkQWidgetFunc_setForegroundRole, METH_O},
    {"setGeometry", (PyCFunction)SbkQWidgetFunc_setGeometry, METH_VARARGS},
    {"setGraphicsEffect", (PyCFunction)SbkQWidgetFunc_setGraphicsEffect, METH_O},
    {"setHidden", (PyCFunction)SbkQWidgetFunc_setHidden, METH_O},
    {"setInputContext", (PyCFunction)SbkQWidgetFunc_setInputContext, METH_O},
    {"setInputMethodHints", (PyCFunction)SbkQWidgetFunc_setInputMethodHints, METH_O},
    {"setLayout", (PyCFunction)SbkQWidgetFunc_setLayout, METH_O},
    {"setLayoutDirection", (PyCFunction)SbkQWidgetFunc_setLayoutDirection, METH_O},
    {"setLocale", (PyCFunction)SbkQWidgetFunc_setLocale, METH_O},
    {"setMask", (PyCFunction)SbkQWidgetFunc_setMask, METH_O},
    {"setMaximumHeight", (PyCFunction)SbkQWidgetFunc_setMaximumHeight, METH_O},
    {"setMaximumSize", (PyCFunction)SbkQWidgetFunc_setMaximumSize, METH_VARARGS},
    {"setMaximumWidth", (PyCFunction)SbkQWidgetFunc_setMaximumWidth, METH_O},
    {"setMinimumHeight", (PyCFunction)SbkQWidgetFunc_setMinimumHeight, METH_O},
    {"setMinimumSize", (PyCFunction)SbkQWidgetFunc_setMinimumSize, METH_VARARGS},
    {"setMinimumWidth", (PyCFunction)SbkQWidgetFunc_setMinimumWidth, METH_O},
    {"setMouseTracking", (PyCFunction)SbkQWidgetFunc_setMouseTracking, METH_O},
    {"setPalette", (PyCFunction)SbkQWidgetFunc_setPalette, METH_O},
    {"setParent", (PyCFunction)SbkQWidgetFunc_setParent, METH_VARARGS},
    {"setShortcutAutoRepeat", (PyCFunction)SbkQWidgetFunc_setShortcutAutoRepeat, METH_VARARGS|METH_KEYWORDS},
    {"setShortcutEnabled", (PyCFunction)SbkQWidgetFunc_setShortcutEnabled, METH_VARARGS|METH_KEYWORDS},
    {"setSizeIncrement", (PyCFunction)SbkQWidgetFunc_setSizeIncrement, METH_VARARGS},
    {"setSizePolicy", (PyCFunction)SbkQWidgetFunc_setSizePolicy, METH_VARARGS},
    {"setStatusTip", (PyCFunction)SbkQWidgetFunc_setStatusTip, METH_O},
    {"setStyle", (PyCFunction)SbkQWidgetFunc_setStyle, METH_O},
    {"setStyleSheet", (PyCFunction)SbkQWidgetFunc_setStyleSheet, METH_O},
    {"setTabOrder", (PyCFunction)SbkQWidgetFunc_setTabOrder, METH_VARARGS|METH_STATIC},
    {"setToolTip", (PyCFunction)SbkQWidgetFunc_setToolTip, METH_O},
    {"setUpdatesEnabled", (PyCFunction)SbkQWidgetFunc_setUpdatesEnabled, METH_O},
    {"setVisible", (PyCFunction)SbkQWidgetFunc_setVisible, METH_O},
    {"setWhatsThis", (PyCFunction)SbkQWidgetFunc_setWhatsThis, METH_O},
    {"setWindowFilePath", (PyCFunction)SbkQWidgetFunc_setWindowFilePath, METH_O},
    {"setWindowFlags", (PyCFunction)SbkQWidgetFunc_setWindowFlags, METH_O},
    {"setWindowIcon", (PyCFunction)SbkQWidgetFunc_setWindowIcon, METH_O},
    {"setWindowIconText", (PyCFunction)SbkQWidgetFunc_setWindowIconText, METH_O},
    {"setWindowModality", (PyCFunction)SbkQWidgetFunc_setWindowModality, METH_O},
    {"setWindowModified", (PyCFunction)SbkQWidgetFunc_setWindowModified, METH_O},
    {"setWindowOpacity", (PyCFunction)SbkQWidgetFunc_setWindowOpacity, METH_O},
    {"setWindowRole", (PyCFunction)SbkQWidgetFunc_setWindowRole, METH_O},
    {"setWindowState", (PyCFunction)SbkQWidgetFunc_setWindowState, METH_O},
    {"setWindowTitle", (PyCFunction)SbkQWidgetFunc_setWindowTitle, METH_O},
    {"show", (PyCFunction)SbkQWidgetFunc_show, METH_NOARGS},
    {"showEvent", (PyCFunction)SbkQWidgetFunc_showEvent, METH_O},
    {"showFullScreen", (PyCFunction)SbkQWidgetFunc_showFullScreen, METH_NOARGS},
    {"showMaximized", (PyCFunction)SbkQWidgetFunc_showMaximized, METH_NOARGS},
    {"showMinimized", (PyCFunction)SbkQWidgetFunc_showMinimized, METH_NOARGS},
    {"showNormal", (PyCFunction)SbkQWidgetFunc_showNormal, METH_NOARGS},
    {"size", (PyCFunction)SbkQWidgetFunc_size, METH_NOARGS},
    {"sizeHint", (PyCFunction)SbkQWidgetFunc_sizeHint, METH_NOARGS},
    {"sizeIncrement", (PyCFunction)SbkQWidgetFunc_sizeIncrement, METH_NOARGS},
    {"sizePolicy", (PyCFunction)SbkQWidgetFunc_sizePolicy, METH_NOARGS},
    {"stackUnder", (PyCFunction)SbkQWidgetFunc_stackUnder, METH_O},
    {"statusTip", (PyCFunction)SbkQWidgetFunc_statusTip, METH_NOARGS},
    {"style", (PyCFunction)SbkQWidgetFunc_style, METH_NOARGS},
    {"styleSheet", (PyCFunction)SbkQWidgetFunc_styleSheet, METH_NOARGS},
    {"tabletEvent", (PyCFunction)SbkQWidgetFunc_tabletEvent, METH_O},
    {"testAttribute", (PyCFunction)SbkQWidgetFunc_testAttribute, METH_O},
    {"toolTip", (PyCFunction)SbkQWidgetFunc_toolTip, METH_NOARGS},
    {"underMouse", (PyCFunction)SbkQWidgetFunc_underMouse, METH_NOARGS},
    {"ungrabGesture", (PyCFunction)SbkQWidgetFunc_ungrabGesture, METH_O},
    {"unsetCursor", (PyCFunction)SbkQWidgetFunc_unsetCursor, METH_NOARGS},
    {"unsetLayoutDirection", (PyCFunction)SbkQWidgetFunc_unsetLayoutDirection, METH_NOARGS},
    {"unsetLocale", (PyCFunction)SbkQWidgetFunc_unsetLocale, METH_NOARGS},
    {"update", (PyCFunction)SbkQWidgetFunc_update, METH_VARARGS},
    {"updateGeometry", (PyCFunction)SbkQWidgetFunc_updateGeometry, METH_NOARGS},
    {"updateMicroFocus", (PyCFunction)SbkQWidgetFunc_updateMicroFocus, METH_NOARGS},
    {"updatesEnabled", (PyCFunction)SbkQWidgetFunc_updatesEnabled, METH_NOARGS},
    {"visibleRegion", (PyCFunction)SbkQWidgetFunc_visibleRegion, METH_NOARGS},
    {"whatsThis", (PyCFunction)SbkQWidgetFunc_whatsThis, METH_NOARGS},
    {"wheelEvent", (PyCFunction)SbkQWidgetFunc_wheelEvent, METH_O},
    {"width", (PyCFunction)SbkQWidgetFunc_width, METH_NOARGS},
    {"winId", (PyCFunction)SbkQWidgetFunc_winId, METH_NOARGS},
    {"window", (PyCFunction)SbkQWidgetFunc_window, METH_NOARGS},
    {"windowFilePath", (PyCFunction)SbkQWidgetFunc_windowFilePath, METH_NOARGS},
    {"windowFlags", (PyCFunction)SbkQWidgetFunc_windowFlags, METH_NOARGS},
    {"windowIcon", (PyCFunction)SbkQWidgetFunc_windowIcon, METH_NOARGS},
    {"windowIconText", (PyCFunction)SbkQWidgetFunc_windowIconText, METH_NOARGS},
    {"windowModality", (PyCFunction)SbkQWidgetFunc_windowModality, METH_NOARGS},
    {"windowOpacity", (PyCFunction)SbkQWidgetFunc_windowOpacity, METH_NOARGS},
    {"windowRole", (PyCFunction)SbkQWidgetFunc_windowRole, METH_NOARGS},
    {"windowState", (PyCFunction)SbkQWidgetFunc_windowState, METH_NOARGS},
    {"windowTitle", (PyCFunction)SbkQWidgetFunc_windowTitle, METH_NOARGS},
    {"windowType", (PyCFunction)SbkQWidgetFunc_windowType, METH_NOARGS},
    {"x", (PyCFunction)SbkQWidgetFunc_x, METH_NOARGS},
    {"x11Info", (PyCFunction)SbkQWidgetFunc_x11Info, METH_NOARGS},
    {"x11PictureHandle", (PyCFunction)SbkQWidgetFunc_x11PictureHandle, METH_NOARGS},
    {"y", (PyCFunction)SbkQWidgetFunc_y, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1 };
int*
SbkQWidget_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QWidget* class_ptr = reinterpret_cast<const QWidget*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QWidget*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QPaintDevice*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QPaintDevice*>((QWidget*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* SbkQWidgetSpecialCastFunction(void* obj, SbkBaseWrapperType* desiredType)
{
    QWidget* me = reinterpret_cast<QWidget*>(obj);
    if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkBaseWrapperType SbkQWidget_Type = { { {
    PyObject_HEAD_INIT(&Shiboken::SbkBaseWrapperType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QWidget",
    /*tp_basicsize*/        sizeof(Shiboken::SbkBaseWrapper),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &Shiboken::deallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          SbkQWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             SbkQWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              Shiboken::SbkBaseWrapper_TpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*mi_offsets*/          0,
    /*mi_init*/             SbkQWidget_mi_init,
    /*mi_specialcast*/      &SbkQWidgetSpecialCastFunction,
    /*type_discovery*/      0,
    /*obj_copier*/          0,
    /*ext_isconvertible*/   0,
    /*ext_tocpp*/           0,
    /*cpp_dtor*/            &Shiboken::callCppDestructor<QWidget >,
    /*is_multicpp*/         0,
    /*is_user_type*/        0,
    /*original_name*/       "QWidget*",
    /*user_data*/           0
};
} //extern

static SbkBaseWrapperType* SbkQWidget_typeDiscovery(void* cptr, SbkBaseWrapperType* instanceType)
{
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWidget*>(reinterpret_cast<QObject*>(cptr)))
        return &SbkQWidget_Type;
    if (instanceType == reinterpret_cast<Shiboken::SbkBaseWrapperType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QWidget*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &SbkQWidget_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___and__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWidget::RenderFlags >::checkType(self) && Shiboken::Converter<QWidget::RenderFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "&", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        & Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___or__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWidget::RenderFlags >::checkType(self) && Shiboken::Converter<QWidget::RenderFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "|", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        | Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___xor__(PyObject* self, PyObject* arg)
{
    if (Shiboken::Converter<QWidget::RenderFlags >::checkType(self) && Shiboken::Converter<QWidget::RenderFlags >::checkType(arg))
    {
        PyErr_Format(PyExc_TypeError, "unsupported operand type(s) for %s: '%s' and '%s'", "^", self->ob_type->tp_name, arg->ob_type->tp_name);
        return 0;
    }

    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        Shiboken::Converter<QWidget::RenderFlags>::toCpp(self)
        ^ Shiboken::Converter< QWidget::RenderFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QWidget_RenderFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWidget::RenderFlags >::toPython(
        ~Shiboken::Converter<QWidget::RenderFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QWidget_RenderFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QWidget_RenderFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


static PyGetSetDef SbkPySide_QtGui_QWidget_RenderFlag_getsetlist[] = {
    {const_cast<char*>("name"), (getter)Shiboken::SbkEnumObject_name},
    {0}  // Sentinel
};

// forward declaration of new function
static PyObject* SbkPySide_QtGui_QWidget_RenderFlag_New(PyTypeObject*, PyObject*, PyObject*);

static PyTypeObject SbkPySide_QtGui_QWidget_RenderFlag_Type = {
    PyObject_HEAD_INIT(&Shiboken::SbkEnumType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderFlag",
    /*tp_basicsize*/        sizeof(Shiboken::SbkEnumObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Shiboken::SbkEnumObject_repr,
    /*tp_as_number*/        &SbkPySide_QtGui_QWidget_RenderFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              Shiboken::SbkEnumObject_repr,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           SbkPySide_QtGui_QWidget_RenderFlag_getsetlist,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkPySide_QtGui_QWidget_RenderFlag_New,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};

static PyObject* SbkPySide_QtGui_QWidget_RenderFlag_New(PyTypeObject* type, PyObject* args, PyObject* kwds)
{
    int item_value = 0;
    if (!PyArg_ParseTuple(args, "|i:__new__", &item_value))
        return 0;
    PyObject* self = Shiboken::SbkEnumObject_New(type, item_value);

    if (!self)
        return 0;
    return self;
}

// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QWidget_RenderFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "RenderFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        SbkPySide_QtGui_QWidget_RenderFlag_Type.tp_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&SbkQWidget_Type);

    SbkQWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    SbkQWidget_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]);

    // Fill type discovery information
    SbkQWidget_Type.type_discovery = &SbkQWidget_typeDiscovery;
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &SbkQWidget_Type);
    bm.addClassInheritance(reinterpret_cast<SbkBaseWrapperType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &SbkQWidget_Type);

    if (PyType_Ready((PyTypeObject*)&SbkQWidget_Type) < 0)
        return;

    Py_INCREF(reinterpret_cast<PyObject*>(&SbkQWidget_Type));
    PyModule_AddObject(module, "QWidget",
        ((PyObject*)&SbkQWidget_Type));

    // Initialize enums
    PyObject* enum_item;

    // init enum class: RenderFlag
    SbkPySide_QtGuiTypes[SBK_QWIDGET_RENDERFLAG_IDX] = &SbkPySide_QtGui_QWidget_RenderFlag_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWidget_RenderFlag_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWidget_RenderFlag_Type);
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict,
            "RenderFlag",((PyObject*)&SbkPySide_QtGui_QWidget_RenderFlag_Type));

    // init flags class: QFlags<QWidget::RenderFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QWIDGET_RENDERFLAG__IDX] = &SbkPySide_QtGui_QWidget_RenderFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QWidget_RenderFlags_Type) < 0)
        return;
    Py_INCREF(&SbkPySide_QtGui_QWidget_RenderFlags_Type);
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict,
            "RenderFlags",((PyObject*)&SbkPySide_QtGui_QWidget_RenderFlags_Type));

    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWidget_RenderFlag_Type,
        (long) QWidget::DrawWindowBackground, "DrawWindowBackground");
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict,
        "DrawWindowBackground", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag_Type.tp_dict,
        "DrawWindowBackground", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWidget_RenderFlag_Type,
        (long) QWidget::DrawChildren, "DrawChildren");
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict,
        "DrawChildren", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag_Type.tp_dict,
        "DrawChildren", enum_item);
    enum_item = Shiboken::SbkEnumObject_New(&SbkPySide_QtGui_QWidget_RenderFlag_Type,
        (long) QWidget::IgnoreMask, "IgnoreMask");
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict,
        "IgnoreMask", enum_item);
    PyDict_SetItemString(SbkPySide_QtGui_QWidget_RenderFlag_Type.tp_dict,
        "IgnoreMask", enum_item);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWidget::RenderFlag");

    // Initialize signals
    PyObject* signal_item;

    signal_item = PySide::signalNew("customContextMenuRequested", "const QPoint&", NULL);
    PyDict_SetItemString(SbkQWidget_Type.super.ht_type.tp_dict, "customContextMenuRequested", signal_item);
    Py_DECREF(signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >("QWidget*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >(typeid(QWidget).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWidget >(typeid(QWidgetWrapper).name());
    PySide::initQtMetaType<QWidget* >();
}

